@@ -17,7 +17,9 @@ module RuboCop
         extend AutoCorrector
 
         MSG = 'Use `#%<type>s_type?` to check node type.'
+        RESTRICT_ON_SEND = %i[==].freeze
 
+        # @!method node_type_check(node)
         def_node_matcher :node_type_check, <<~PATTERN
           (send (send $_ :type) :== (sym $_))
         PATTERN
@@ -28,9 +30,7 @@ module RuboCop
 
             message = format(MSG, type: node_type)
             add_offense(node, message: message) do |corrector|
-              range = node.loc.expression.with(
-                begin_pos: receiver.loc.expression.end_pos + 1
-              )
+              range = node.loc.expression.with(begin_pos: receiver.loc.expression.end_pos + 1)
               corrector.replace(range, "#{node_type}_type?")
             end
           end
