@@ -3,9 +3,16 @@
 module RuboCop
   module Cop
     module Layout
-      # This cop checks if empty lines around the bodies of blocks match
+      # Checks if empty lines around the bodies of blocks match
       # the configuration.
       #
+      # @example EnforcedStyle: no_empty_lines (default)
+      #   # good
+      #
+      #   foo do |bar|
+      #     # ...
+      #   end
+      #
       # @example EnforcedStyle: empty_lines
       #   # good
       #
@@ -14,15 +21,9 @@ module RuboCop
       #     # ...
       #
       #   end
-      #
-      # @example EnforcedStyle: no_empty_lines (default)
-      #   # good
-      #
-      #   foo do |bar|
-      #     # ...
-      #   end
-      class EmptyLinesAroundBlockBody < Cop
+      class EmptyLinesAroundBlockBody < Base
         include EmptyLinesAroundBody
+        extend AutoCorrector
 
         KIND = 'block'
 
@@ -32,9 +33,7 @@ module RuboCop
           check(node, node.body, adjusted_first_line: first_line)
         end
 
-        def autocorrect(node)
-          EmptyLineCorrector.correct(node)
-        end
+        alias on_numblock on_block
       end
     end
   end
