@@ -3,7 +3,7 @@
 module RuboCop
   module Cop
     module Layout
-      # This cop checks for a line break before the first parameter in a
+      # Checks for a line break before the first parameter in a
       # multi-line method parameter definition.
       #
       # @example
@@ -26,20 +26,16 @@ module RuboCop
       #         bar
       #       do_something
       #     end
-      class FirstMethodParameterLineBreak < Cop
+      class FirstMethodParameterLineBreak < Base
         include FirstElementLineBreak
+        extend AutoCorrector
 
-        MSG = 'Add a line break before the first parameter of a ' \
-              'multi-line method parameter list.'
+        MSG = 'Add a line break before the first parameter of a multi-line method parameter list.'
 
         def on_def(node)
           check_method_line_break(node, node.arguments)
         end
         alias on_defs on_def
-
-        def autocorrect(node)
-          EmptyLineCorrector.insert_before(node)
-        end
       end
     end
   end
