@@ -3,7 +3,7 @@
 module RuboCop
   module Cop
     module Layout
-      # This cop ensures that each item in a multi-line array
+      # Ensures that each item in a multi-line array
       # starts on a separate line.
       #
       # @example
@@ -20,19 +20,15 @@ module RuboCop
       #     b,
       #     c
       #   ]
-      class MultilineArrayLineBreaks < Cop
+      class MultilineArrayLineBreaks < Base
         include MultilineElementLineBreaks
+        extend AutoCorrector
 
-        MSG = 'Each item in a multi-line array must start ' \
-          'on a separate line.'
+        MSG = 'Each item in a multi-line array must start on a separate line.'
 
         def on_array(node)
           check_line_breaks(node, node.children)
         end
-
-        def autocorrect(node)
-          EmptyLineCorrector.insert_before(node)
-        end
       end
     end
   end
