@@ -3,7 +3,7 @@
 module RuboCop
   module Cop
     module Layout
-      # This cop ensures that each key in a multi-line hash
+      # Ensures that each key in a multi-line hash
       # starts on a separate line.
       #
       # @example
@@ -20,11 +20,11 @@ module RuboCop
       #     b: 2,
       #     c: 3
       #   }
-      class MultilineHashKeyLineBreaks < Cop
+      class MultilineHashKeyLineBreaks < Base
         include MultilineElementLineBreaks
+        extend AutoCorrector
 
-        MSG = 'Each key in a multi-line hash must start on a ' \
-          'separate line.'
+        MSG = 'Each key in a multi-line hash must start on a separate line.'
 
         def on_hash(node)
           # This cop only deals with hashes wrapped by a set of curly
@@ -35,10 +35,6 @@ module RuboCop
           check_line_breaks(node, node.children) if node.loc.begin
         end
 
-        def autocorrect(node)
-          EmptyLineCorrector.insert_before(node)
-        end
-
         private
 
         def starts_with_curly_brace?(node)
