@@ -3,9 +3,12 @@
 module RuboCop
   module Cop
     module Layout
-      # This cop ensures that each argument in a multi-line method call
+      # Ensures that each argument in a multi-line method call
       # starts on a separate line.
       #
+      # NOTE: This cop does not move the first argument, if you want that to
+      # be on a separate line, see `Layout/FirstMethodArgumentLineBreak`.
+      #
       # @example
       #
       #   # bad
@@ -19,11 +22,14 @@ module RuboCop
       #     b,
       #     c
       #   )
-      class MultilineMethodArgumentLineBreaks < Cop
-        include(MultilineElementLineBreaks)
+      #
+      #   # good
+      #   foo(a, b, c)
+      class MultilineMethodArgumentLineBreaks < Base
+        include MultilineElementLineBreaks
+        extend AutoCorrector
 
-        MSG = 'Each argument in a multi-line method call must start ' \
-          'on a separate line.'
+        MSG = 'Each argument in a multi-line method call must start on a separate line.'
 
         def on_send(node)
           return if node.method?(:[]=)
@@ -36,16 +42,11 @@ module RuboCop
           #
           # ...then each key/value pair is treated as a method 'argument'
           # when determining where line breaks should appear.
-          if (last_arg = args.last)
-            args = args[0...-1] + last_arg.children if last_arg.hash_type? && !last_arg.braces?
-          end
+          last_arg = args.last
+          args = args[0...-1] + last_arg.children if last_arg&.hash_type? && !last_arg&.braces?
 
           check_line_breaks(node, args)
         end
-
-        def autocorrect(node)
-          EmptyLineCorrector.insert_before(node)
-        end
       end
     end
   end
