@@ -3,7 +3,7 @@
 module RuboCop
   module Cop
     module Lint
-      # This cop checks for duplicated keys in hash literals.
+      # Checks for duplicated keys in hash literals.
       #
       # This cop mirrors a warning in Ruby 2.2.
       #
@@ -28,9 +28,7 @@ module RuboCop
 
           return unless duplicates?(keys)
 
-          consecutive_duplicates(keys).each do |key|
-            add_offense(key)
-          end
+          consecutive_duplicates(keys).each { |key| add_offense(key) }
         end
       end
     end
