@@ -3,7 +3,7 @@
 module RuboCop
   module Cop
     module Lint
-      # This cop checks that there are no repeated exceptions
+      # Checks that there are no repeated exceptions
       # used in 'rescue' expressions.
       #
       # @example
@@ -33,27 +33,14 @@ module RuboCop
         def on_rescue(node)
           return if rescue_modifier?(node)
 
-          _body, *resbodies, _else = *node
-
-          resbodies.each_with_object(Set.new) do |resbody, previous|
-            rescued_exceptions = rescued_exceptions(resbody)
+          node.resbody_branches.each_with_object(Set.new) do |resbody, previous|
+            rescued_exceptions = resbody.exceptions
 
             rescued_exceptions.each do |exception|
               add_offense(exception) unless previous.add?(exception)
             end
           end
         end
-
-        private
-
-        def rescued_exceptions(resbody)
-          rescue_group, = *resbody
-          if rescue_group
-            rescue_group.values
-          else
-            []
-          end
-        end
       end
     end
   end
