@@ -3,7 +3,7 @@
 module RuboCop
   module Cop
     module Lint
-      # This cop checks for the presence of `when` branches without a body.
+      # Checks for the presence of `when` branches without a body.
       #
       # @example
       #
@@ -45,12 +45,14 @@ module RuboCop
       #   end
       #
       class EmptyWhen < Base
+        include CommentsHelp
+
         MSG = 'Avoid `when` branches without a body.'
 
         def on_case(node)
           node.each_when do |when_node|
             next if when_node.body
-            next if cop_config['AllowComments'] && comment_lines?(node)
+            next if cop_config['AllowComments'] && contains_comments?(when_node)
 
             add_offense(when_node)
           end
