@@ -3,7 +3,7 @@
 module RuboCop
   module Cop
     module Lint
-      # This cop identifies Float literals which are, like, really really really
+      # Identifies Float literals which are, like, really really really
       # really really really really really big. Too big. No-one needs Floats
       # that big. If you need a float that big, something is wrong with you.
       #
@@ -24,8 +24,7 @@ module RuboCop
         def on_float(node)
           value, = *node
 
-          return unless value.infinite? ||
-                        value.zero? && /[1-9]/.match?(node.source)
+          return unless value.infinite? || (value.zero? && /[1-9]/.match?(node.source))
 
           add_offense(node)
         end
