@@ -3,7 +3,7 @@
 module RuboCop
   module Cop
     module Lint
-      # This cop checks for `rand(1)` calls.
+      # Checks for `rand(1)` calls.
       # Such calls always return `0`.
       #
       # @example
@@ -21,15 +21,16 @@ module RuboCop
       #
       #   0 # just use 0 instead
       class RandOne < Base
-        MSG = '`%<method>s` always returns `0`. ' \
-              'Perhaps you meant `rand(2)` or `rand`?'
+        MSG = '`%<method>s` always returns `0`. Perhaps you meant `rand(2)` or `rand`?'
+        RESTRICT_ON_SEND = %i[rand].freeze
 
+        # @!method rand_one?(node)
         def_node_matcher :rand_one?, <<~PATTERN
           (send {(const {nil? cbase} :Kernel) nil?} :rand {(int {-1 1}) (float {-1.0 1.0})})
         PATTERN
 
         def on_send(node)
-          return unless node.method?(:rand) && rand_one?(node)
+          return unless rand_one?(node)
 
           add_offense(node)
         end
