@@ -3,7 +3,7 @@
 module RuboCop
   module Cop
     module Lint
-      # This cop checks for string conversion in string interpolation,
+      # Checks for string conversion in string interpolation,
       # which is redundant.
       #
       # @example
@@ -22,9 +22,9 @@ module RuboCop
         extend AutoCorrector
 
         MSG_DEFAULT = 'Redundant use of `Object#to_s` in interpolation.'
-        MSG_SELF = 'Use `self` instead of `Object#to_s` in ' \
-                   'interpolation.'
+        MSG_SELF = 'Use `self` instead of `Object#to_s` in interpolation.'
 
+        # @!method to_s_without_args?(node)
         def_node_matcher :to_s_without_args?, '(send _ :to_s)'
 
         def on_interpolation(begin_node)
