@@ -3,7 +3,7 @@
 module RuboCop
   module Cop
     module Lint
-      # This cop checks for `rescue` blocks targeting the Exception class.
+      # Checks for `rescue` blocks targeting the Exception class.
       #
       # @example
       #
@@ -25,8 +25,7 @@ module RuboCop
       #     handle_exception
       #   end
       class RescueException < Base
-        MSG = 'Avoid rescuing the `Exception` class. ' \
-              'Perhaps you meant to rescue `StandardError`?'
+        MSG = 'Avoid rescuing the `Exception` class. Perhaps you meant to rescue `StandardError`?'
 
         def on_resbody(node)
           return unless node.children.first
