@@ -3,7 +3,7 @@
 module RuboCop
   module Cop
     module Lint
-      # This cop checks for the use of a return with a value in a context
+      # Checks for the use of a return with a value in a context
       # where the value will be ignored. (initialize and setter methods)
       #
       # @example
@@ -40,12 +40,12 @@ module RuboCop
           context_node = non_void_context(return_node)
 
           return unless context_node&.def_type?
+          return unless context_node&.void_context?
 
-          method_name = method_name(context_node)
-
-          return unless method_name && void_context_method?(method_name)
-
-          add_offense(return_node.loc.keyword, message: format(message, method: method_name))
+          add_offense(
+            return_node.loc.keyword,
+            message: format(message, method: context_node.method_name)
+          )
         end
 
         private
@@ -53,19 +53,6 @@ module RuboCop
         def non_void_context(return_node)
           return_node.each_ancestor(:block, :def, :defs).first
         end
-
-        def method_name(context_node)
-          context_node.children.first
-        end
-
-        def void_context_method?(method_name)
-          method_name == :initialize || setter_method?(method_name)
-        end
-
-        def setter_method?(method_name)
-          method_name.to_s.end_with?('=') &&
-            !AST::Node::COMPARISON_OPERATORS.include?(method_name)
-        end
       end
     end
   end
