@@ -3,7 +3,7 @@
 module RuboCop
   module Cop
     module Lint
-      # This cop checks for top level return with arguments. If there is a
+      # Checks for top level return with arguments. If there is a
       # top-level return statement with an argument, then the argument is
       # always ignored. This is detected automatically since Ruby 2.7.
       #
@@ -11,7 +11,7 @@ module RuboCop
       #
       #   # Detected since Ruby 2.7
       #   return 1 # 1 is always ignored.
-      class TopLevelReturnWithArgument < Cop
+      class TopLevelReturnWithArgument < Base
         # This cop works by validating the ancestors of the return node. A
         # top-level return node's ancestors should not be of block, def, or
         # defs type.
