@@ -20,6 +20,11 @@ module RuboCop
 
       private
 
+      def indent_level(str)
+        indentations = str.lines.map { |line| line[/^\s*/] }.reject { |line| line.end_with?("\n") }
+        indentations.empty? ? 0 : indentations.min_by(&:size).size
+      end
+
       def delimiter_string(node)
         node.source.match(OPENING_DELIMITER).captures[1]
       end
