@@ -3,7 +3,7 @@
 module RuboCop
   module Cop
     module Style
-      # This cop checks for places where the `#__dir__` method can replace more
+      # Checks for places where the `#__dir__` method can replace more
       # complex constructs to retrieve a canonicalized absolute path to the
       # current file.
       #
@@ -18,9 +18,14 @@ module RuboCop
       #   path = __dir__
       class Dir < Base
         extend AutoCorrector
+        extend TargetRubyVersion
+
+        minimum_target_ruby_version 2.0
 
         MSG = "Use `__dir__` to get an absolute path to the current file's directory."
+        RESTRICT_ON_SEND = %i[expand_path dirname].freeze
 
+        # @!method dir_replacement?(node)
         def_node_matcher :dir_replacement?, <<~PATTERN
           {(send (const {nil? cbase} :File) :expand_path (send (const {nil? cbase} :File) :dirname  #file_keyword?))
            (send (const {nil? cbase} :File) :dirname     (send (const {nil? cbase} :File) :realpath #file_keyword?))}
