@@ -3,7 +3,7 @@
 module RuboCop
   module Cop
     module Style
-      # This cop checks for the presence of `method_missing` without also
+      # Checks for the presence of `method_missing` without also
       # defining `respond_to_missing?`.
       #
       # @example
@@ -22,8 +22,7 @@ module RuboCop
       #   end
       #
       class MissingRespondToMissing < Base
-        MSG =
-          'When using `method_missing`, define `respond_to_missing?`.'
+        MSG = 'When using `method_missing`, define `respond_to_missing?`.'
 
         def on_def(node)
           return unless node.method?(:method_missing)
