@@ -11,14 +11,16 @@ RSpec.describe RuboCop::ConfigLoader do
     described_class.default_configuration = nil
   end
 
-  after { described_class.debug = false }
+  after do
+    described_class.debug = false
+    # Remove custom configuration
+    described_class.default_configuration = nil
+  end
 
   let(:default_config) { described_class.default_configuration }
 
   describe '.configuration_file_for', :isolated_environment do
-    subject(:configuration_file_for) do
-      described_class.configuration_file_for(dir_path)
-    end
+    subject(:configuration_file_for) { described_class.configuration_file_for(dir_path) }
 
     context 'when no config file exists in ancestor directories' do
       let(:dir_path) { 'dir' }
@@ -37,9 +39,7 @@ RSpec.describe RuboCop::ConfigLoader do
         before { create_empty_file('~/.config/rubocop/config.yml') }
 
         it 'returns the path to the file in XDG directory' do
-          expect(configuration_file_for).to end_with(
-            'home/.config/rubocop/config.yml'
-          )
+          expect(configuration_file_for).to end_with('home/.config/rubocop/config.yml')
         end
       end
 
@@ -50,9 +50,7 @@ RSpec.describe RuboCop::ConfigLoader do
         end
 
         it 'returns the path to the file in XDG directory' do
-          expect(configuration_file_for).to end_with(
-            'home/xdg-stuff/rubocop/config.yml'
-          )
+          expect(configuration_file_for).to end_with('home/xdg-stuff/rubocop/config.yml')
         end
       end
 
@@ -87,14 +85,14 @@ RSpec.describe RuboCop::ConfigLoader do
 
       before do
         # Force reload of project root
-        described_class.project_root = nil
+        RuboCop::ConfigFinder.project_root = nil
         create_empty_file('Gemfile')
         create_empty_file('../.rubocop.yml')
       end
 
       after do
         # Don't leak project root change
-        described_class.project_root = nil
+        RuboCop::ConfigFinder.project_root = nil
       end
 
       it 'ignores the spurious config and falls back to the provided default file if run from the project' do
@@ -131,9 +129,7 @@ RSpec.describe RuboCop::ConfigLoader do
   end
 
   describe '.configuration_from_file', :isolated_environment do
-    subject(:configuration_from_file) do
-      described_class.configuration_from_file(file_path)
-    end
+    subject(:configuration_from_file) { described_class.configuration_from_file(file_path) }
 
     context 'with any config file' do
       let(:file_path) { '.rubocop.yml' }
@@ -273,6 +269,9 @@ RSpec.describe RuboCop::ConfigLoader do
             Exclude:
               - vendor/**
               - !ruby/regexp /[A-Z]/
+          Style/StringLiterals:
+            Include:
+              - dir/**/*.rb
         YAML
 
         create_file(file_path, ['inherit_from: ../.rubocop.yml'])
@@ -283,6 +282,10 @@ RSpec.describe RuboCop::ConfigLoader do
         expect(excludes).to eq([File.expand_path('vendor/**'), /[A-Z]/])
       end
 
+      it 'gets an Include that is relative to the subdirectory' do
+        expect(configuration_from_file['Style/StringLiterals']['Include']).to eq(['**/*.rb'])
+      end
+
       it 'ignores parent AllCops/Exclude if ignore_parent_exclusion is true' do
         sub_file_path = 'vendor/.rubocop.yml'
         create_file(sub_file_path, <<~YAML)
@@ -324,6 +327,9 @@ RSpec.describe RuboCop::ConfigLoader do
           AllCops:
             Exclude:
               - vendor/**
+          Style/StringLiterals:
+            Include:
+              - '**/*.rb'
         YAML
 
         create_file(file_path, ['inherit_from: ../src/.rubocop.yml'])
@@ -333,37 +339,47 @@ RSpec.describe RuboCop::ConfigLoader do
         excludes = configuration_from_file['AllCops']['Exclude']
         expect(excludes).to eq([File.expand_path('src/vendor/**')])
       end
+
+      it 'gets an Include that is relative to the subdirectory' do
+        expect(configuration_from_file['Style/StringLiterals']['Include']).to eq(['../src/**/*.rb'])
+      end
     end
 
     context 'when a file inherits and overrides an Exclude' do
       let(:file_path) { '.rubocop.yml' }
       let(:message) do
         '.rubocop.yml: Style/For:Exclude overrides the same parameter in ' \
-        '.rubocop_todo.yml'
+          '.rubocop_2.yml'
       end
 
       before do
         create_file(file_path, <<~YAML)
-          inherit_from: .rubocop_todo.yml
+          inherit_from:
+            - .rubocop_1.yml
+            - .rubocop_2.yml
 
           Style/For:
             Exclude:
               - spec/requests/group_invite_spec.rb
         YAML
 
-        create_file('.rubocop_todo.yml', <<~YAML)
+        create_file('.rubocop_1.yml', <<~YAML)
+          Style/StringLiterals:
+            Exclude:
+              - 'spec/models/group_spec.rb'
+        YAML
+
+        create_file('.rubocop_2.yml', <<~YAML)
           Style/For:
             Exclude:
               - 'spec/models/expense_spec.rb'
-              - 'spec/models/group_spec.rb'
         YAML
       end
 
       it 'gets the Exclude overriding the inherited one with a warning' do
         expect do
           excludes = configuration_from_file['Style/For']['Exclude']
-          expect(excludes)
-            .to eq([File.expand_path('spec/requests/group_invite_spec.rb')])
+          expect(excludes).to eq([File.expand_path('spec/requests/group_invite_spec.rb')])
         end.to output(/#{message}/).to_stdout
       end
     end
@@ -395,15 +411,8 @@ RSpec.describe RuboCop::ConfigLoader do
       end
 
       it 'removes hash keys with nil values' do
-        inverse_methods =
-          configuration_from_file['Style/InverseMethods']['InverseMethods']
-        expect(inverse_methods).to eq(
-          '==': :!=,
-          '=~': :!~,
-          any?: :none?,
-          even?: :odd?,
-          foo: :bar
-        )
+        inverse_methods = configuration_from_file['Style/InverseMethods']['InverseMethods']
+        expect(inverse_methods).to eq('==': :!=, '=~': :!~, any?: :none?, even?: :odd?, foo: :bar)
       end
     end
 
@@ -460,8 +469,7 @@ RSpec.describe RuboCop::ConfigLoader do
                   default_config['AllCops']['Exclude']).sort)
       end
 
-      it 'merges Style/Documentation:Exclude with parent and ' \
-         'default configuration' do
+      it 'merges Style/Documentation:Exclude with parent and default configuration' do
         expect(configuration_from_file['Style/Documentation']['Exclude'].sort)
           .to eq(([File.expand_path('funk/*.rb'),
                    File.expand_path('junk/*.rb')] +
@@ -511,7 +519,7 @@ RSpec.describe RuboCop::ConfigLoader do
       end
 
       it 'unions the two lists of Excludes from the parent and child configs ' \
-          'for cops that do not override the inherit_mode' do
+         'for cops that do not override the inherit_mode' do
         expect do
           excludes = configuration_from_file['Style/For']['Exclude']
           expect(excludes.sort)
@@ -521,23 +529,161 @@ RSpec.describe RuboCop::ConfigLoader do
         end.not_to output(/overrides the same parameter/).to_stdout
       end
 
-      it 'overwrites the Exclude from the parent when the cop overrides' \
-          'the global inherit_mode' do
+      it 'overwrites the Exclude from the parent when the cop overridesthe global inherit_mode' do
         expect do
           excludes = configuration_from_file['Style/Dir']['Exclude']
-          expect(excludes)
-            .to eq([File.expand_path('spec/requests/group_invite_spec.rb')])
+          expect(excludes).to eq([File.expand_path('spec/requests/group_invite_spec.rb')])
         end.not_to output(/overrides the same parameter/).to_stdout
       end
     end
 
-    context 'when a department is disabled' do
+    context 'when inherit_mode is specified for a nested element even ' \
+            'without explicitly specifying `inherit_from`/`inherit_gem`' do
       let(:file_path) { '.rubocop.yml' }
 
-      shared_examples 'resolves enabled/disabled for all cops' do |enabled_by_default, disabled_by_default|
+      before do
+        stub_const('RuboCop::ConfigLoader::RUBOCOP_HOME', 'rubocop')
+        stub_const('RuboCop::ConfigLoader::DEFAULT_FILE',
+                   File.join('rubocop', 'config', 'default.yml'))
+
+        create_file('rubocop/config/default.yml', <<~YAML)
+          Language:
+            Examples:
+              inherit_mode:
+                merge:
+                  - Regular
+                  - Focused
+              Regular:
+                - it
+              Focused:
+                - fit
+              Skipped:
+                - xit
+              Pending:
+                - pending
+        YAML
+        create_file(file_path, <<~YAML)
+          Language:
+            Examples:
+              inherit_mode:
+                merge:
+                  - Skipped
+                override:
+                  - Focused
+              Regular:
+                - scenario
+              Focused:
+                - fscenario
+              Skipped:
+                - xscenario
+              Pending:
+                - later
+        YAML
+      end
+
+      it 'respects the priority of `inherit_mode`, user-defined first' do
+        examples_configuration = configuration_from_file['Language']['Examples']
+        expect(examples_configuration['Regular']).to contain_exactly('it', 'scenario')
+        expect(examples_configuration['Focused']).to contain_exactly('fscenario')
+        expect(examples_configuration['Skipped']).to contain_exactly('xit', 'xscenario')
+        expect(examples_configuration['Pending']).to contain_exactly('later')
+      end
+    end
+
+    context 'when inherit_mode:merge for a cop lists parameters that are either in parent or in ' \
+            'default configuration' do
+      let(:file_path) { '.rubocop.yml' }
+
+      before do
+        create_file('hosted_config.yml', <<~YAML)
+          AllCops:
+            NewCops: enable
+
+          Naming/VariableNumber:
+            EnforcedStyle: snake_case
+            Exclude:
+              - foo.rb
+            Include:
+              - bar.rb
+        YAML
+        create_file(file_path, <<~YAML)
+          inherit_from:
+            - hosted_config.yml
+
+          Naming/VariableNumber:
+            inherit_mode:
+              merge:
+                - AllowedIdentifiers
+                - Exclude
+                - Include
+            AllowedIdentifiers:
+              - iso2
+            Exclude:
+              - test.rb
+            Include:
+              - another_test.rb
+        YAML
+      end
+
+      it 'merges array parameters with parent or default configuration' do
+        examples_configuration = configuration_from_file['Naming/VariableNumber']
+        expect(examples_configuration['Exclude'].map { |abs_path| File.basename(abs_path) })
+          .to contain_exactly('foo.rb', 'test.rb')
+        expect(examples_configuration['Include']).to contain_exactly('bar.rb', 'another_test.rb')
+        expect(examples_configuration['AllowedIdentifiers'])
+          .to contain_exactly(*%w[capture3 iso8601 rfc1123_date rfc2822 rfc3339 rfc822 iso2])
+      end
+    end
+
+    context 'when a department is enabled in the top directory and disabled in a subdirectory' do
+      let(:file_path) { '.rubocop.yml' }
+      let(:configuration_from_subdir) do
+        described_class.configuration_from_file('subdir/.rubocop.yml')
+      end
+
+      before do
+        stub_const('RuboCop::ConfigLoader::RUBOCOP_HOME', 'rubocop')
+        stub_const('RuboCop::ConfigLoader::DEFAULT_FILE',
+                   File.join('rubocop', 'config', 'default.yml'))
+
+        create_file('rubocop/config/default.yml', <<~YAML)
+          Layout/SomeCop:
+            Enabled: pending
+        YAML
+        create_file(file_path, <<~YAML)
+          Layout:
+            Enabled: true
+        YAML
+        create_file('subdir/.rubocop.yml', <<~YAML)
+          Layout:
+            Enabled: false
+        YAML
+      end
+
+      it 'does not disable pending cops of that department in the top directory' do
+        # The cop is disabled in subdir because its department is disabled there.
+        subdir_configuration = configuration_from_subdir.for_cop('Layout/SomeCop')
+        expect(subdir_configuration['Enabled']).to be(false)
+
+        # The disabling of the cop in subdir should not leak into the top directory.
+        examples_configuration = configuration_from_file.for_cop('Layout/SomeCop')
+        expect(examples_configuration['Enabled']).to eq('pending')
+      end
+    end
+
+    context 'when a department is disabled', :restore_registry do
+      let(:file_path) { '.rubocop.yml' }
+
+      shared_examples 'resolves enabled/disabled for all ' \
+                      'cops' do |enabled_by_default, disabled_by_default, custom_dept_to_disable|
+        before { stub_cop_class('RuboCop::Cop::Foo::Bar::Baz') }
+
         it "handles EnabledByDefault: #{enabled_by_default}, " \
-           "DisabledByDefault: #{disabled_by_default}" do
+           "DisabledByDefault: #{disabled_by_default} with disabled #{custom_dept_to_disable}" do
           create_file('grandparent_rubocop.yml', <<~YAML)
+            Naming/FileName:
+              Enabled: pending
+
             Metrics/AbcSize:
               Enabled: true
 
@@ -546,6 +692,9 @@ RSpec.describe RuboCop::ConfigLoader do
 
             Lint:
               Enabled: false
+
+            Foo/Bar/Baz:
+              Enabled: true
           YAML
           create_file('parent_rubocop.yml', <<~YAML)
             inherit_from: grandparent_rubocop.yml
@@ -555,6 +704,12 @@ RSpec.describe RuboCop::ConfigLoader do
 
             Metrics/AbcSize:
               Enabled: false
+
+            Naming:
+              Enabled: false
+
+            #{custom_dept_to_disable}:
+              Enabled: false
           YAML
           create_file(file_path, <<~YAML)
             inherit_from: parent_rubocop.yml
@@ -583,6 +738,15 @@ RSpec.describe RuboCop::ConfigLoader do
             configuration_from_file.for_cop(cop)['Enabled']
           end
 
+          if custom_dept_to_disable == 'Foo'
+            message = <<~'OUTPUT'.chomp
+              unrecognized cop or department Foo found in parent_rubocop.yml
+              Foo is not a department. Use `Foo/Bar`.
+            OUTPUT
+            expect { enabled?('Foo/Bar/Baz') }.to raise_error(RuboCop::ValidationError, message)
+            next
+          end
+
           # Department disabled in parent config, cop enabled in child.
           expect(enabled?('Metrics/MethodLength')).to be(true)
 
@@ -595,8 +759,8 @@ RSpec.describe RuboCop::ConfigLoader do
           # Enabled in grandparent config, department disabled in parent.
           expect(enabled?('Metrics/PerceivedComplexity')).to be(false)
 
-          # Pending in default config, department disabled in grandparent.
-          expect(enabled?('Lint/StructNewOverride')).to be(false)
+          # Pending in grandparent config, department disabled in parent.
+          expect(enabled?('Naming/FileName')).to be(false)
 
           # Department disabled in child config.
           expect(enabled?('Style/Alias')).to be(false)
@@ -607,21 +771,27 @@ RSpec.describe RuboCop::ConfigLoader do
           # Department disabled in grandparent, cop enabled in child config.
           expect(enabled?('Lint/RaiseException')).to be(true)
 
+          # Cop enabled in grandparent, nested department disabled in parent.
+          expect(enabled?('Foo/Bar/Baz')).to be(false)
+
+          # Cop with similar prefix to disabled nested department.
+          expect(enabled?('Foo/BarBaz')).to eq(!disabled_by_default)
+
+          # Cop enabled in default config, department disabled in grandparent.
+          expect(enabled?('Lint/StructNewOverride')).to be(false)
+
           # Cop enabled in default config, but not mentioned in user config.
           expect(enabled?('Bundler/DuplicatedGem')).to eq(!disabled_by_default)
         end
       end
 
-      include_examples 'resolves enabled/disabled for all cops', false, false
-      include_examples 'resolves enabled/disabled for all cops', false, true
-      include_examples 'resolves enabled/disabled for all cops', true, false
+      include_examples 'resolves enabled/disabled for all cops', false, false, 'Foo/Bar'
+      include_examples 'resolves enabled/disabled for all cops', false, true, 'Foo/Bar'
+      include_examples 'resolves enabled/disabled for all cops', true, false, 'Foo/Bar'
+      include_examples 'resolves enabled/disabled for all cops', false, false, 'Foo'
     end
 
-    context 'when a third party require defines a new gem' do
-      around do |example|
-        RuboCop::Cop::Registry.with_temporary_global { example.run }
-      end
-
+    context 'when a third party require defines a new gem', :restore_registry do
       context 'when the gem is not loaded' do
         before do
           create_file('.rubocop.yml', <<~YAML)
@@ -647,7 +817,7 @@ RSpec.describe RuboCop::ConfigLoader do
             module RuboCop
               module Cop
                 module Custom
-                  class Loop < Cop
+                  class Loop < Base
                   end
                 end
               end
@@ -713,12 +883,12 @@ RSpec.describe RuboCop::ConfigLoader do
               default_config['Layout/LineLength']['VersionAdded'],
               'VersionChanged' =>
               default_config['Layout/LineLength']['VersionChanged'],
-              'AutoCorrect' => false,
               'Max' => 77,
               'AllowHeredoc' => true,
               'AllowURI' => true,
               'URISchemes' => %w[http https],
               'IgnoreCopDirectives' => true,
+              'AllowedPatterns' => [],
               'IgnoredPatterns' => []
             },
             'Metrics/MethodLength' => {
@@ -733,12 +903,13 @@ RSpec.describe RuboCop::ConfigLoader do
               'CountComments' => false,
               'Max' => 5,
               'CountAsOne' => [],
+              'AllowedMethods' => [],
+              'IgnoredMethods' => [],
+              'AllowedPatterns' => [],
               'ExcludedMethods' => []
             }
           )
-        expect do
-          expect(configuration_from_file.to_h).to eq(config)
-        end.to output('').to_stderr
+        expect { expect(configuration_from_file.to_h).to eq(config) }.to output('').to_stderr
       end
     end
 
@@ -778,10 +949,10 @@ RSpec.describe RuboCop::ConfigLoader do
         expect do
           expect(configuration_from_file['Metrics/MethodLength']
                    .to_set.superset?(expected.to_set)).to be(true)
-        end.to output(/#{<<~OUTPUT}/).to_stdout
-          .rubocop.yml: Metrics/MethodLength:Enabled overrides the same parameter in normal.yml
+        end.to output(Regexp.new(<<~OUTPUT)).to_stdout
           .rubocop.yml: Metrics/MethodLength:Enabled overrides the same parameter in special.yml
-          .rubocop.yml: Metrics/MethodLength:Max overrides the same parameter in special.yml
+          .rubocop.yml: Metrics/MethodLength:Enabled overrides the same parameter in normal.yml
+          .rubocop.yml: Metrics/MethodLength:Max overrides the same parameter in normal.yml
         OUTPUT
       end
     end
@@ -818,12 +989,12 @@ RSpec.describe RuboCop::ConfigLoader do
               default_config['Layout/LineLength']['VersionAdded'],
               'VersionChanged' =>
               default_config['Layout/LineLength']['VersionChanged'],
-              'AutoCorrect' => false,
               'Max' => 120,             # overridden in line_length.yml
               'AllowHeredoc' => false,  # overridden in rubocop.yml
               'AllowURI' => true,
               'URISchemes' => %w[http https],
               'IgnoreCopDirectives' => true,
+              'AllowedPatterns' => [],
               'IgnoredPatterns' => []
             }
           )
@@ -921,11 +1092,10 @@ RSpec.describe RuboCop::ConfigLoader do
 
       context 'and the gem is globally installed' do
         before do
-          gem_class = Struct.new(:gem_dir)
           %w[gemone gemtwo].each do |gem_name|
-            mock_spec = gem_class.new(File.join(gem_root, gem_name))
-            allow(Gem::Specification).to receive(:find_by_name)
-              .with(gem_name).and_return(mock_spec)
+            mock_spec = double
+            allow(mock_spec).to receive(:gem_dir).and_return(File.join(gem_root, gem_name))
+            allow(Gem::Specification).to receive(:find_by_name).with(gem_name).and_return(mock_spec)
           end
           allow(Gem).to receive(:path).and_return([gem_root])
         end
@@ -951,15 +1121,19 @@ RSpec.describe RuboCop::ConfigLoader do
       end
 
       context 'and the gem is bundled' do
+        let(:gem_one) { double }
+        let(:gem_two) { double }
+
         before do
           require 'bundler'
 
-          specs = {
-            'gemone' => [OpenStruct.new(full_gem_path: File.join(gem_root, 'gemone'))],
-            'gemtwo' => [OpenStruct.new(full_gem_path: File.join(gem_root, 'gemtwo'))]
-          }
+          specs = { 'gemone' => [gem_one], 'gemtwo' => [gem_two] }
 
-          allow(Bundler).to receive(:load).and_return(OpenStruct.new(specs: specs))
+          allow(gem_one).to receive(:full_gem_path).and_return(File.join(gem_root, 'gemone'))
+          allow(gem_two).to receive(:full_gem_path).and_return(File.join(gem_root, 'gemtwo'))
+          result = double
+          allow(result).to receive(:specs).and_return(specs)
+          allow(Bundler).to receive(:load).and_return(result)
         end
 
         it 'returns values from the gem config with local overrides' do
@@ -997,14 +1171,14 @@ RSpec.describe RuboCop::ConfigLoader do
 
         create_file("#{gem_root}/#{gem_name}/default.yml", ["Layout/LineLength:\n    Max: 48"])
 
-        mock_spec = OpenStruct.new(gem_dir: File.join(gem_root, gem_name))
-        allow(Gem::Specification).to receive(:find_by_name)
-          .with(gem_name).and_return(mock_spec)
+        mock_spec = double
+        allow(mock_spec).to receive(:gem_dir).and_return(File.join(gem_root, gem_name))
+        allow(Gem::Specification).to receive(:find_by_name).with(gem_name).and_return(mock_spec)
         allow(Gem).to receive(:path).and_return([gem_root])
       end
 
       after do
-        File.unlink cache_file if File.exist? cache_file
+        FileUtils.rm_rf cache_file
       end
 
       it 'resolves the inherited config' do
@@ -1033,7 +1207,7 @@ RSpec.describe RuboCop::ConfigLoader do
       end
 
       after do
-        File.unlink cache_file if File.exist? cache_file
+        FileUtils.rm_rf cache_file
       end
 
       it 'creates the cached file alongside the owning file' do
@@ -1045,7 +1219,7 @@ RSpec.describe RuboCop::ConfigLoader do
     context 'when a file inherits from a url inheriting from another file' do
       let(:file_path) { '.rubocop.yml' }
       let(:cache_file) { '.rubocop-http---example-com-rubocop-yml' }
-      let(:cache_file_2) { '.rubocop-http---example-com-inherit-yml' }
+      let(:cache_file2) { '.rubocop-http---example-com-inherit-yml' }
 
       before do
         stub_request(:get, %r{example.com/rubocop})
@@ -1058,15 +1232,94 @@ RSpec.describe RuboCop::ConfigLoader do
       end
 
       after do
-        [cache_file, cache_file_2].each do |f|
-          File.unlink f if File.exist? f
+        [cache_file, cache_file2].each do |f|
+          FileUtils.rm_rf f
         end
       end
 
       it 'downloads the inherited file from the same url and caches it' do
         configuration_from_file
         expect(File.exist?(cache_file)).to be true
-        expect(File.exist?(cache_file_2)).to be true
+        expect(File.exist?(cache_file2)).to be true
+      end
+    end
+
+    context 'when a file inherits a configuration that specifies TargetRubyVersion' do
+      let(:file_path) { '.rubocop.yml' }
+      let(:target_ruby_version) { configuration_from_file['AllCops']['TargetRubyVersion'] }
+      let(:default_ruby_version) { RuboCop::TargetRuby::DEFAULT_VERSION }
+
+      before do
+        create_file('.rubocop-parent.yml', <<~YAML)
+          AllCops:
+            TargetRubyVersion: #{inherited_version}
+        YAML
+      end
+
+      context 'when the specified version is current' do
+        before do
+          create_file(file_path, <<~YAML)
+            inherit_from: .rubocop-parent.yml
+          YAML
+        end
+
+        let(:inherited_version) { default_ruby_version }
+
+        it 'sets TargetRubyVersion' do
+          expect(target_ruby_version).to eq(inherited_version)
+        end
+      end
+
+      context 'when the specified version is obsolete' do
+        let(:inherited_version) { '1.9' }
+
+        context 'and it is not overridden' do
+          before do
+            create_file(file_path, <<~YAML)
+              inherit_from: .rubocop-parent.yml
+            YAML
+          end
+
+          it 'raises a validation error' do
+            expect { configuration_from_file }.to raise_error(RuboCop::ValidationError) do |error|
+              expect(error.message).to start_with('RuboCop found unsupported Ruby version 1.9')
+            end
+          end
+        end
+
+        context 'and it is overridden' do
+          before do
+            create_file(file_path, <<~YAML)
+              inherit_from: .rubocop-parent.yml
+
+              AllCops:
+                TargetRubyVersion: #{default_ruby_version}
+            YAML
+          end
+
+          it 'uses the given version' do
+            expect(target_ruby_version).to eq(default_ruby_version)
+          end
+        end
+
+        context 'with deeper nesting' do
+          before do
+            create_file('.rubocop-child.yml', <<~YAML)
+              inherit_from: .rubocop-parent.yml
+            YAML
+
+            create_file('.rubocop.yml', <<~YAML)
+              inherit_from: .rubocop-child.yml
+
+              AllCops:
+                TargetRubyVersion: #{default_ruby_version}
+            YAML
+          end
+
+          it 'uses the given version' do
+            expect(target_ruby_version).to eq(default_ruby_version)
+          end
+        end
       end
     end
 
@@ -1077,9 +1330,7 @@ RSpec.describe RuboCop::ConfigLoader do
 
       let(:file_path) { '.rubocop.yml' }
 
-      before do
-        create_file(file_path, config)
-      end
+      before { create_file(file_path, config) }
 
       context 'when DisabledByDefault is true' do
         let(:config) do
@@ -1092,8 +1343,8 @@ RSpec.describe RuboCop::ConfigLoader do
           YAML
         end
 
-        it 'enables cops that are explicitly in the config file '\
-          'even if they are disabled by default' do
+        it 'enables cops that are explicitly in the config file ' \
+           'even if they are disabled by default' do
           cop_class = RuboCop::Cop::Style::Copyright
           expect(cop_enabled?(cop_class)).to be true
         end
@@ -1145,7 +1396,7 @@ RSpec.describe RuboCop::ConfigLoader do
           expect(cop_enabled?(cop_class)).to be true
         end
 
-        it 'respects cops that are disbled in the config' do
+        it 'respects cops that are disabled in the config' do
           cop_class = RuboCop::Cop::Layout::TrailingWhitespace
           expect(cop_enabled?(cop_class)).to be false
         end
@@ -1234,14 +1485,105 @@ RSpec.describe RuboCop::ConfigLoader do
         end
       end
     end
+
+    context 'when a department is configured without an Enable value specified', :restore_registry do
+      let(:file_path) { '.rubocop.yml' }
+
+      before do
+        create_file('third_party/default.yml', <<~YAML)
+          Custom:
+            Foo: Bar
+        YAML
+
+        stub_cop_class('RuboCop::Cop::Custom::Cop')
+      end
+
+      def cop_enabled?(cop_class)
+        configuration_from_file.for_cop(cop_class).fetch('Enabled')
+      end
+
+      context 'inline' do
+        before do
+          create_file('.rubocop.yml', <<~YAML)
+            AllCops:
+              DisabledByDefault: true
+
+            Custom:
+              Foo: Bar
+
+            Custom/Cop:
+              Enabled: true
+          YAML
+        end
+
+        it 'enables the cop' do
+          expect(cop_enabled?('Custom/Cop')).to be true
+        end
+      end
+
+      context 'via inherit_from' do
+        before do
+          create_file('.rubocop.yml', <<~YAML)
+            inherit_from:
+              - 'third_party/default.yml'
+
+            AllCops:
+              DisabledByDefault: true
+
+            Custom/Cop:
+              Enabled: true
+          YAML
+        end
+
+        it 'enables the cop' do
+          expect(cop_enabled?('Custom/Cop')).to be true
+        end
+      end
+
+      context 'by an extension' do
+        before do
+          create_file('third_party.rb', <<~RUBY)
+            module RuboCop
+              module Custom
+                def self.inject!
+                  path = 'third_party/default.yml'
+
+                  # Injection code currently used in extensions
+                  hash = ConfigLoader.send(:load_yaml_configuration, path)
+                  config = Config.new(hash, path)
+                  config = ConfigLoader.merge_with_default(config, path)
+                  ConfigLoader.instance_variable_set(:@default_configuration, config)
+                end
+              end
+            end
+
+            RuboCop::Custom.inject!
+          RUBY
+
+          create_file('.rubocop.yml', <<~YAML)
+            require:
+              - ./third_party.rb
+
+            AllCops:
+              DisabledByDefault: true
+
+            Custom/Cop:
+              Enabled: true
+          YAML
+        end
+
+        it 'enables the cop' do
+          expect(cop_enabled?('Custom/Cop')).to be true
+        end
+      end
+    end
   end
 
   describe '.load_file', :isolated_environment do
-    subject(:load_file) do
-      described_class.load_file(configuration_path)
-    end
+    subject(:load_file) { described_class.load_file(configuration_path, check: check) }
 
     let(:configuration_path) { '.rubocop.yml' }
+    let(:check) { true }
 
     it 'returns a configuration loaded from the passed path' do
       create_file(configuration_path, <<~YAML)
@@ -1249,9 +1591,7 @@ RSpec.describe RuboCop::ConfigLoader do
           Enabled: true
       YAML
       configuration = load_file
-      expect(configuration['Style/Encoding']).to eq(
-        'Enabled' => true
-      )
+      expect(configuration['Style/Encoding']).to eq('Enabled' => true)
     end
 
     it 'does ERB pre-processing of the configuration file' do
@@ -1280,8 +1620,7 @@ RSpec.describe RuboCop::ConfigLoader do
           <% end %>
       YAML
       configuration = described_class.load_file('dir/.rubocop.yml')
-      expect(configuration['Style/Encoding'])
-        .to eq('Exclude' => [abs('dir/c.rb')])
+      expect(configuration['Style/Encoding']).to eq('Exclude' => [abs('dir/c.rb')])
     end
 
     it 'fails with a TypeError when loading a malformed configuration file' do
@@ -1291,7 +1630,7 @@ RSpec.describe RuboCop::ConfigLoader do
       )
     end
 
-    it 'loads configuration properly when it includes non-ascii characters ' do
+    it 'loads configuration properly when it includes non-ascii characters' do
       create_file(configuration_path, <<~YAML)
         # All these cops of mine are ❤
         Style/Encoding:
@@ -1307,51 +1646,6 @@ RSpec.describe RuboCop::ConfigLoader do
       expect(configuration.to_h).to eq({})
     end
 
-    context 'when SafeYAML is required' do
-      before do
-        create_file(configuration_path, <<~YAML)
-          Style/WordArray:
-            WordRegex: !ruby/regexp '/\\A[\\p{Word}]+\\z/'
-        YAML
-      end
-
-      context 'when it is fully required', broken_on: :ruby_head do
-        it 'de-serializes Regexp class' do
-          in_its_own_process_with('safe_yaml') do
-            configuration = described_class.load_file('.rubocop.yml')
-
-            word_regexp = configuration['Style/WordArray']['WordRegex']
-            expect(word_regexp.is_a?(::Regexp)).to be(true)
-          end
-        end
-      end
-
-      context 'when safe_yaml is required without monkey patching', broken_on: :ruby_head do
-        it 'de-serializes Regexp class' do
-          in_its_own_process_with('safe_yaml/load') do
-            configuration = described_class.load_file('.rubocop.yml')
-
-            word_regexp = configuration['Style/WordArray']['WordRegex']
-            expect(word_regexp.is_a?(::Regexp)).to be(true)
-          end
-        end
-
-        context 'and SafeYAML.load is private' do
-          # According to issue #2935, SafeYAML.load can be private in some
-          # circumstances.
-          it 'does not raise private method load called for SafeYAML:Module' do
-            in_its_own_process_with('safe_yaml/load') do
-              SafeYAML.send :private_class_method, :load
-              configuration = described_class.load_file('.rubocop.yml')
-
-              word_regexp = configuration['Style/WordArray']['WordRegex']
-              expect(word_regexp.is_a?(::Regexp)).to be(true)
-            end
-          end
-        end
-      end
-    end
-
     context 'set neither true nor false to value to Enabled' do
       before do
         create_file(configuration_path, <<~YAML)
@@ -1400,38 +1694,42 @@ RSpec.describe RuboCop::ConfigLoader do
       end
     end
 
-    context '< Ruby 2.5', if: RUBY_VERSION < '2.5' do
-      context 'when the file has duplicated keys' do
-        it 'outputs a warning' do
-          create_file(configuration_path, <<~YAML)
-            Style/Encoding:
-              Enabled: true
+    context 'when the file has duplicated keys' do
+      it 'outputs a warning' do
+        create_file(configuration_path, <<~YAML)
+          Style/Encoding:
+            Enabled: true
 
-            Style/Encoding:
-              Enabled: false
-          YAML
+          Style/Encoding:
+            Enabled: false
+        YAML
 
-          expect do
-            load_file
-          end.to output(%r{`Style/Encoding` is concealed by duplicat}).to_stderr
-        end
+        expect { load_file }.to output(%r{`Style/Encoding` is concealed by line 4}).to_stderr
       end
     end
 
-    context '>= Ruby 2.5', if: RUBY_VERSION >= '2.5' do
-      context 'when the file has duplicated keys' do
-        it 'outputs a warning' do
-          create_file(configuration_path, <<~YAML)
-            Style/Encoding:
-              Enabled: true
+    context 'when the config file contains an obsolete config' do
+      before do
+        create_file(configuration_path, <<~YAML)
+          Style/MethodMissing:
+            Enabled: true
+        YAML
+      end
 
-            Style/Encoding:
-              Enabled: false
-          YAML
+      context 'and check is true' do
+        it 'raises an error' do
+          expect { load_file }.to raise_error(
+            RuboCop::ValidationError,
+            %r{`Style/MethodMissing` cop has been split}
+          )
+        end
+      end
 
-          expect do
-            load_file
-          end.to output(%r{`Style/Encoding` is concealed by line 4}).to_stderr
+      context 'and check is false' do
+        let(:check) { false }
+
+        it 'does not raise an error' do
+          expect { load_file }.not_to raise_error
         end
       end
     end
@@ -1448,9 +1746,7 @@ RSpec.describe RuboCop::ConfigLoader do
         }
       }
     end
-    let(:derived) do
-      { 'AllCops' => { 'Exclude' => ['example.rb', 'exclude_*'] } }
-    end
+    let(:derived) { { 'AllCops' => { 'Exclude' => ['example.rb', 'exclude_*'] } } }
 
     it 'returns a recursive merge of its two arguments' do
       expect(merge).to eq('AllCops' => {
@@ -1468,8 +1764,7 @@ RSpec.describe RuboCop::ConfigLoader do
       described_class.configuration_from_file(config_path)
     end
 
-    context 'when .rubocop.yml inherits from a file with a name starting ' \
-            'with .rubocop' do
+    context 'when .rubocop.yml inherits from a file with a name starting with .rubocop' do
       before do
         create_file('test/.rubocop_rules.yml', <<~YAML)
           Style/CharacterLiteral:
@@ -1479,20 +1774,49 @@ RSpec.describe RuboCop::ConfigLoader do
         create_file('test/.rubocop.yml', 'inherit_from: .rubocop_rules.yml')
       end
 
-      it 'gets an Exclude relative to the inherited file converted to ' \
-         'absolute' do
+      it 'gets an Exclude relative to the inherited file converted to absolute' do
         expect(config.for_cop(RuboCop::Cop::Style::CharacterLiteral)['Exclude'])
           .to eq([File.join(Dir.pwd, 'test/blargh/blah.rb')])
       end
     end
   end
 
+  describe 'when pending cops exist', :isolated_environment do
+    subject(:from_file) { described_class.configuration_from_file('.rubocop.yml') }
+
+    before do
+      create_empty_file('.rubocop.yml')
+
+      # Setup similar to https://github.com/rubocop/rubocop-rspec/blob/master/lib/rubocop/rspec/inject.rb#L16
+      # and https://github.com/runtastic/rt_rubocop_defaults/blob/master/lib/rt_rubocop_defaults/inject.rb#L21
+      config = RuboCop::Config.new(parent_config)
+      described_class.instance_variable_set(:@default_configuration, config)
+    end
+
+    context 'when NewCops is set in a required file' do
+      let(:parent_config) { { 'AllCops' => { 'NewCops' => 'enable' } } }
+
+      it 'does not print a warning' do
+        expect(described_class).not_to receive(:warn_on_pending_cops)
+        from_file
+      end
+    end
+
+    context 'when NewCops is not configured in a required file' do
+      let(:parent_config) { { 'AllCops' => { 'Exclude:' => ['coverage/**/*'] } } }
+
+      it 'prints a warning' do
+        expect(described_class).to receive(:warn_on_pending_cops)
+        from_file
+      end
+    end
+  end
+
   describe 'configuration for AssignmentInCondition' do
     describe 'AllowSafeAssignment' do
       it 'is enabled by default' do
         default_config = described_class.default_configuration
-        symbol_name_config =
-          default_config.for_cop('Lint/AssignmentInCondition')
+        symbol_name_config = default_config.for_cop('Lint/AssignmentInCondition')
         expect(symbol_name_config['AllowSafeAssignment']).to be_truthy
       end
     end
