@@ -26,23 +26,66 @@ RSpec.describe RuboCop::Config do
         $stderr = StringIO.new
       end
 
-      after do
-        $stderr = STDERR
-      end
+      after { $stderr = STDERR }
 
       it 'raises an validation error' do
         expect { configuration }.to raise_error(
           RuboCop::ValidationError,
-          'unrecognized cop LyneLenth found in .rubocop.yml'
+          'unrecognized cop or department LyneLenth found in .rubocop.yml'
         )
       end
     end
 
-    context 'when the configuration includes an empty section' do
-      before do
-        create_file(configuration_path, ['Layout/LineLength:'])
+    context 'when the configuration includes any unrecognized cop name and given `--ignore-unrecognized-cops` option' do
+      context 'there is unrecognized cop' do
+        before do
+          create_file(configuration_path, <<~YAML)
+            LyneLenth:
+              Enabled: true
+              Max: 100
+          YAML
+          RuboCop::ConfigLoader.ignore_unrecognized_cops = true
+          $stderr = StringIO.new
+        end
+
+        after do
+          RuboCop::ConfigLoader.ignore_unrecognized_cops = nil
+          $stderr = STDERR
+        end
+
+        it 'prints a warning about the cop' do
+          configuration
+          expect($stderr.string)
+            .to eq("The following cops or departments are not recognized and will be ignored:\n" \
+                   "unrecognized cop or department LyneLenth found in .rubocop.yml\n")
+        end
       end
 
+      context 'there are no unrecognized cops' do
+        before do
+          create_file(configuration_path, <<~YAML)
+            Layout/LineLength:
+              Enabled: true
+          YAML
+          RuboCop::ConfigLoader.ignore_unrecognized_cops = true
+          $stderr = StringIO.new
+        end
+
+        after do
+          RuboCop::ConfigLoader.ignore_unrecognized_cops = nil
+          $stderr = STDERR
+        end
+
+        it 'does not print any warnings' do
+          configuration
+          expect($stderr.string).to eq('')
+        end
+      end
+    end
+
+    context 'when the configuration includes an empty section' do
+      before { create_file(configuration_path, ['Layout/LineLength:']) }
+
       it 'raises validation error' do
         expect { configuration.validate }
           .to raise_error(RuboCop::ValidationError,
@@ -51,9 +94,7 @@ RSpec.describe RuboCop::Config do
     end
 
     context 'when the empty section is AllCops' do
-      before do
-        create_file(configuration_path, ['AllCops:'])
-      end
+      before { create_file(configuration_path, ['AllCops:']) }
 
       it 'raises validation error' do
         expect { configuration.validate }
@@ -88,15 +129,11 @@ RSpec.describe RuboCop::Config do
         $stderr = StringIO.new
       end
 
-      after do
-        $stderr = STDERR
-      end
+      after { $stderr = STDERR }
 
       it 'prints a warning message' do
         configuration # ConfigLoader.load_file will validate config
-        expect($stderr.string).to match(
-          %r{Layout/LineLength does not support Min parameter.}
-        )
+        expect($stderr.string).to match(%r{Layout/LineLength does not support Min parameter.})
       end
     end
 
@@ -145,8 +182,7 @@ RSpec.describe RuboCop::Config do
       end
 
       it 'raises validation error' do
-        expect { configuration.validate }
-          .to raise_error(RuboCop::ValidationError, /itisinvalid/)
+        expect { configuration.validate }.to raise_error(RuboCop::ValidationError, /itisinvalid/)
       end
     end
 
@@ -172,8 +208,7 @@ RSpec.describe RuboCop::Config do
       end
 
       it 'raises validation error' do
-        expect { configuration.validate }
-          .to raise_error(RuboCop::ValidationError, /itisinvalid/)
+        expect { configuration.validate }.to raise_error(RuboCop::ValidationError, /itisinvalid/)
       end
     end
 
@@ -192,7 +227,7 @@ RSpec.describe RuboCop::Config do
       end
     end
 
-    context 'when the configuration includes multiple valid enforced styles '\
+    context 'when the configuration includes multiple valid enforced styles ' \
             'and one invalid style' do
       before do
         create_file(configuration_path, <<~YAML)
@@ -204,13 +239,11 @@ RSpec.describe RuboCop::Config do
       end
 
       it 'raises validation error' do
-        expect { configuration.validate }
-          .to raise_error(RuboCop::ValidationError, /trailing_comma/)
+        expect { configuration.validate }.to raise_error(RuboCop::ValidationError, /trailing_comma/)
       end
     end
 
-    context 'when the configuration includes multiple '\
-            'but config does not allow' do
+    context 'when the configuration includes multiple but config does not allow' do
       before do
         create_file(configuration_path, <<~YAML)
           Layout/SpaceAroundBlockParameters:
@@ -220,8 +253,7 @@ RSpec.describe RuboCop::Config do
       end
 
       it 'raises validation error' do
-        expect { configuration.validate }
-          .to raise_error(RuboCop::ValidationError, /space/)
+        expect { configuration.validate }.to raise_error(RuboCop::ValidationError, /space/)
       end
     end
 
@@ -236,8 +268,7 @@ RSpec.describe RuboCop::Config do
       end
 
       it 'raises validation error' do
-        expect { configuration.validate }
-          .to raise_error(RuboCop::ValidationError, /itisinvalid/)
+        expect { configuration.validate }.to raise_error(RuboCop::ValidationError, /itisinvalid/)
       end
     end
 
@@ -265,13 +296,11 @@ RSpec.describe RuboCop::Config do
       end
 
       it 'raises validation error' do
-        expect { configuration.validate }
-          .to raise_error(RuboCop::ValidationError, /EnforcedStyle/)
+        expect { configuration.validate }.to raise_error(RuboCop::ValidationError, /EnforcedStyle/)
       end
     end
 
-    context 'when the configuration includes an obsolete EnforcedStyle ' \
-            'parameter' do
+    context 'when the configuration includes an obsolete EnforcedStyle parameter' do
       before do
         create_file(configuration_path, <<~YAML)
           Layout/IndentationConsistency:
@@ -304,10 +333,8 @@ RSpec.describe RuboCop::Config do
       end
     end
 
-    include_examples 'obsolete MaxLineLength parameter',
-                     'Style/WhileUntilModifier'
-    include_examples 'obsolete MaxLineLength parameter',
-                     'Style/IfUnlessModifier'
+    include_examples 'obsolete MaxLineLength parameter', 'Style/WhileUntilModifier'
+    include_examples 'obsolete MaxLineLength parameter', 'Style/IfUnlessModifier'
 
     context 'when the configuration includes obsolete parameters and cops' do
       before do
@@ -330,8 +357,7 @@ RSpec.describe RuboCop::Config do
             message.include?('EnforcedStyleAlignWith') &&
             message.include?('Layout/SpaceAroundKeyword')
         end
-        expect { configuration.validate }
-          .to raise_error(RuboCop::ValidationError, message_matcher)
+        expect { configuration.validate }.to raise_error(RuboCop::ValidationError, message_matcher)
       end
     end
 
@@ -392,7 +418,7 @@ RSpec.describe RuboCop::Config do
 
     describe 'conflicting Safe settings' do
       context 'when the configuration includes an unsafe cop that is ' \
-              'explicitly declared to have a safe auto-correction' do
+              'explicitly declared to have a safe autocorrection' do
         before do
           create_file(configuration_path, <<~YAML)
             Style/PreferredHashMethods:
@@ -405,13 +431,13 @@ RSpec.describe RuboCop::Config do
           expect { configuration.validate }
             .to raise_error(
               RuboCop::ValidationError,
-              /Unsafe cops cannot have a safe auto-correction/
+              /Unsafe cops cannot have a safe autocorrection/
             )
         end
       end
 
       context 'when the configuration includes an unsafe cop without ' \
-              'a declaration of its auto-correction' do
+              'a declaration of its autocorrection' do
         before do
           create_file(configuration_path, <<~YAML)
             Style/PreferredHashMethods:
@@ -428,16 +454,7 @@ RSpec.describe RuboCop::Config do
 
   describe '#make_excludes_absolute' do
     context 'when config is in root directory' do
-      let(:hash) do
-        {
-          'AllCops' => {
-            'Exclude' => [
-              'config/environment',
-              'spec'
-            ]
-          }
-        }
-      end
+      let(:hash) { { 'AllCops' => { 'Exclude' => ['config/environment', 'spec'] } } }
 
       before do
         allow(configuration)
@@ -447,13 +464,8 @@ RSpec.describe RuboCop::Config do
       end
 
       it 'generates valid absolute directory' do
-        excludes = configuration['AllCops']['Exclude']
-                   .map { |e| e.sub(/^[A-Z]:/i, '') }
-        expect(excludes)
-          .to eq [
-            '/home/foo/project/config/environment',
-            '/home/foo/project/spec'
-          ]
+        excludes = configuration['AllCops']['Exclude'].map { |e| e.sub(/^[A-Z]:/i, '') }
+        expect(excludes).to eq ['/home/foo/project/config/environment', '/home/foo/project/spec']
       end
     end
 
@@ -477,25 +489,14 @@ RSpec.describe RuboCop::Config do
       end
 
       it 'generates valid absolute directory' do
-        excludes = configuration['AllCops']['Exclude']
-                   .map { |e| e.sub(/^[A-Z]:/i, '') }
-        expect(excludes)
-          .to eq [
-            '/home/foo/project/config/environment',
-            '/home/foo/project/spec'
-          ]
+        excludes = configuration['AllCops']['Exclude'].map { |e| e.sub(/^[A-Z]:/i, '') }
+        expect(excludes).to eq ['/home/foo/project/config/environment', '/home/foo/project/spec']
       end
     end
   end
 
   describe '#file_to_include?' do
-    let(:hash) do
-      {
-        'AllCops' => {
-          'Include' => ['**/Gemfile', 'config/unicorn.rb.example']
-        }
-      }
-    end
+    let(:hash) { { 'AllCops' => { 'Include' => ['**/Gemfile', 'config/unicorn.rb.example'] } } }
 
     let(:loaded_path) { '/home/foo/project/.rubocop.yml' }
 
@@ -519,16 +520,7 @@ RSpec.describe RuboCop::Config do
 
     after { $stderr = STDERR }
 
-    let(:hash) do
-      {
-        'AllCops' => {
-          'Exclude' => [
-            "#{Dir.pwd}/log/**/*",
-            '**/bar.rb'
-          ]
-        }
-      }
-    end
+    let(:hash) { { 'AllCops' => { 'Exclude' => ["#{Dir.pwd}/log/**/*", '**/bar.rb'] } } }
 
     let(:loaded_path) { '/home/foo/project/.rubocop.yml' }
 
@@ -558,23 +550,15 @@ RSpec.describe RuboCop::Config do
   describe '#allowed_camel_case_file?' do
     subject { configuration.allowed_camel_case_file?(file_path) }
 
-    let(:hash) do
-      {
-        'AllCops' => {
-          'Include' => ['**/Gemfile']
-        }
-      }
-    end
+    let(:hash) { { 'AllCops' => { 'Include' => ['**/Gemfile'] } } }
 
-    context 'when the passed path matches allowed camel case patterns ' \
-            'to include' do
+    context 'when the passed path matches allowed camel case patterns to include' do
       let(:file_path) { '/home/foo/project/Gemfile' }
 
       it { is_expected.to be true }
     end
 
-    context 'when the passed path does not match allowed camel case patterns ' \
-            'to include' do
+    context 'when the passed path does not match allowed camel case patterns to include' do
       let(:file_path) { '/home/foo/project/testCase' }
 
       it { is_expected.to be false }
@@ -605,25 +589,18 @@ RSpec.describe RuboCop::Config do
       end
 
       it 'returns the Include value' do
-        expect(patterns_to_include).to eq([
-                                            '**/Gemfile',
-                                            'config/unicorn.rb.example'
-                                          ])
+        expect(patterns_to_include).to eq(['**/Gemfile', 'config/unicorn.rb.example'])
       end
     end
   end
 
   describe '#possibly_include_hidden?' do
-    subject(:configuration) do
-      described_class.new(hash, loaded_path)
-    end
+    subject(:configuration) { described_class.new(hash, loaded_path) }
 
     let(:loaded_path) { 'example/.rubocop.yml' }
 
     it 'returns true when Include config only includes regular paths' do
-      configuration['AllCops'] = {
-        'Include' => ['**/Gemfile', 'config/unicorn.rb.example']
-      }
+      configuration['AllCops'] = { 'Include' => ['**/Gemfile', 'config/unicorn.rb.example'] }
 
       expect(configuration.possibly_include_hidden?).to be(false)
     end
@@ -656,13 +633,7 @@ RSpec.describe RuboCop::Config do
     let(:loaded_path) { 'example/.rubocop.yml' }
 
     context 'when config file has AllCops => Exclude key' do
-      let(:hash) do
-        {
-          'AllCops' => {
-            'Exclude' => ['log/*']
-          }
-        }
-      end
+      let(:hash) { { 'AllCops' => { 'Exclude' => ['log/*'] } } }
 
       it 'returns the Exclude value' do
         expect(patterns_to_exclude).to eq(['log/*'])
@@ -671,9 +642,7 @@ RSpec.describe RuboCop::Config do
   end
 
   describe '#check' do
-    subject(:configuration) do
-      described_class.new(hash, loaded_path)
-    end
+    subject(:configuration) { described_class.new(hash, loaded_path) }
 
     let(:loaded_path) { 'example/.rubocop.yml' }
 
@@ -686,9 +655,7 @@ RSpec.describe RuboCop::Config do
 
       it 'prints a warning message for the loaded path' do
         configuration.check
-        expect($stderr.string).to include(
-          "#{loaded_path} - AllCops/Includes was renamed"
-        )
+        expect($stderr.string).to include("#{loaded_path} - AllCops/Includes was renamed")
       end
     end
   end
@@ -707,9 +674,7 @@ RSpec.describe RuboCop::Config do
         let(:hash) { { 'AllCops' => { 'Exclude' => [], 'Include' => [] } } }
 
         it 'does not yield' do
-          expect do |b|
-            configuration.deprecation_check(&b)
-          end.not_to yield_control
+          expect { |b| configuration.deprecation_check(&b) }.not_to yield_control
         end
       end
 
@@ -717,9 +682,7 @@ RSpec.describe RuboCop::Config do
         let(:hash) { { 'AllCops' => { 'Includes' => [] } } }
 
         it 'yields' do
-          expect do |b|
-            configuration.deprecation_check(&b)
-          end.to yield_with_args(String)
+          expect { |b| configuration.deprecation_check(&b) }.to yield_with_args(String)
         end
       end
 
@@ -727,9 +690,7 @@ RSpec.describe RuboCop::Config do
         let(:hash) { { 'AllCops' => { 'Excludes' => [] } } }
 
         it 'yields' do
-          expect do |b|
-            configuration.deprecation_check(&b)
-          end.to yield_with_args(String)
+          expect { |b| configuration.deprecation_check(&b) }.to yield_with_args(String)
         end
       end
     end
@@ -774,8 +735,33 @@ RSpec.describe RuboCop::Config do
           }
         end
 
-        it 'still disables the cop' do
+        it 'the cop setting overrides the department' do
           cop_class = RuboCop::Cop::Layout::TrailingWhitespace
+          expect(cop_enabled(cop_class)).to be true
+        end
+      end
+    end
+
+    context 'when an nested cop department is disabled' do
+      context 'but an individual cop is enabled' do
+        let(:hash) do
+          {
+            'Foo/Bar' => { 'Enabled' => false },
+            'Foo/Bar/BazCop' => { 'Enabled' => true }
+          }
+        end
+
+        it 'the cop setting overrides the department' do
+          cop_class = 'Foo/Bar/BazCop'
+          expect(cop_enabled(cop_class)).to be true
+        end
+      end
+
+      context 'and an individual cop is not specified' do
+        let(:hash) { { 'Foo/Bar' => { 'Enabled' => false } } }
+
+        it 'the cop setting overrides the department' do
+          cop_class = 'Foo/Bar/BazCop'
           expect(cop_enabled(cop_class)).to be false
         end
       end
@@ -798,11 +784,7 @@ RSpec.describe RuboCop::Config do
     end
 
     context 'when a cop has configuration but no explicit Enabled setting' do
-      let(:hash) do
-        {
-          'Layout/TrailingWhitespace' => { 'Exclude' => ['foo'] }
-        }
-      end
+      let(:hash) { { 'Layout/TrailingWhitespace' => { 'Exclude' => ['foo'] } } }
 
       it 'enables the cop by default' do
         cop_class = RuboCop::Cop::Layout::TrailingWhitespace
@@ -811,20 +793,14 @@ RSpec.describe RuboCop::Config do
     end
 
     context 'when configuration has no mention of a cop' do
-      let(:hash) do
-        {}
-      end
+      let(:hash) { {} }
 
       it 'enables the cop that is not mentioned' do
         expect(cop_enabled('VeryCustomDepartment/CustomCop')).to be true
       end
 
       context 'when all cops are disabled by default' do
-        let(:hash) do
-          {
-            'AllCops' => { 'DisabledByDefault' => true }
-          }
-        end
+        let(:hash) { { 'AllCops' => { 'DisabledByDefault' => true } } }
 
         it 'disables the cop that is not mentioned' do
           expect(cop_enabled('VeryCustomDepartment/CustomCop')).to be false
@@ -832,11 +808,7 @@ RSpec.describe RuboCop::Config do
       end
 
       context 'when all cops are explicitly enabled by default' do
-        let(:hash) do
-          {
-            'AllCops' => { 'EnabledByDefault' => true }
-          }
-        end
+        let(:hash) { { 'AllCops' => { 'EnabledByDefault' => true } } }
 
         it 'enables the cop that is not mentioned' do
           expect(cop_enabled('VeryCustomDepartment/CustomCop')).to be true
@@ -845,7 +817,7 @@ RSpec.describe RuboCop::Config do
     end
   end
 
-  describe '#for_department' do
+  describe '#for_department', :restore_registry do
     let(:hash) do
       {
         'Foo' => { 'Bar' => 42, 'Baz' => true },
@@ -853,15 +825,7 @@ RSpec.describe RuboCop::Config do
       }
     end
 
-    around do |test|
-      RuboCop::Cop::Registry.with_temporary_global do
-        test.run
-      end
-    end
-
-    before do
-      stub_const('RuboCop::Foo::Foo', Class.new(RuboCop::Cop::Base))
-    end
+    before { stub_cop_class('RuboCop::Foo::Foo') }
 
     it "always returns the department's config" do
       expect(configuration.for_department('Foo')).to eq hash['Foo']
