@@ -1,8 +1,6 @@
 # frozen_string_literal: true
 
-RSpec.describe RuboCop::Cop::Layout::ArgumentAlignment do
-  subject(:cop) { described_class.new(config) }
-
+RSpec.describe RuboCop::Cop::Layout::ArgumentAlignment, :config do
   let(:config) do
     RuboCop::Config.new('Layout/ArgumentAlignment' => cop_config,
                         'Layout/IndentationWidth' => {
@@ -12,11 +10,7 @@ RSpec.describe RuboCop::Cop::Layout::ArgumentAlignment do
   let(:indentation_width) { 2 }
 
   context 'aligned with first argument' do
-    let(:cop_config) do
-      {
-        'EnforcedStyle' => 'with_first_argument'
-      }
-    end
+    let(:cop_config) { { 'EnforcedStyle' => 'with_first_argument' } }
 
     it 'registers an offense and corrects arguments with single indent' do
       expect_offense(<<~RUBY)
@@ -31,7 +25,7 @@ RSpec.describe RuboCop::Cop::Layout::ArgumentAlignment do
       RUBY
     end
 
-    it 'registers an offense and corrects multiline missed indendation' do
+    it 'registers an offense and corrects multiline missed indentation' do
       expect_offense(<<~RUBY)
         func(a,
                b,
@@ -94,6 +88,31 @@ RSpec.describe RuboCop::Cop::Layout::ArgumentAlignment do
       RUBY
     end
 
+    it 'registers an offense and corrects when missed indentation kwargs' do
+      expect_offense(<<~RUBY)
+        func1(foo: 'foo',
+          bar: 'bar',
+          ^^^^^^^^^^ Align the arguments of a method call if they span more than one line.
+          baz: 'baz')
+          ^^^^^^^^^^ Align the arguments of a method call if they span more than one line.
+        func2(do_something,
+          foo: 'foo',
+          ^^^^^^^^^^^ Align the arguments of a method call if they span more than one line.
+          bar: 'bar',
+          baz: 'baz')
+      RUBY
+
+      expect_correction(<<~RUBY)
+        func1(foo: 'foo',
+              bar: 'bar',
+              baz: 'baz')
+        func2(do_something,
+              foo: 'foo',
+              bar: 'bar',
+              baz: 'baz')
+      RUBY
+    end
+
     it 'registers an offense and corrects splat operator' do
       expect_offense(<<~RUBY)
         func1(*a,
@@ -244,19 +263,23 @@ RSpec.describe RuboCop::Cop::Layout::ArgumentAlignment do
 
     it "doesn't crash and burn when there are nested issues" do
       # regression test; see GH issue 2441
-      src = <<~RUBY
-        build(:house,
-          :rooms => [
-            build(:bedroom,
-              :bed => build(:bed,
-                :occupants => [],
-                :size => "king"
+      expect do
+        expect_offense(<<~RUBY)
+          build(:house,
+            :rooms => [
+            ^^^^^^^^^^^ Align the arguments of a method call if they span more than one line.
+              build(:bedroom,
+                :bed => build(:bed,
+                ^^^^^^^^^^^^^^^^^^^ Align the arguments of a method call if they span more than one line.
+                  :occupants => [],
+                  ^^^^^^^^^^^^^^^^^ Align the arguments of a method call if they span more than one line.
+                  :size => "king"
+                )
               )
-            )
-          ]
-        )
-      RUBY
-      expect { inspect_source(src) }.not_to raise_error
+            ]
+          )
+        RUBY
+      end.not_to raise_error
     end
 
     context 'assigned methods' do
@@ -297,8 +320,7 @@ RSpec.describe RuboCop::Cop::Layout::ArgumentAlignment do
       RUBY
     end
 
-    it 'registers an offense and correct multi-line parameters' \
-      'indented too far' do
+    it 'registers an offense and correct multi-line parametersindented too far' do
       expect_offense(<<~RUBY)
         create :transaction, :closed,
                  account:          account,
@@ -353,28 +375,17 @@ RSpec.describe RuboCop::Cop::Layout::ArgumentAlignment do
   end
 
   context 'aligned with fixed indentation' do
-    let(:cop_config) do
-      {
-        'EnforcedStyle' => 'with_fixed_indentation'
-      }
-    end
-
-    let(:correct_source) do
-      <<~RUBY
-        create :transaction, :closed,
-          account:     account,
-          open_price:  1.29,
-          close_price: 1.30
-      RUBY
-    end
+    let(:cop_config) { { 'EnforcedStyle' => 'with_fixed_indentation' } }
 
     it 'autocorrects by outdenting when indented too far' do
       expect_offense(<<~RUBY)
         create :transaction, :closed,
                account:     account,
-               ^^^^^^^^^^^^^^^^^^^^^ Use one level of indentation for arguments following the first line of a multi-line method call.
+               ^^^^^^^^^^^^^^^^^^^^ Use one level of indentation for arguments following the first line of a multi-line method call.
                open_price:  1.29,
+               ^^^^^^^^^^^^^^^^^ Use one level of indentation for arguments following the first line of a multi-line method call.
                close_price: 1.30
+               ^^^^^^^^^^^^^^^^^ Use one level of indentation for arguments following the first line of a multi-line method call.
       RUBY
 
       expect_correction(<<~RUBY)
@@ -389,9 +400,11 @@ RSpec.describe RuboCop::Cop::Layout::ArgumentAlignment do
       expect_offense(<<~RUBY)
         create :transaction, :closed,
         account:     account,
-        ^^^^^^^^^^^^^^^^^^^^^ Use one level of indentation for arguments following the first line of a multi-line method call.
+        ^^^^^^^^^^^^^^^^^^^^ Use one level of indentation for arguments following the first line of a multi-line method call.
         open_price:  1.29,
+        ^^^^^^^^^^^^^^^^^ Use one level of indentation for arguments following the first line of a multi-line method call.
         close_price: 1.30
+        ^^^^^^^^^^^^^^^^^ Use one level of indentation for arguments following the first line of a multi-line method call.
       RUBY
 
       expect_correction(<<~RUBY)
@@ -402,13 +415,58 @@ RSpec.describe RuboCop::Cop::Layout::ArgumentAlignment do
       RUBY
     end
 
+    it 'registers an offense and corrects when missed indentation kwargs' do
+      expect_offense(<<~RUBY)
+        func1(foo: 'foo',
+              bar: 'bar',
+              ^^^^^^^^^^ Use one level of indentation for arguments following the first line of a multi-line method call.
+              baz: 'baz')
+              ^^^^^^^^^^ Use one level of indentation for arguments following the first line of a multi-line method call.
+        func2(do_something,
+              foo: 'foo',
+              ^^^^^^^^^^ Use one level of indentation for arguments following the first line of a multi-line method call.
+              bar: 'bar',
+              ^^^^^^^^^^ Use one level of indentation for arguments following the first line of a multi-line method call.
+              baz: 'baz')
+              ^^^^^^^^^^ Use one level of indentation for arguments following the first line of a multi-line method call.
+      RUBY
+
+      expect_correction(<<~RUBY)
+        func1(foo: 'foo',
+          bar: 'bar',
+          baz: 'baz')
+        func2(do_something,
+          foo: 'foo',
+          bar: 'bar',
+          baz: 'baz')
+      RUBY
+    end
+
+    it 'corrects indentation for kwargs starting on same line as other args' do
+      expect_offense(<<~RUBY)
+        func(do_something, foo: 'foo',
+                           bar: 'bar',
+                           ^^^^^^^^^^ Use one level of indentation for arguments following the first line of a multi-line method call.
+                           baz: 'baz')
+                           ^^^^^^^^^^ Use one level of indentation for arguments following the first line of a multi-line method call.
+      RUBY
+
+      expect_correction(<<~RUBY)
+        func(do_something, foo: 'foo',
+          bar: 'bar',
+          baz: 'baz')
+      RUBY
+    end
+
     it 'autocorrects when first line is indented' do
       expect_offense(<<-RUBY.strip_margin('|'))
         |  create :transaction, :closed,
         |  account:     account,
-        |  ^^^^^^^^^^^^^^^^^^^^^ Use one level of indentation for arguments following the first line of a multi-line method call.
+        |  ^^^^^^^^^^^^^^^^^^^^ Use one level of indentation for arguments following the first line of a multi-line method call.
         |  open_price:  1.29,
+        |  ^^^^^^^^^^^^^^^^^ Use one level of indentation for arguments following the first line of a multi-line method call.
         |  close_price: 1.30
+        |  ^^^^^^^^^^^^^^^^^ Use one level of indentation for arguments following the first line of a multi-line method call.
       RUBY
 
       expect_correction(<<-RUBY.strip_margin('|'))
@@ -431,8 +489,7 @@ RSpec.describe RuboCop::Cop::Layout::ArgumentAlignment do
         RUBY
       end
 
-      it 'registers offenses and corrects double indentation ' \
-        'from relevant method' do
+      it 'registers offenses and corrects double indentation from relevant method' do
         expect_offense(<<~RUBY)
           something
             .method_name(
@@ -561,5 +618,16 @@ RSpec.describe RuboCop::Cop::Layout::ArgumentAlignment do
         end
       end
     end
+
+    it 'does not register an offense when using aligned braced hash as a argument' do
+      expect_no_offenses(<<~RUBY)
+        do_something(
+          {
+            foo: 'bar',
+            baz: 'qux'
+          }
+        )
+      RUBY
+    end
   end
 end
