@@ -1,9 +1,7 @@
 # frozen_string_literal: true
 
 RSpec.describe RuboCop::Cop::Layout::BlockAlignment, :config do
-  let(:cop_config) do
-    { 'EnforcedStyleAlignWith' => 'either' }
-  end
+  let(:cop_config) { { 'EnforcedStyleAlignWith' => 'either' } }
 
   context 'when the block has no arguments' do
     it 'registers an offense for mismatched block end' do
@@ -135,7 +133,7 @@ RSpec.describe RuboCop::Cop::Layout::BlockAlignment, :config do
   end
 
   context 'when the method part is a call chain that spans several lines' do
-    # Example from issue 346 of rubocop-hq/rubocop on github:
+    # Example from issue 346 of rubocop/rubocop on github:
     it 'accepts pretty alignment style' do
       expect_no_offenses(<<~RUBY)
         def foo(bar)
@@ -185,7 +183,7 @@ RSpec.describe RuboCop::Cop::Layout::BlockAlignment, :config do
       RUBY
     end
 
-    # Example from issue 393 of rubocop-hq/rubocop on github:
+    # Example from issue 393 of rubocop/rubocop on github:
     it 'accepts end indented as the start of the block' do
       expect_no_offenses(<<~RUBY)
                my_object.chaining_this_very_long_method(with_a_parameter)
@@ -200,7 +198,7 @@ RSpec.describe RuboCop::Cop::Layout::BlockAlignment, :config do
       RUBY
     end
 
-    # Example from issue 447 of rubocop-hq/rubocop on github:
+    # Example from issue 447 of rubocop/rubocop on github:
     it 'accepts two kinds of end alignment' do
       expect_no_offenses(<<~RUBY)
         # Aligned with start of line where do is:
@@ -254,8 +252,7 @@ RSpec.describe RuboCop::Cop::Layout::BlockAlignment, :config do
     RUBY
   end
 
-  it 'registers an offense for mismatched block end with' \
-     ' an instance variable' do
+  it 'registers an offense for mismatched block end with an instance variable' do
     expect_offense(<<~RUBY)
       @variable = test do |ala|
         end
@@ -359,8 +356,7 @@ RSpec.describe RuboCop::Cop::Layout::BlockAlignment, :config do
     RUBY
   end
 
-  it 'registers an offense for mismatched end with a method call' \
-     ' with arguments' do
+  it 'registers an offense for mismatched end with a method call with arguments' do
     expect_offense(<<~RUBY)
       @h[:f] = f.each_pair.map do |f, v|
         v = 1
@@ -387,8 +383,7 @@ RSpec.describe RuboCop::Cop::Layout::BlockAlignment, :config do
     RUBY
   end
 
-  it 'registers an offense for mismatched end not aligned with the block' \
-     ' that is an argument' do
+  it 'registers an offense for mismatched end not aligned with the block that is an argument' do
     expect_offense(<<~RUBY)
       expect(arr.all? do |o|
         o.valid?
@@ -622,9 +617,7 @@ RSpec.describe RuboCop::Cop::Layout::BlockAlignment, :config do
   end
 
   context 'when configured to align with start_of_line' do
-    let(:cop_config) do
-      { 'EnforcedStyleAlignWith' => 'start_of_line' }
-    end
+    let(:cop_config) { { 'EnforcedStyleAlignWith' => 'start_of_line' } }
 
     it 'allows when start_of_line aligned' do
       expect_no_offenses(<<~RUBY)
@@ -654,9 +647,7 @@ RSpec.describe RuboCop::Cop::Layout::BlockAlignment, :config do
   end
 
   context 'when configured to align with do' do
-    let(:cop_config) do
-      { 'EnforcedStyleAlignWith' => 'start_of_block' }
-    end
+    let(:cop_config) { { 'EnforcedStyleAlignWith' => 'start_of_block' } }
 
     it 'allows when do aligned' do
       expect_no_offenses(<<~RUBY)
@@ -684,4 +675,23 @@ RSpec.describe RuboCop::Cop::Layout::BlockAlignment, :config do
       RUBY
     end
   end
+
+  context 'Ruby 2.7', :ruby27 do
+    it 'accepts end aligned with a call chain left hand side' do
+      expect_no_offenses(<<~RUBY)
+        parser.diagnostics.consumer = lambda do
+          _1 << diagnostic
+        end
+      RUBY
+    end
+
+    it 'registers an offense for mismatched block end with a mass assignment' do
+      expect_offense(<<~RUBY)
+        var1, var2 = lambda do
+          [_1, _2]
+          end
+          ^^^ `end` at 3, 2 is not aligned with `var1, var2` at 1, 0.
+      RUBY
+    end
+  end
 end
