@@ -1,8 +1,6 @@
 # frozen_string_literal: true
 
-RSpec.describe RuboCop::Cop::Layout::EmptyLines do
-  subject(:cop) { described_class.new }
-
+RSpec.describe RuboCop::Cop::Layout::EmptyLines, :config do
   it 'registers an offense for consecutive empty lines' do
     expect_offense(<<~RUBY)
       test = 5
@@ -19,11 +17,11 @@ RSpec.describe RuboCop::Cop::Layout::EmptyLines do
     RUBY
   end
 
-  it 'works when there are no tokens' do
+  it 'does not register an offense when there are no tokens' do
     expect_no_offenses('#comment')
   end
 
-  it 'handles comments' do
+  it 'does not register an offense for comments' do
     expect_no_offenses(<<~RUBY)
       test
 
