@@ -1,17 +1,9 @@
 # frozen_string_literal: true
 
 RSpec.describe RuboCop::Cop::Layout::FirstArgumentIndentation, :config do
-  let(:cop_config) do
-    { 'EnforcedStyle' => style }
-  end
+  let(:cop_config) { { 'EnforcedStyle' => style } }
 
-  let(:other_cops) do
-    {
-      'Layout/IndentationWidth' => {
-        'Width' => indentation_width
-      }
-    }
-  end
+  let(:other_cops) { { 'Layout/IndentationWidth' => { 'Width' => indentation_width } } }
 
   shared_examples 'common behavior' do
     context 'when IndentationWidth:Width is 2' do
@@ -34,6 +26,74 @@ RSpec.describe RuboCop::Cop::Layout::FirstArgumentIndentation, :config do
         RUBY
       end
 
+      it 'registers an offense and corrects an over-indented first argument of `super`' do
+        expect_offense(<<~RUBY)
+          super(
+              :foo,
+              ^^^^ Indent the first argument one step more than the start of the previous line.
+              bar: 3
+          )
+        RUBY
+
+        expect_correction(<<~RUBY)
+          super(
+            :foo,
+              bar: 3
+          )
+        RUBY
+      end
+
+      it 'registers an offense and corrects an over-indented first argument on an alphanumeric method name' do
+        expect_offense(<<~RUBY)
+          self.run(
+              :foo,
+              ^^^^ Indent the first argument one step more than the start of the previous line.
+              bar: 3
+          )
+        RUBY
+
+        expect_correction(<<~RUBY)
+          self.run(
+            :foo,
+              bar: 3
+          )
+        RUBY
+      end
+
+      it 'registers an offense and corrects an over-indented first argument on a pipe method name' do
+        expect_offense(<<~RUBY)
+          self.|(
+              :foo,
+              ^^^^ Indent the first argument one step more than the start of the previous line.
+              bar: 3
+          )
+        RUBY
+
+        expect_correction(<<~RUBY)
+          self.|(
+            :foo,
+              bar: 3
+          )
+        RUBY
+      end
+
+      it 'registers an offense and corrects an over-indented first argument on a plus sign method name' do
+        expect_offense(<<~RUBY)
+          self.+(
+              :foo,
+              ^^^^ Indent the first argument one step more than the start of the previous line.
+              bar: 3
+          )
+        RUBY
+
+        expect_correction(<<~RUBY)
+          self.+(
+            :foo,
+              bar: 3
+          )
+        RUBY
+      end
+
       it 'registers an offense and corrects an under-indented first argument' do
         expect_offense(<<~RUBY)
           run(
@@ -51,8 +111,7 @@ RSpec.describe RuboCop::Cop::Layout::FirstArgumentIndentation, :config do
         RUBY
       end
 
-      it 'registers an offense and corrects lines ' \
-        'affected by another offense' do
+      it 'registers an offense and corrects lines affected by another offense' do
         expect_offense(<<~RUBY)
           foo(
            bar(
@@ -92,6 +151,15 @@ RSpec.describe RuboCop::Cop::Layout::FirstArgumentIndentation, :config do
         end
       end
 
+      context 'for a setter call' do
+        it 'accepts an unindented value' do
+          expect_no_offenses(<<~RUBY)
+            foo.baz =
+            bar
+          RUBY
+        end
+      end
+
       context 'for assignment' do
         it 'accepts a correctly indented first argument and does not care ' \
            'about the second argument' do
@@ -112,8 +180,7 @@ RSpec.describe RuboCop::Cop::Layout::FirstArgumentIndentation, :config do
             RUBY
           end
 
-          it 'registers an offense and corrects ' \
-            'an under-indented first argument' do
+          it 'registers an offense and corrects an under-indented first argument' do
             expect_offense(<<~RUBY)
               @x =
                 run(
@@ -147,8 +214,7 @@ RSpec.describe RuboCop::Cop::Layout::FirstArgumentIndentation, :config do
           RUBY
         end
 
-        it 'registers an offense and corrects ' \
-          'an over-indented first argument' do
+        it 'registers an offense and corrects an over-indented first argument' do
           expect_offense(<<~RUBY)
             puts x.
               merge(
@@ -165,8 +231,7 @@ RSpec.describe RuboCop::Cop::Layout::FirstArgumentIndentation, :config do
           RUBY
         end
 
-        it 'accepts a correctly indented first argument preceded by an ' \
-           'empty line' do
+        it 'accepts a correctly indented first argument preceded by an empty line' do
           expect_no_offenses(<<~RUBY)
             puts x.
               merge(
@@ -187,8 +252,7 @@ RSpec.describe RuboCop::Cop::Layout::FirstArgumentIndentation, :config do
             RUBY
           end
 
-          it 'registers an offense and corrects ' \
-            'an under-indented first argument' do
+          it 'registers an offense and corrects an under-indented first argument' do
             expect_offense(<<~RUBY)
               puts x.
                 merge(
@@ -262,12 +326,7 @@ RSpec.describe RuboCop::Cop::Layout::FirstArgumentIndentation, :config do
     end
 
     context 'when indentation width is overridden for this cop only' do
-      let(:cop_config) do
-        {
-          'EnforcedStyle'    => style,
-          'IndentationWidth' => 4
-        }
-      end
+      let(:cop_config) { { 'EnforcedStyle' => style, 'IndentationWidth' => 4 } }
 
       it 'accepts a correctly indented first argument' do
         expect_no_offenses(<<~RUBY)
@@ -303,8 +362,7 @@ RSpec.describe RuboCop::Cop::Layout::FirstArgumentIndentation, :config do
 
     context 'for method calls within method calls' do
       context 'with outer parentheses' do
-        it 'registers an offense and corrects ' \
-          'an over-indented first argument' do
+        it 'registers an offense and corrects an over-indented first argument' do
           expect_offense(<<~RUBY)
             run(:foo, defaults.merge(
                                     bar: 3))
@@ -329,8 +387,7 @@ RSpec.describe RuboCop::Cop::Layout::FirstArgumentIndentation, :config do
     end
   end
 
-  context 'when EnforcedStyle is ' \
-          'special_for_inner_method_call_in_parentheses' do
+  context 'when EnforcedStyle is special_for_inner_method_call_in_parentheses' do
     let(:style) { 'special_for_inner_method_call_in_parentheses' }
     let(:indentation_width) { 2 }
 
@@ -338,8 +395,7 @@ RSpec.describe RuboCop::Cop::Layout::FirstArgumentIndentation, :config do
 
     context 'for method calls within method calls' do
       context 'with outer parentheses' do
-        it 'registers an offense and corrects ' \
-          'an over-indented first argument' do
+        it 'registers an offense and corrects an over-indented first argument' do
           expect_offense(<<~RUBY)
             run(:foo, defaults.merge(
                                     bar: 3))
@@ -352,8 +408,7 @@ RSpec.describe RuboCop::Cop::Layout::FirstArgumentIndentation, :config do
           RUBY
         end
 
-        it 'registers an offense and corrects ' \
-          'an under-indented first argument' do
+        it 'registers an offense and corrects an under-indented first argument' do
           expect_offense(<<~RUBY)
             run(:foo, defaults.
                       merge(
@@ -380,8 +435,7 @@ RSpec.describe RuboCop::Cop::Layout::FirstArgumentIndentation, :config do
           RUBY
         end
 
-        it 'accepts a correctly indented first argument with fullwidth ' \
-           'characters' do
+        it 'accepts a correctly indented first argument with fullwidth characters' do
           expect_no_offenses(<<~RUBY)
             puts('Ｒｕｂｙ', f(
                                a))
@@ -492,7 +546,7 @@ RSpec.describe RuboCop::Cop::Layout::FirstArgumentIndentation, :config do
 
       context 'for assignment' do
         it 'register an offense and corrects a correctly indented first ' \
-          'argument and does not care about the second argument' do
+           'argument and does not care about the second argument' do
           expect_offense(<<~RUBY)
             x = run(
               :foo,
@@ -518,8 +572,7 @@ RSpec.describe RuboCop::Cop::Layout::FirstArgumentIndentation, :config do
             RUBY
           end
 
-          it 'registers an offense and corrects ' \
-            'an under-indented first argument' do
+          it 'registers an offense and corrects an under-indented first argument' do
             expect_offense(<<~RUBY)
               @x =
                 run(
@@ -543,6 +596,28 @@ RSpec.describe RuboCop::Cop::Layout::FirstArgumentIndentation, :config do
         RUBY
       end
 
+      it 'does not register an offense when argument has expected indent width and ' \
+         'the method is preceded by splat' do
+        expect_no_offenses(<<~RUBY)
+          [
+            item,
+            *do_something(
+              arg)
+          ]
+        RUBY
+      end
+
+      it 'does not register an offense when argument has expected indent width and ' \
+         'the method is preceded by double splat' do
+        expect_no_offenses(<<~RUBY)
+          [
+            item,
+            **do_something(
+              arg)
+          ]
+        RUBY
+      end
+
       context 'when the receiver contains a line break' do
         it 'accepts a correctly indented first argument' do
           expect_no_offenses(<<~RUBY)
@@ -570,8 +645,7 @@ RSpec.describe RuboCop::Cop::Layout::FirstArgumentIndentation, :config do
           RUBY
         end
 
-        it 'accepts a correctly indented first argument preceded by an ' \
-           'empty line' do
+        it 'accepts a correctly indented first argument preceded by an empty line' do
           expect_no_offenses(<<~RUBY)
             puts x.
               merge(
@@ -592,8 +666,7 @@ RSpec.describe RuboCop::Cop::Layout::FirstArgumentIndentation, :config do
             RUBY
           end
 
-          it 'registers an offense and corrects ' \
-            'an under-indented first argument' do
+          it 'registers an offense and corrects an under-indented first argument' do
             expect_offense(<<~RUBY)
               puts x.
                 merge(
@@ -668,12 +741,7 @@ RSpec.describe RuboCop::Cop::Layout::FirstArgumentIndentation, :config do
 
     context 'when indentation width is overridden for this cop only' do
       let(:indentation_width) { nil }
-      let(:cop_config) do
-        {
-          'EnforcedStyle'    => style,
-          'IndentationWidth' => 4
-        }
-      end
+      let(:cop_config) { { 'EnforcedStyle' => style, 'IndentationWidth' => 4 } }
 
       it 'accepts a correctly indented first argument' do
         expect_no_offenses(<<~RUBY)
