@@ -1,8 +1,6 @@
 # frozen_string_literal: true
 
-RSpec.describe RuboCop::Cop::Layout::FirstHashElementIndentation do
-  subject(:cop) { described_class.new(config) }
-
+RSpec.describe RuboCop::Cop::Layout::FirstHashElementIndentation, :config do
   let(:config) do
     supported_styles = {
       'SupportedStyles' => %w[special_inside_parentheses consistent
@@ -58,8 +56,7 @@ RSpec.describe RuboCop::Cop::Layout::FirstHashElementIndentation do
       RUBY
     end
 
-    it 'registers an offense and corrects incorrectly indented ' \
-      'first pair with :' do
+    it 'registers an offense and corrects incorrectly indented first pair with :' do
       expect_offense(<<~RUBY)
         a << {
                a: 1,
@@ -97,8 +94,7 @@ RSpec.describe RuboCop::Cop::Layout::FirstHashElementIndentation do
       RUBY
     end
 
-    it 'registers an offense and corrects incorrectly indented ' \
-      'first pair with =>' do
+    it 'registers an offense and corrects incorrectly indented first pair with =>' do
       expect_offense(<<~RUBY)
         a << {
            'a' => 1,
@@ -348,6 +344,74 @@ RSpec.describe RuboCop::Cop::Layout::FirstHashElementIndentation do
             )
           RUBY
         end
+
+        it 'registers an offense for incorrectly indented hash that is the value of a single pair hash' do
+          expect_offense(<<~RUBY)
+            func(x: {
+                  a: 1, b: 2 })
+                  ^^^^ Use 2 spaces for indentation in a hash, relative to the first position after the preceding left parenthesis.
+          RUBY
+
+          expect_correction(<<~RUBY)
+            func(x: {
+                   a: 1, b: 2 })
+          RUBY
+        end
+
+        it 'registers an offense for a hash that is a value of a multi pairs hash' \
+           'when the indent of its elements is not based on the hash key' do
+          expect_offense(<<~RUBY)
+            func(x: {
+              a: 1,
+              ^^^^ Use 2 spaces for indentation in a hash, relative to the parent hash key.
+                   b: 2
+            },
+            ^ Indent the right brace the same as the parent hash key.
+                 y: {
+                   c: 1,
+                   d: 2
+                 })
+          RUBY
+
+          expect_correction(<<~RUBY)
+            func(x: {
+                   a: 1,
+                   b: 2
+                 },
+                 y: {
+                   c: 1,
+                   d: 2
+                 })
+          RUBY
+        end
+
+        it 'accepts indent based on the preceding left parenthesis' \
+           'when the right brace and its following pair is on the same line' do
+          expect_no_offenses(<<~RUBY)
+            func(:x, y: {
+                   a: 1,
+                   b: 2
+                 }, z: {
+                   c: 1,
+                   d: 2
+                 })
+          RUBY
+        end
+
+        it 'accepts indent based on the left brace when the outer hash key and ' \
+           'the left brace is not on the same line' do
+          expect_no_offenses(<<~RUBY)
+            func(x:
+                   {
+                     a: 1,
+                     b: 2
+                   },
+                 y: {
+                   c: 1,
+                   d: 2
+                 })
+          RUBY
+        end
       end
 
       context 'and EnforcedStyle is consistent' do
@@ -395,6 +459,74 @@ RSpec.describe RuboCop::Cop::Layout::FirstHashElementIndentation do
               :name => /q\[(id_eq)\]/ })
           RUBY
         end
+
+        it 'registers an offense for incorrectly indented hash that is the value of a single pair hash' do
+          expect_offense(<<~RUBY)
+            func(x: {
+                  a: 1, b: 2 })
+                  ^^^^ Use 2 spaces for indentation in a hash, relative to the start of the line where the left curly brace is.
+          RUBY
+
+          expect_correction(<<~RUBY)
+            func(x: {
+              a: 1, b: 2 })
+          RUBY
+        end
+
+        it 'registers an offense for a hash that is a value of a multi pairs hash' \
+           'when the indent of its elements is not based on the hash key' do
+          expect_offense(<<~RUBY)
+            func(x: {
+              a: 1,
+              ^^^^ Use 2 spaces for indentation in a hash, relative to the parent hash key.
+                   b: 2
+            },
+            ^ Indent the right brace the same as the parent hash key.
+                 y: {
+                   c: 1,
+                   d: 2
+                 })
+          RUBY
+
+          expect_correction(<<~RUBY)
+            func(x: {
+                   a: 1,
+                   b: 2
+                 },
+                 y: {
+                   c: 1,
+                   d: 2
+                 })
+          RUBY
+        end
+
+        it 'accepts indent based on the start of the line where the left brace is' \
+           'when the right brace and its following pair is on the same line' do
+          expect_no_offenses(<<~RUBY)
+            func(:x, y: {
+              a: 1,
+              b: 2
+            }, z: {
+              c: 1,
+              d: 2
+            })
+          RUBY
+        end
+
+        it 'accepts indent based on the left brace when the outer hash key and ' \
+           'the left brace is not on the same line' do
+          expect_no_offenses(<<~RUBY)
+            func(x:
+                   {
+                     a: 1,
+                     b: 2
+                   },
+                 y: {
+                   c: 1,
+                   d: 2
+                 })
+          RUBY
+        end
       end
     end
 
@@ -414,8 +546,7 @@ RSpec.describe RuboCop::Cop::Layout::FirstHashElementIndentation do
         RUBY
       end
 
-      it 'registers an offense for incorrectly indented multi-line hash ' \
-         'with braces' do
+      it 'registers an offense for incorrectly indented multi-line hash with braces' do
         expect_offense(<<~RUBY)
           func x, {
                  a: 1, b: 2 }
@@ -427,6 +558,77 @@ RSpec.describe RuboCop::Cop::Layout::FirstHashElementIndentation do
             a: 1, b: 2 }
         RUBY
       end
+
+      it 'registers an offense for the first inner hash member not based on the start of line ' \
+         'when the outer hash pair has no following siblings' do
+        expect_offense(<<~RUBY)
+          func x: :foo, y: {
+                          a: 1, b: 2 }
+                          ^^^^ Use 2 spaces for indentation in a hash, relative to the start of the line where the left curly brace is.
+        RUBY
+
+        expect_correction(<<~RUBY)
+          func x: :foo, y: {
+            a: 1, b: 2 }
+        RUBY
+      end
+
+      it 'registers an offense for a hash that is a value of a multi pairs hash' \
+         'when the indent of its elements is not based on the hash key' do
+        expect_offense(<<~RUBY)
+          func x: {
+            a: 1,
+            ^^^^ Use 2 spaces for indentation in a hash, relative to the parent hash key.
+                 b: 2
+          },
+          ^ Indent the right brace the same as the parent hash key.
+               y: {
+                 c: 1,
+                 d: 2
+               }
+        RUBY
+
+        expect_correction(<<~RUBY)
+          func x: {
+                 a: 1,
+                 b: 2
+               },
+               y: {
+                 c: 1,
+                 d: 2
+               }
+        RUBY
+      end
+
+      it 'accepts indent based on the start of the line where the left brace is' \
+         'when the right brace and its following pair is on the same line' do
+        expect_no_offenses(<<~RUBY)
+          func :x, y: {
+            a: 1,
+            b: 2
+          }, z: {
+            c: 1,
+            d: 2
+          }
+        RUBY
+      end
+
+      it 'accepts indent based on the left brace when the outer hash key and ' \
+         'the left brace is not on the same line' do
+        expect_no_offenses(<<~RUBY)
+          {
+            x:
+              {
+                a: 1,
+                b: 2
+              },
+            y: {
+              c: 1,
+              d: 2
+            }
+          }
+        RUBY
+      end
     end
   end
 
@@ -465,7 +667,7 @@ RSpec.describe RuboCop::Cop::Layout::FirstHashElementIndentation do
     end
 
     context "when 'consistent' style is used" do
-      it 'registers an offense and correcs incorrect indentation' do
+      it 'registers an offense and corrects incorrect indentation' do
         expect_offense(<<~RUBY)
           func({
             a: 1
@@ -518,5 +720,45 @@ RSpec.describe RuboCop::Cop::Layout::FirstHashElementIndentation do
              }
       RUBY
     end
+
+    it 'registers an offense for incorrectly indented hash that is the value of a single pair hash' do
+      expect_offense(<<~RUBY)
+        func x: {
+                a: 1, b: 2 }
+                ^^^^ Use 2 spaces for indentation in a hash, relative to the position of the opening brace.
+      RUBY
+
+      expect_correction(<<~RUBY)
+        func x: {
+                  a: 1, b: 2 }
+      RUBY
+    end
+
+    it 'registers an offense for a hash that is a value of a multi pairs hash' \
+       'when the indent of its elements is not based on the hash key' do
+      expect_offense(<<~RUBY)
+        func x: {
+          a: 1,
+          ^^^^ Use 2 spaces for indentation in a hash, relative to the position of the opening brace.
+                  b: 2
+        },
+        ^ Indent the right brace the same as the left brace.
+             y: {
+                  c: 1,
+                  d: 2
+                }
+      RUBY
+
+      expect_correction(<<~RUBY)
+        func x: {
+                  a: 1,
+                  b: 2
+                },
+             y: {
+                  c: 1,
+                  d: 2
+                }
+      RUBY
+    end
   end
 end
