@@ -1,13 +1,16 @@
 # frozen_string_literal: true
 
 RSpec.describe RuboCop::Cop::Layout::HashAlignment, :config do
-  let(:cop_config) do
-    {
-      'EnforcedHashRocketStyle' => 'key',
-      'EnforcedColonStyle' => 'key'
-    }
+  let(:config) do
+    RuboCop::Config.new(
+      'Layout/HashAlignment' => default_cop_config.merge(cop_config),
+      'Layout/ArgumentAlignment' => argument_alignment_config
+    )
   end
 
+  let(:default_cop_config) { { 'EnforcedHashRocketStyle' => 'key', 'EnforcedColonStyle' => 'key' } }
+  let(:argument_alignment_config) { { 'EnforcedStyle' => 'with_first_argument' } }
+
   shared_examples 'not on separate lines' do
     it 'accepts single line hash' do
       expect_no_offenses('func(a: 0, bb: 1)')
@@ -33,14 +36,37 @@ RSpec.describe RuboCop::Cop::Layout::HashAlignment, :config do
         end
       RUBY
     end
+
+    context 'when using hash value omission', :ruby31 do
+      it 'accepts single line hash' do
+        expect_no_offenses('func(a:, bb:)')
+      end
+
+      it 'accepts several pairs per line' do
+        expect_no_offenses(<<~RUBY)
+          func(a:, bb:,
+               ccc:, dddd:)
+        RUBY
+      end
+
+      it "accepts pairs that don't start a line" do
+        expect_no_offenses(<<~RUBY)
+          render :json => {a:,
+                           b:}, :status => 404
+          def example
+            a(
+              b:,
+              c: d(
+                e:
+              ), f:)
+          end
+        RUBY
+      end
+    end
   end
 
   context 'always inspect last argument hash' do
-    let(:cop_config) do
-      {
-        'EnforcedLastArgumentHashStyle' => 'always_inspect'
-      }
-    end
+    let(:cop_config) { { 'EnforcedLastArgumentHashStyle' => 'always_inspect' } }
 
     it 'registers offense and corrects misaligned keys in implicit hash' do
       expect_offense(<<~RUBY)
@@ -68,8 +94,7 @@ RSpec.describe RuboCop::Cop::Layout::HashAlignment, :config do
       RUBY
     end
 
-    it 'registers an offense and corrects misaligned keys in implicit ' \
-      'hash for super' do
+    it 'registers an offense and corrects misaligned keys in implicit hash for super' do
       expect_offense(<<~RUBY)
         super(a: 0,
           b: 1)
@@ -82,8 +107,7 @@ RSpec.describe RuboCop::Cop::Layout::HashAlignment, :config do
       RUBY
     end
 
-    it 'registers an offense and corrects misaligned keys in explicit ' \
-      'hash for super' do
+    it 'registers an offense and corrects misaligned keys in explicit hash for super' do
       expect_offense(<<~RUBY)
         super({a: 0,
           b: 1})
@@ -96,8 +120,7 @@ RSpec.describe RuboCop::Cop::Layout::HashAlignment, :config do
       RUBY
     end
 
-    it 'registers an offense and corrects misaligned keys in implicit ' \
-      'hash for yield' do
+    it 'registers an offense and corrects misaligned keys in implicit hash for yield' do
       expect_offense(<<~RUBY)
         yield(a: 0,
           b: 1)
@@ -110,8 +133,7 @@ RSpec.describe RuboCop::Cop::Layout::HashAlignment, :config do
       RUBY
     end
 
-    it 'registers an offense and corrects misaligned keys in explicit ' \
-      'hash for yield' do
+    it 'registers an offense and corrects misaligned keys in explicit hash for yield' do
       expect_offense(<<~RUBY)
         yield({a: 0,
           b: 1})
@@ -123,14 +145,133 @@ RSpec.describe RuboCop::Cop::Layout::HashAlignment, :config do
                b: 1})
       RUBY
     end
+
+    context 'when using hash value omission', :ruby31 do
+      it 'registers offense and corrects misaligned keys in implicit hash' do
+        expect_offense(<<~RUBY)
+          func(a:,
+            b:)
+            ^^ Align the keys of a hash literal if they span more than one line.
+        RUBY
+
+        expect_correction(<<~RUBY)
+          func(a:,
+               b:)
+        RUBY
+      end
+
+      it 'registers offense and corrects misaligned keys in explicit hash' do
+        expect_offense(<<~RUBY)
+          func({a:,
+            b:})
+            ^^ Align the keys of a hash literal if they span more than one line.
+        RUBY
+
+        expect_correction(<<~RUBY)
+          func({a:,
+                b:})
+        RUBY
+      end
+    end
+  end
+
+  context 'when `EnforcedStyle: with_fixed_indentation` of `ArgumentAlignment`' do
+    let(:argument_alignment_config) { { 'EnforcedStyle' => 'with_fixed_indentation' } }
+
+    it 'register and corrects an offense' do
+      expect_offense(<<~RUBY)
+        THINGS = {
+          oh: :io,
+            hi: 'neat'
+            ^^^^^^^^^^ Align the keys of a hash literal if they span more than one line.
+            }
+      RUBY
+
+      expect_correction(<<~RUBY)
+        THINGS = {
+          oh: :io,
+          hi: 'neat'
+            }
+      RUBY
+    end
+
+    it 'registers and corrects an offense when using misaligned keyword arguments' do
+      expect_offense(<<~RUBY)
+        config.fog_credentials_as_kwargs(
+          provider:              'AWS',
+          ^^^^^^^^^^^^^^^^^^^^^^^^^^^^ Align the keys of a hash literal if they span more than one line.
+          aws_access_key_id:     ENV['S3_ACCESS_KEY'],
+          ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^ Align the keys of a hash literal if they span more than one line.
+          aws_secret_access_key: ENV['S3_SECRET'],
+          region:                ENV['S3_REGION'],
+          ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^ Align the keys of a hash literal if they span more than one line.
+        )
+      RUBY
+
+      expect_correction(<<~RUBY)
+        config.fog_credentials_as_kwargs(
+          provider: 'AWS',
+          aws_access_key_id: ENV['S3_ACCESS_KEY'],
+          aws_secret_access_key: ENV['S3_SECRET'],
+          region: ENV['S3_REGION'],
+        )
+      RUBY
+    end
+
+    context 'when using hash value omission', :ruby31 do
+      it 'register and corrects an offense' do
+        expect_offense(<<~RUBY)
+          THINGS = {
+            oh:,
+              hi:
+              ^^^ Align the keys of a hash literal if they span more than one line.
+              }
+        RUBY
+
+        expect_correction(<<~RUBY)
+          THINGS = {
+            oh:,
+            hi:
+              }
+        RUBY
+      end
+
+      it 'does not register and corrects an offense when using aligned keyword arguments' do
+        expect_no_offenses(<<~RUBY)
+          config.fog_credentials_as_kwargs(
+            provider:,
+            aws_access_key_id:,
+            aws_secret_access_key:,
+            region:
+          )
+        RUBY
+      end
+    end
+
+    it 'does not register an offense using aligned hash literal' do
+      expect_no_offenses(<<~RUBY)
+        {
+          oh: :io,
+          hi: 'neat'
+        }
+      RUBY
+    end
+
+    it 'does not register an offense for an empty hash literal' do
+      expect_no_offenses(<<~RUBY)
+        foo({})
+      RUBY
+    end
+
+    it 'does not register an offense using aligned hash argument for `proc.()`' do
+      expect_no_offenses(<<~RUBY)
+        proc.(key: value)
+      RUBY
+    end
   end
 
   context 'always ignore last argument hash' do
-    let(:cop_config) do
-      {
-        'EnforcedLastArgumentHashStyle' => 'always_ignore'
-      }
-    end
+    let(:cop_config) { { 'EnforcedLastArgumentHashStyle' => 'always_ignore' } }
 
     it 'accepts misaligned keys in implicit hash' do
       expect_no_offenses(<<~RUBY)
@@ -176,11 +317,7 @@ RSpec.describe RuboCop::Cop::Layout::HashAlignment, :config do
   end
 
   context 'ignore implicit last argument hash' do
-    let(:cop_config) do
-      {
-        'EnforcedLastArgumentHashStyle' => 'ignore_implicit'
-      }
-    end
+    let(:cop_config) { { 'EnforcedLastArgumentHashStyle' => 'ignore_implicit' } }
 
     it 'accepts misaligned keys in implicit hash' do
       expect_no_offenses(<<~RUBY)
@@ -209,8 +346,7 @@ RSpec.describe RuboCop::Cop::Layout::HashAlignment, :config do
       RUBY
     end
 
-    it 'registers an offense and corrects misaligned keys in explicit ' \
-      'hash for super' do
+    it 'registers an offense and corrects misaligned keys in explicit hash for super' do
       expect_offense(<<~RUBY)
         super({a: 0,
           b: 1})
@@ -230,8 +366,7 @@ RSpec.describe RuboCop::Cop::Layout::HashAlignment, :config do
       RUBY
     end
 
-    it 'registers an offense and corrects misaligned keys in explicit ' \
-      'hash for yield' do
+    it 'registers an offense and corrects misaligned keys in explicit hash for yield' do
       expect_offense(<<~RUBY)
         yield({a: 0,
           b: 1})
@@ -246,11 +381,7 @@ RSpec.describe RuboCop::Cop::Layout::HashAlignment, :config do
   end
 
   context 'ignore explicit last argument hash' do
-    let(:cop_config) do
-      {
-        'EnforcedLastArgumentHashStyle' => 'ignore_explicit'
-      }
-    end
+    let(:cop_config) { { 'EnforcedLastArgumentHashStyle' => 'ignore_explicit' } }
 
     it 'registers an offense and corrects misaligned keys in implicit hash' do
       expect_offense(<<~RUBY)
@@ -272,8 +403,29 @@ RSpec.describe RuboCop::Cop::Layout::HashAlignment, :config do
       RUBY
     end
 
-    it 'registers an offense and corrects misaligned keys in implicit ' \
-      'hash for super' do
+    context 'when using hash value omission', :ruby31 do
+      it 'registers an offense and corrects misaligned keys in implicit hash' do
+        expect_offense(<<~RUBY)
+          func(a:,
+            b:)
+            ^^ Align the keys of a hash literal if they span more than one line.
+        RUBY
+
+        expect_correction(<<~RUBY)
+          func(a:,
+               b:)
+        RUBY
+      end
+
+      it 'accepts misaligned keys in explicit hash' do
+        expect_no_offenses(<<~RUBY)
+          func({a:,
+            b:})
+        RUBY
+      end
+    end
+
+    it 'registers an offense and corrects misaligned keys in implicit hash for super' do
       expect_offense(<<~RUBY)
         super(a: 0,
           b: 1)
@@ -293,8 +445,7 @@ RSpec.describe RuboCop::Cop::Layout::HashAlignment, :config do
       RUBY
     end
 
-    it 'registers an offense and corrects misaligned keys in implicit ' \
-      'hash for yield' do
+    it 'registers an offense and corrects misaligned keys in implicit hash for yield' do
       expect_offense(<<~RUBY)
         yield(a: 0,
           b: 1)
@@ -342,8 +493,7 @@ RSpec.describe RuboCop::Cop::Layout::HashAlignment, :config do
       RUBY
     end
 
-    it 'registers an offense and corrects misaligned mixed multiline ' \
-      'hash keys' do
+    it 'registers an offense and corrects misaligned mixed multiline hash keys' do
       expect_offense(<<~RUBY)
         hash = { a: 1, b: 2,
                 c: 3 }
@@ -435,8 +585,7 @@ RSpec.describe RuboCop::Cop::Layout::HashAlignment, :config do
       RUBY
     end
 
-    it 'registers an offense and corrects multiline value starts ' \
-      'in wrong place' do
+    it 'registers an offense and corrects multiline value starts in wrong place' do
       expect_offense(<<~RUBY)
         hash = {
           'a' =>  (
@@ -538,12 +687,11 @@ RSpec.describe RuboCop::Cop::Layout::HashAlignment, :config do
       RUBY
     end
 
-    it 'registers an offense and corrects alignment when using double splat ' \
-       'in an explicit hash' do
+    it 'registers an offense and corrects alignment when using double splat in an explicit hash' do
       expect_offense(<<~RUBY)
         Hash(foo: 'bar',
                **extra_params
-               ^^^^^^^^^^^^^^ Align the keys of a hash literal if they span more than one line.
+               ^^^^^^^^^^^^^^ Align keyword splats with the rest of the hash if it spans more than one line.
         )
       RUBY
 
@@ -554,12 +702,11 @@ RSpec.describe RuboCop::Cop::Layout::HashAlignment, :config do
       RUBY
     end
 
-    it 'registers an offense and corrects alignment when using double splat ' \
-      'in braces' do
+    it 'registers an offense and corrects alignment when using double splat in braces' do
       expect_offense(<<~RUBY)
         {foo: 'bar',
                **extra_params
-               ^^^^^^^^^^^^^^ Align the keys of a hash literal if they span more than one line.
+               ^^^^^^^^^^^^^^ Align keyword splats with the rest of the hash if it spans more than one line.
         }
       RUBY
 
@@ -600,6 +747,22 @@ RSpec.describe RuboCop::Cop::Layout::HashAlignment, :config do
       expect_no_offenses('h = {}')
     end
 
+    context 'when using hash value omission', :ruby31 do
+      it 'accepts aligned hash keys and values' do
+        expect_no_offenses(<<~RUBY)
+          hash1 = {
+            'a'   => 0,
+            'bbb' => 1
+          }
+          hash2 = {
+            a:   0,
+            bbb: 1,
+            ccc:
+          }
+        RUBY
+      end
+    end
+
     it 'accepts a multiline array of single line hashes' do
       expect_no_offenses(<<~RUBY)
         def self.scenarios_order
@@ -724,21 +887,17 @@ RSpec.describe RuboCop::Cop::Layout::HashAlignment, :config do
   end
 
   context 'with invalid configuration' do
-    let(:cop_config) do
-      {
-        'EnforcedHashRocketStyle' => 'junk',
-        'EnforcedColonStyle' => 'junk'
-      }
-    end
+    let(:cop_config) { { 'EnforcedHashRocketStyle' => 'junk', 'EnforcedColonStyle' => 'junk' } }
 
     it 'fails' do
-      src = <<~RUBY
-        hash = {
-          a: 0,
-          bb: 1
-        }
-      RUBY
-      expect { inspect_source(src) }.to raise_error(RuntimeError)
+      expect do
+        expect_offense(<<~RUBY)
+          hash = {
+            a: 0,
+            bb: 1
+          }
+        RUBY
+      end.to raise_error(RuntimeError)
     end
   end
 
@@ -763,6 +922,38 @@ RSpec.describe RuboCop::Cop::Layout::HashAlignment, :config do
       RUBY
     end
 
+    context 'when using hash value omission', :ruby31 do
+      it 'accepts aligned hash keys' do
+        expect_no_offenses(<<~RUBY)
+          hash1 = {
+              a: 0,
+            bbb: 1,
+            ccc:
+          }
+          hash2 = {
+              'a' => 0,
+            'bbb' => 1
+          }
+        RUBY
+      end
+
+      it 'registers an offense and corrects mixed indentation and spacing' do
+        expect_offense(<<~RUBY)
+          hash1 = { a: 0,
+               bb:,
+               ^^^ Align the separators of a hash literal if they span more than one line.
+                     ccc: 2 }
+                     ^^^^^^ Align the separators of a hash literal if they span more than one line.
+        RUBY
+
+        expect_correction(<<~RUBY)
+          hash1 = { a: 0,
+                   bb:,
+                  ccc: 2 }
+        RUBY
+      end
+    end
+
     it 'accepts an empty hash' do
       expect_no_offenses('h = {}')
     end
@@ -942,7 +1133,7 @@ RSpec.describe RuboCop::Cop::Layout::HashAlignment, :config do
     end
 
     it 'registers an offense and corrects misaligned hash values, ' \
-      'prefer table when least offenses' do
+       'prefer table when least offenses' do
       expect_offense(<<~RUBY)
         hash = {
           'abcdefg' => 0,
@@ -968,8 +1159,7 @@ RSpec.describe RuboCop::Cop::Layout::HashAlignment, :config do
       RUBY
     end
 
-    it 'registers an offense and corrects misaligned hash values, ' \
-      'prefer key when least offenses' do
+    it 'registers an offense and corrects misaligned hash values, prefer key when least offenses' do
       expect_offense(<<~RUBY)
         hash = {
           'abcdefg' => 0,
@@ -995,8 +1185,7 @@ RSpec.describe RuboCop::Cop::Layout::HashAlignment, :config do
       RUBY
     end
 
-    it 'registers an offense and corrects misaligned hash keys ' \
-      'with mixed hash style' do
+    it 'registers an offense and corrects misaligned hash keys with mixed hash style' do
       expect_offense(<<~RUBY)
         headers = {
           "Content-Type" => 0,
@@ -1013,8 +1202,7 @@ RSpec.describe RuboCop::Cop::Layout::HashAlignment, :config do
       RUBY
     end
 
-    it 'registers an offense and corrects misaligned hash values, ' \
-      'works separate for each hash' do
+    it 'registers an offense and corrects misaligned hash values, works separate for each hash' do
       expect_offense(<<~RUBY)
         hash = {
           'abcdefg' => 0,
@@ -1054,7 +1242,7 @@ RSpec.describe RuboCop::Cop::Layout::HashAlignment, :config do
         }
       end
 
-      it 'registers an offense and corrects misaligned hash values, '\
+      it 'registers an offense and corrects misaligned hash values, ' \
          'prefer table because it is specified first' do
         expect_offense(<<~RUBY)
           hash = {
@@ -1138,4 +1326,155 @@ RSpec.describe RuboCop::Cop::Layout::HashAlignment, :config do
   it 'register no offense for yield without args' do
     expect_no_offenses('yield')
   end
+
+  context 'with `EnforcedColonStyle`: `table`' do
+    let(:cop_config) do
+      {
+        'EnforcedColonStyle' => 'table'
+      }
+    end
+
+    context 'and misaligned keys' do
+      it 'registers an offense and corrects' do
+        expect_offense(<<~RUBY)
+          foo ab: 1,
+              c: 2
+              ^^^^ Align the keys and values of a hash literal if they span more than one line.
+        RUBY
+
+        expect_correction(<<~RUBY)
+          foo ab: 1,
+              c:  2
+        RUBY
+      end
+    end
+
+    context 'when using hash value omission', :ruby31 do
+      context 'and aligned keys' do
+        it 'does not register an offense and corrects' do
+          expect_no_offenses(<<~RUBY)
+            foo ab: 1,
+                c:
+          RUBY
+        end
+      end
+    end
+
+    context 'when the only item is a kwsplat' do
+      it 'does not register an offense' do
+        expect_no_offenses(<<~RUBY)
+          foo({**rest})
+        RUBY
+      end
+    end
+
+    context 'and a double splat argument after a hash key' do
+      it 'registers an offense on the misaligned key and corrects' do
+        expect_offense(<<~RUBY)
+          foo ab: 1,
+              c: 2, **rest
+              ^^^^ Align the keys and values of a hash literal if they span more than one line.
+        RUBY
+
+        expect_correction(<<~RUBY)
+          foo ab: 1,
+              c:  2, **rest
+        RUBY
+      end
+    end
+
+    context 'and aligned keys but a double splat argument after' do
+      it 'does not register an offense on the `kwsplat`' do
+        expect_no_offenses(<<~RUBY)
+          foo a: 1,
+              b: 2, **rest
+        RUBY
+      end
+    end
+
+    context 'and a misaligned double splat argument' do
+      it 'registers an offense and corrects' do
+        expect_offense(<<~RUBY)
+          foo a: 1,
+                **rest
+                ^^^^^^ Align keyword splats with the rest of the hash if it spans more than one line.
+        RUBY
+
+        expect_correction(<<~RUBY)
+          foo a: 1,
+              **rest
+        RUBY
+      end
+    end
+  end
+
+  context 'with `EnforcedHashRocketStyle`: `table`' do
+    let(:cop_config) do
+      {
+        'EnforcedHashRocketStyle' => 'table'
+      }
+    end
+
+    context 'and misaligned keys' do
+      it 'registers an offense and corrects' do
+        expect_offense(<<~RUBY)
+          foo :ab => 1,
+              :c => 2
+              ^^^^^^^ Align the keys and values of a hash literal if they span more than one line.
+        RUBY
+
+        expect_correction(<<~RUBY)
+          foo :ab => 1,
+              :c  => 2
+        RUBY
+      end
+    end
+
+    context 'when the only item is a kwsplat' do
+      it 'does not register an offense' do
+        expect_no_offenses(<<~RUBY)
+          foo({**rest})
+        RUBY
+      end
+    end
+
+    context 'and a double splat argument after a hash key' do
+      it 'registers an offense on the misaligned key and corrects' do
+        expect_offense(<<~RUBY)
+          foo :ab => 1,
+              :c => 2, **rest
+              ^^^^^^^ Align the keys and values of a hash literal if they span more than one line.
+        RUBY
+
+        expect_correction(<<~RUBY)
+          foo :ab => 1,
+              :c  => 2, **rest
+        RUBY
+      end
+    end
+
+    context 'and aligned keys but a double splat argument after' do
+      it 'does not register an offense on the `kwsplat`' do
+        expect_no_offenses(<<~RUBY)
+          foo :a => 1,
+              :b => 2, **rest
+        RUBY
+      end
+    end
+
+    context 'and a misaligned double splat argument' do
+      it 'registers an offense and corrects' do
+        expect_offense(<<~RUBY)
+          foo :a => 1,
+                **rest
+                ^^^^^^ Align keyword splats with the rest of the hash if it spans more than one line.
+        RUBY
+
+        expect_correction(<<~RUBY)
+          foo :a => 1,
+              **rest
+        RUBY
+      end
+    end
+  end
 end
