@@ -9,6 +9,33 @@ RSpec.describe RuboCop::Cop::Layout::IndentationConsistency, :config do
         "#{}"
       RUBY
     end
+
+    it 'accepts when using access modifier at the top level' do
+      expect_no_offenses(<<~'RUBY')
+        public
+
+        def foo
+        end
+      RUBY
+    end
+
+    it 'registers and corrects an offense when using access modifier and indented method definition ' \
+       'at the top level' do
+      expect_offense(<<~'RUBY')
+        public
+
+          def foo
+          ^^^^^^^ Inconsistent indentation detected.
+          end
+      RUBY
+
+      expect_correction(<<~'RUBY')
+        public
+
+        def foo
+        end
+      RUBY
+    end
   end
 
   context 'with if statement' do
@@ -202,8 +229,7 @@ RSpec.describe RuboCop::Cop::Layout::IndentationConsistency, :config do
       RUBY
     end
 
-    it 'accepts an if/else in assignment on next line with end aligned ' \
-       'with if' do
+    it 'accepts an if/else in assignment on next line with end aligned with if' do
       expect_no_offenses(<<~RUBY)
         var =
           if a
@@ -255,8 +281,7 @@ RSpec.describe RuboCop::Cop::Layout::IndentationConsistency, :config do
   end
 
   context 'with case' do
-    it 'registers an offense and corrects bad indentation ' \
-      'in a case/when body' do
+    it 'registers an offense and corrects bad indentation in a case/when body' do
       expect_offense(<<~RUBY)
         case a
         when b
@@ -275,8 +300,7 @@ RSpec.describe RuboCop::Cop::Layout::IndentationConsistency, :config do
       RUBY
     end
 
-    it 'registers an offense and corrects bad indentation ' \
-      'in a case/else body' do
+    it 'registers an offense and corrects bad indentation in a case/else body' do
       expect_offense(<<~RUBY)
         case a
         when b
@@ -527,6 +551,42 @@ RSpec.describe RuboCop::Cop::Layout::IndentationConsistency, :config do
           end
         RUBY
       end
+
+      it 'accepts different indentation in different visibility sections when using `Struct.new`' do
+        expect_no_offenses(<<~RUBY)
+          Foo = Struct.new(:foo) do
+            def meow
+              puts('Meow!')
+            end
+
+            protected
+
+              def can_we_be_friends?(another_cat)
+                # some logic
+              end
+
+              def related_to?(another_cat)
+                # some logic
+              end
+
+            private
+
+                        # Here we go back an indentation level again. This is a
+                        # violation of the indented_internal_methods style,
+                        # but it's not for this cop to report.
+                        # Layout/IndentationWidth will handle it.
+            def meow_at_3am?
+              rand < 0.8
+            end
+
+                        # As long as the indentation of this method is
+                        # consistent with that of the last one, we're fine.
+            def meow_at_4am?
+              rand < 0.8
+            end
+          end
+        RUBY
+      end
     end
 
     context 'with normal style configured' do
@@ -580,7 +640,7 @@ RSpec.describe RuboCop::Cop::Layout::IndentationConsistency, :config do
       end
 
       it 'registers an offense and corrects bad indentation ' \
-        'in def but not for outdented public, protected, and private' do
+         'in def but not for outdented public, protected, and private' do
         expect_offense(<<~RUBY)
           class Test
           public
@@ -676,8 +736,7 @@ RSpec.describe RuboCop::Cop::Layout::IndentationConsistency, :config do
     end
 
     context 'even when there are no public methods' do
-      it 'registers an offense and corrects bad indentation ' \
-        'of private methods' do
+      it 'registers an offense and corrects bad indentation of private methods' do
         expect_offense(<<~RUBY)
           module Test
             private
@@ -749,7 +808,7 @@ RSpec.describe RuboCop::Cop::Layout::IndentationConsistency, :config do
       RUBY
     end
 
-    it 'does not auto-correct an offense within another offense' do
+    it 'does not autocorrect an offense within another offense' do # rubocop:disable InternalAffairs/ExampleDescription
       expect_offense(<<~RUBY)
         require 'spec_helper'
         describe ArticlesController do
