@@ -1,8 +1,6 @@
 # frozen_string_literal: true
 
-RSpec.describe RuboCop::Cop::Layout::IndentationWidth do
-  subject(:cop) { described_class.new(config) }
-
+RSpec.describe RuboCop::Cop::Layout::IndentationWidth, :config do
   let(:config) do
     RuboCop::Config.new(
       'Layout/IndentationWidth' => cop_config,
@@ -14,15 +12,10 @@ RSpec.describe RuboCop::Cop::Layout::IndentationWidth do
   end
   let(:access_modifier_config) { { 'EnforcedStyle' => 'indent' } }
   let(:consistency_config) { { 'EnforcedStyle' => 'normal' } }
-  let(:end_alignment_config) do
-    { 'Enabled' => true, 'EnforcedStyleAlignWith' => 'variable' }
-  end
+  let(:end_alignment_config) { { 'Enabled' => true, 'EnforcedStyleAlignWith' => 'variable' } }
   let(:def_end_alignment_config) do
     { 'Enabled' => true, 'EnforcedStyleAlignWith' => 'start_of_line' }
   end
-  let(:indented_internal_methods_offense_message) do
-    'Use 2 (not 0) spaces for indented_internal_methods indentation.'
-  end
 
   context 'with Width set to 4' do
     let(:cop_config) { { 'Width' => 4 } }
@@ -44,7 +37,7 @@ RSpec.describe RuboCop::Cop::Layout::IndentationWidth do
       let(:cop_config) do
         {
           'Width' => 4,
-          'IgnoredPatterns' => ['^\s*module', '^\s*(els)?if.*[A-Z][a-z]+']
+          'AllowedPatterns' => ['^\s*module', '^\s*(els)?if.*[A-Z][a-z]+']
         }
       end
 
@@ -78,30 +71,31 @@ RSpec.describe RuboCop::Cop::Layout::IndentationWidth do
       end
     end
 
-    describe '#autocorrect' do
-      it 'corrects bad indentation' do
-        corrected = autocorrect_source(<<~RUBY)
-          if a1
-             b1
-             b1
-          elsif a2
-           b2
-          else
-              c
-          end
-        RUBY
-        # The second `b1` will be corrected by IndentationConsistency.
-        expect(corrected).to eq <<~RUBY
-          if a1
-              b1
-             b1
-          elsif a2
-              b2
-          else
-              c
-          end
-        RUBY
-      end
+    it 'registers and corrects offense for bad indentation' do
+      expect_offense(<<~RUBY)
+        if a1
+           b1
+        ^^^ Use 4 (not 3) spaces for indentation.
+           b1
+        elsif a2
+         b2
+        ^ Use 4 (not 1) spaces for indentation.
+        else
+            c
+        end
+      RUBY
+
+      # The second `b1` will be corrected by IndentationConsistency.
+      expect_correction(<<~RUBY)
+        if a1
+            b1
+           b1
+        elsif a2
+            b2
+        else
+            c
+        end
+      RUBY
     end
   end
 
@@ -129,8 +123,7 @@ RSpec.describe RuboCop::Cop::Layout::IndentationWidth do
         RUBY
       end
 
-      it 'registers an offense for bad indentation of an else body when if ' \
-         'body contains no code' do
+      it 'registers an offense for bad indentation of an else body when if body contains no code' do
         expect_offense(<<~RUBY)
           if cond
             # nothing here
@@ -217,6 +210,46 @@ RSpec.describe RuboCop::Cop::Layout::IndentationWidth do
         RUBY
       end
 
+      it 'accepts `rescue`/`ensure` after an empty body' do
+        expect_no_offenses(<<~RUBY)
+          begin
+          rescue
+            handle_error
+          ensure
+            something
+          end
+        RUBY
+      end
+
+      it 'accepts `rescue` after an empty def' do
+        expect_no_offenses(<<~RUBY)
+          def foo
+          rescue
+            handle_error
+          end
+        RUBY
+      end
+
+      it 'accepts `ensure` after an empty def' do
+        expect_no_offenses(<<~RUBY)
+          def foo
+          ensure
+            something
+          end
+        RUBY
+      end
+
+      it 'accepts `rescue`/`ensure` after an empty def' do
+        expect_no_offenses(<<~RUBY)
+          def foo
+          rescue
+            handle_error
+          ensure
+            something
+          end
+        RUBY
+      end
+
       it 'does not raise any error with empty braces' do
         expect_no_offenses(<<~RUBY)
           if cond
@@ -227,147 +260,155 @@ RSpec.describe RuboCop::Cop::Layout::IndentationWidth do
         RUBY
       end
 
-      describe '#autocorrect' do
-        it 'corrects bad indentation' do
-          corrected = autocorrect_source(<<~RUBY)
-            if a1
-               b1
-               b1
-            elsif a2
-             b2
-            else
-                c
-            end
-          RUBY
-          # The second `b1` will be corrected by IndentationConsistency.
-          expect(corrected).to eq <<~RUBY
-            if a1
-              b1
-               b1
-            elsif a2
-              b2
-            else
+      it 'registers and corrects on offense for bad indentation' do
+        expect_offense(<<~RUBY)
+          if a1
+             b1
+          ^^^ Use 2 (not 3) spaces for indentation.
+             b1
+          elsif a2
+           b2
+          ^ Use 2 (not 1) spaces for indentation.
+          else
               c
-            end
-          RUBY
-        end
+          ^^^^ Use 2 (not 4) spaces for indentation.
+          end
+        RUBY
 
-        it 'does not correct in scopes that contain block comments' do
-          source = <<~RUBY
-            module Foo
-            # The class has a block comment within, so it's not corrected.
-            class Bar
-            =begin
-            This is a nice long
-            comment
-            which spans a few lines
-            =end
-            # The method has no block comment inside,
-            # but it's within a class that has a block
-            # comment, so it's not corrected either.
+        # The second `b1` will be corrected by IndentationConsistency.
+        expect_correction(<<~RUBY)
+          if a1
+            b1
+             b1
+          elsif a2
+            b2
+          else
+            c
+          end
+        RUBY
+      end
+
+      it 'does not correct in scopes that contain block comments' do
+        expect_offense(<<~RUBY)
+          module Foo
+          # The class has a block comment within, so it's not corrected.
+          class Bar
+          ^{} Use 2 (not 0) spaces for indentation.
+          =begin
+          This is a nice long
+          comment
+          which spans a few lines
+          =end
+          # The method has no block comment inside,
+          # but it's within a class that has a block
+          # comment, so it's not corrected either.
+          def baz
+          ^{} Use 2 (not 0) spaces for indentation.
+          do_something
+          ^{} Use 2 (not 0) spaces for indentation.
+          end
+          end
+          end
+        RUBY
+
+        expect_no_corrections
+      end
+
+      it 'does not indent heredoc strings' do
+        expect_offense(<<~'RUBY')
+          module Foo
+          module Bar
+          ^{} Use 2 (not 0) spaces for indentation.
+            SOMETHING = <<GOO
+          text
+          more text
+          foo
+          GOO
             def baz
-            do_something
+              do_something("#{x}")
             end
-            end
-            end
-          RUBY
+          end
+          end
+        RUBY
 
-          expect(autocorrect_source(source)).to eq source
-        end
-
-        it 'does not indent heredoc strings' do
-          corrected = autocorrect_source(<<~'RUBY')
-            module Foo
+        expect_correction(<<~'RUBY')
+          module Foo
             module Bar
               SOMETHING = <<GOO
-            text
-            more text
-            foo
-            GOO
+          text
+          more text
+          foo
+          GOO
               def baz
                 do_something("#{x}")
               end
             end
-            end
-          RUBY
-          expect(corrected).to eq <<~'RUBY'
-            module Foo
-              module Bar
-                SOMETHING = <<GOO
-            text
-            more text
-            foo
-            GOO
-                def baz
-                  do_something("#{x}")
-                end
-              end
-            end
-          RUBY
-        end
+          end
+        RUBY
+      end
 
-        it 'indents parenthesized expressions' do
-          src = <<~RUBY
-            var1 = nil
-            array_list = []
-            if var1.attr1 != 0 || array_list.select{ |w|
-                                    (w.attr2 == var1.attr2)
-                             }.blank?
-              array_list << var1
-            end
-          RUBY
-          corrected = autocorrect_source(src)
-          expect(corrected)
-            .to eq <<~RUBY
-              var1 = nil
-              array_list = []
-              if var1.attr1 != 0 || array_list.select{ |w|
-                                 (w.attr2 == var1.attr2)
-                               }.blank?
-                array_list << var1
-              end
-            RUBY
-        end
+      it 'indents parenthesized expressions' do
+        expect_offense(<<~RUBY)
+          var1 = nil
+          array_list = []
+          if var1.attr1 != 0 || array_list.select{ |w|
+                                  (w.attr2 == var1.attr2)
+                           ^^^^^^^ Use 2 (not 7) spaces for indentation.
+                           }.blank?
+            array_list << var1
+          end
+        RUBY
 
-        it 'leaves rescue ; end unchanged' do
-          src = <<~RUBY
-            if variable
-              begin
-                do_something
-              rescue ; end # consume any exception
-            end
-          RUBY
-          corrected = autocorrect_source(src)
-          expect(corrected).to eq src
-        end
+        expect_correction(<<~RUBY)
+          var1 = nil
+          array_list = []
+          if var1.attr1 != 0 || array_list.select{ |w|
+                             (w.attr2 == var1.attr2)
+                           }.blank?
+            array_list << var1
+          end
+        RUBY
+      end
 
-        it 'leaves block unchanged if block end is not on its own line' do
-          src = <<~RUBY
-            a_function {
-              # a comment
-              result = AObject.find_by_attr(attr) if attr
-              result || AObject.make(
-                  :attr => attr,
-                  :attr2 => Other.get_value(),
-                  :attr3 => Another.get_value()) }
-          RUBY
-          corrected = autocorrect_source(src)
-          expect(corrected).to eq src
-        end
+      it 'leaves rescue ; end unchanged' do
+        expect_no_offenses(<<~RUBY)
+          if variable
+            begin
+              do_something
+            rescue ; end # consume any exception
+          end
+        RUBY
+      end
 
-        it 'handles lines with only whitespace' do
-          corrected = autocorrect_source(['def x',
-                                          '    y',
-                                          ' ',
-                                          'rescue',
-                                          'end'].join("\n"))
+      it 'leaves block unchanged if block end is not on its own line' do
+        expect_no_offenses(<<~RUBY)
+          a_function {
+            # a comment
+            result = AObject.find_by_attr(attr) if attr
+            result || AObject.make(
+                :attr => attr,
+                :attr2 => Other.get_value(),
+                :attr3 => Another.get_value()) }
+        RUBY
+      end
 
-          expect(corrected).to eq ['def x',
-                                   '  y',
-                                   ' ',
-                                   'rescue',
-                                   'end'].join("\n")
-        end
+      it 'handles lines with only whitespace' do
+        expect_offense(<<~RUBY)
+          def x
+              y
+          ^^^^ Use 2 (not 4) spaces for indentation.
+
+          rescue
+          end
+        RUBY
+
+        expect_correction(<<~RUBY)
+          def x
+            y
+
+          rescue
+          end
+        RUBY
       end
 
       it 'accepts a one line if statement' do
@@ -631,18 +672,20 @@ RSpec.describe RuboCop::Cop::Layout::IndentationWidth do
               RUBY
             end
 
-            it 'autocorrects bad indentation' do
-              corrected = autocorrect_source(<<~RUBY)
+            it 'registers and corrects bad indentation' do
+              expect_offense(<<~RUBY)
                 var = if a
                   b
+                  ^ Use 2 (not -4) spaces for indentation.
                 end
 
                 var = while a
                   b
+                  ^ Use 2 (not -4) spaces for indentation.
                 end
               RUBY
               # Not this cop's job to fix the `end`.
-              expect(corrected).to eq <<~RUBY
+              expect_correction(<<~RUBY)
                 var = if a
                         b
                 end
@@ -823,6 +866,101 @@ RSpec.describe RuboCop::Cop::Layout::IndentationWidth do
       end
     end
 
+    context 'with case match', :ruby27 do
+      it 'registers an offense for bad indentation in a case/in body' do
+        expect_offense(<<~RUBY)
+          case a
+          in b
+           c
+          ^ Use 2 (not 1) spaces for indentation.
+          end
+        RUBY
+      end
+
+      it 'registers an offense for bad indentation in a case/else body' do
+        expect_offense(<<~RUBY)
+          case a
+          in b
+            c
+          in d
+            e
+          else
+             f
+          ^^^ Use 2 (not 3) spaces for indentation.
+          end
+        RUBY
+      end
+
+      it 'accepts correctly indented case/in/else' do
+        expect_no_offenses(<<~RUBY)
+          case a
+          in b
+            c
+            c
+          in d
+          else
+            f
+          end
+        RUBY
+      end
+
+      it 'accepts aligned values in `in` clause' do
+        expect_no_offenses(<<~'RUBY')
+          case condition
+          in [42]
+            foo
+          in [43]
+            bar
+          end
+        RUBY
+      end
+
+      it 'accepts aligned value in `in` clause and `else` is empty' do
+        expect_no_offenses(<<~'RUBY')
+          case x
+          in 42
+            foo
+          else
+          end
+        RUBY
+      end
+
+      it 'accepts case/in/else laid out as a table' do
+        expect_no_offenses(<<~RUBY)
+          case sexp.loc.keyword.source
+          in 'if'     then cond, body, _else = *sexp
+          in 'unless' then cond, _else, body = *sexp
+          else             cond, body = *sexp
+          end
+        RUBY
+      end
+
+      it 'accepts case/in/else with then beginning a line' do
+        expect_no_offenses(<<~RUBY)
+          case sexp.loc.keyword.source
+          in 'if'
+          then cond, body, _else = *sexp
+          end
+        RUBY
+      end
+
+      it 'accepts indented in/else plus indented body' do
+        # "Indent `in` as deep as `case`" is the job of another cop.
+        expect_no_offenses(<<~RUBY)
+          case code_type
+            in 'ruby' | 'sql' | 'plain'
+              code_type
+            in 'erb'
+              'ruby; html-script: true'
+            in "html"
+              'xml'
+            else
+              'plain'
+          end
+        RUBY
+      end
+    end
+
     context 'with while/until' do
       it 'registers an offense for bad indentation of a while body' do
         expect_offense(<<~RUBY)
@@ -1067,6 +1205,18 @@ RSpec.describe RuboCop::Cop::Layout::IndentationWidth do
         RUBY
       end
 
+      it 'leaves body unchanged if the first body line is on the same line with class keyword' do
+        # The class body will be corrected by IndentationConsistency.
+        expect_no_offenses(<<~RUBY)
+          class Test foo
+              def func1
+              end
+                def func2
+                end
+          end
+        RUBY
+      end
+
       it 'accepts an empty class body' do
         expect_no_offenses(<<~RUBY)
           class Test
@@ -1074,6 +1224,18 @@ RSpec.describe RuboCop::Cop::Layout::IndentationWidth do
         RUBY
       end
 
+      it 'leaves body unchanged if the first body line is on the same line with an opening of singleton class' do
+        # The class body will be corrected by IndentationConsistency.
+        expect_no_offenses(<<~RUBY)
+          class << self; foo
+              def func1
+              end
+                def func2
+                end
+          end
+        RUBY
+      end
+
       context 'with access modifier' do
         it 'registers an offense for bad indentation of sections' do
           expect_offense(<<~RUBY)
@@ -1173,13 +1335,10 @@ RSpec.describe RuboCop::Cop::Layout::IndentationWidth do
       end
 
       context 'when consistency style is indented_internal_methods' do
-        let(:consistency_config) do
-          { 'EnforcedStyle' => 'indented_internal_methods' }
-        end
+        let(:consistency_config) { { 'EnforcedStyle' => 'indented_internal_methods' } }
 
-        it 'registers an offense for normal non-indented internal methods ' \
-           'indentation' do
-          inspect_source(<<~RUBY)
+        it 'registers an offense for normal non-indented internal methods indentation' do
+          expect_offense(<<~RUBY)
             class Test
               public
 
@@ -1189,22 +1348,21 @@ RSpec.describe RuboCop::Cop::Layout::IndentationWidth do
               protected
 
               def f
+              ^{} Use 2 (not 0) spaces for indented_internal_methods indentation.
               end
 
               private
 
               def g
+              ^{} Use 2 (not 0) spaces for indented_internal_methods indentation.
               end
             end
           RUBY
-          expect(cop.messages)
-            .to eq([indented_internal_methods_offense_message] * 2)
-          expect(cop.offenses.map(&:line)).to eq([9, 14])
         end
 
         it 'registers an offense for normal non-indented internal methods ' \
            'indentation when defined in a singleton class' do
-          inspect_source(<<~RUBY)
+          expect_offense(<<~RUBY)
             class << self
               public
 
@@ -1214,18 +1372,16 @@ RSpec.describe RuboCop::Cop::Layout::IndentationWidth do
               protected
 
               def f
+              ^{} Use 2 (not 0) spaces for indented_internal_methods indentation.
               end
 
               private
 
               def g
+              ^{} Use 2 (not 0) spaces for indented_internal_methods indentation.
               end
             end
           RUBY
-
-          expect(cop.messages)
-            .to eq([indented_internal_methods_offense_message] * 2)
-          expect(cop.offenses.map(&:line)).to eq([9, 14])
         end
       end
     end
@@ -1250,10 +1406,20 @@ RSpec.describe RuboCop::Cop::Layout::IndentationWidth do
         end
       end
 
+      it 'leaves body unchanged if the first body line is on the same line with module keyword' do
+        # The module body will be corrected by IndentationConsistency.
+        expect_no_offenses(<<~RUBY)
+          module Test foo
+              def func1
+              end
+                def func2
+                end
+          end
+        RUBY
+      end
+
       context 'when consistency style is indented_internal_methods' do
-        let(:consistency_config) do
-          { 'EnforcedStyle' => 'indented_internal_methods' }
-        end
+        let(:consistency_config) { { 'EnforcedStyle' => 'indented_internal_methods' } }
 
         it 'registers an offense for bad indentation of a module body' do
           expect_offense(<<~RUBY)
@@ -1269,8 +1435,7 @@ RSpec.describe RuboCop::Cop::Layout::IndentationWidth do
           RUBY
         end
 
-        it 'accepts normal non-indented internal methods of' \
-           'module functions' do
+        it 'accepts normal non-indented internal methods of module functions' do
           expect_no_offenses(<<~RUBY)
             module Test
               module_function
@@ -1284,27 +1449,27 @@ RSpec.describe RuboCop::Cop::Layout::IndentationWidth do
 
     context 'with begin/rescue/else/ensure/end' do
       it 'registers an offense for bad indentation of bodies' do
-        inspect_source(<<~RUBY)
+        expect_offense(<<~RUBY)
           def my_func
             puts 'do something outside block'
             begin
             puts 'do something error prone'
+            ^{} Use 2 (not 0) spaces for indentation.
             rescue SomeException, SomeOther => e
-             puts 'wrongly intended error handling'
+             puts 'wrongly indented error handling'
+            ^ Use 2 (not 1) spaces for indentation.
             rescue
-             puts 'wrongly intended error handling'
+             puts 'wrongly indented error handling'
+            ^ Use 2 (not 1) spaces for indentation.
             else
-               puts 'wrongly intended normal case handling'
+               puts 'wrongly indented normal case handling'
+            ^^^ Use 2 (not 3) spaces for indentation.
             ensure
-                puts 'wrongly intended common handling'
+                puts 'wrongly indented common handling'
+            ^^^^ Use 2 (not 4) spaces for indentation.
             end
           end
         RUBY
-        expect(cop.messages).to eq(['Use 2 (not 0) spaces for indentation.',
-                                    'Use 2 (not 1) spaces for indentation.',
-                                    'Use 2 (not 1) spaces for indentation.',
-                                    'Use 2 (not 3) spaces for indentation.',
-                                    'Use 2 (not 4) spaces for indentation.'])
       end
     end
 
@@ -1314,13 +1479,23 @@ RSpec.describe RuboCop::Cop::Layout::IndentationWidth do
           def my_func
             puts 'do something error prone'
           rescue SomeException
-           puts 'wrongly intended error handling'
+           puts 'wrongly indented error handling'
           ^ Use 2 (not 1) spaces for indentation.
           rescue
-           puts 'wrongly intended error handling'
+           puts 'wrongly indented error handling'
           ^ Use 2 (not 1) spaces for indentation.
           end
         RUBY
+
+        expect_correction(<<~RUBY)
+          def my_func
+            puts 'do something error prone'
+          rescue SomeException
+            puts 'wrongly indented error handling'
+          rescue
+            puts 'wrongly indented error handling'
+          end
+        RUBY
       end
 
       it 'registers an offense for bad indent of defs bodies with a modifier' do
@@ -1328,10 +1503,10 @@ RSpec.describe RuboCop::Cop::Layout::IndentationWidth do
           foo def self.my_func
             puts 'do something error prone'
           rescue SomeException
-           puts 'wrongly intended error handling'
+           puts 'wrongly indented error handling'
           ^ Use 2 (not 1) spaces for indentation.
           rescue
-           puts 'wrongly intended error handling'
+           puts 'wrongly indented error handling'
           ^ Use 2 (not 1) spaces for indentation.
           end
         RUBY
@@ -1340,12 +1515,10 @@ RSpec.describe RuboCop::Cop::Layout::IndentationWidth do
 
     context 'with block' do
       context 'when consistency style is indented_internal_methods' do
-        let(:consistency_config) do
-          { 'EnforcedStyle' => 'indented_internal_methods' }
-        end
+        let(:consistency_config) { { 'EnforcedStyle' => 'indented_internal_methods' } }
 
         it 'registers an offense for bad indentation in a do/end body' do
-          inspect_source(<<~RUBY)
+          expect_offense(<<~RUBY)
             concern :Authenticatable do
               def foo
                 puts "foo"
@@ -1354,12 +1527,11 @@ RSpec.describe RuboCop::Cop::Layout::IndentationWidth do
               private
 
               def bar
+              ^{} Use 2 (not 0) spaces for indented_internal_methods indentation.
                 puts "bar"
               end
             end
           RUBY
-          expect(cop.messages)
-            .to eq([indented_internal_methods_offense_message])
         end
       end
 
@@ -1396,6 +1568,27 @@ RSpec.describe RuboCop::Cop::Layout::IndentationWidth do
         RUBY
       end
 
+      it 'does not register an offense for good indentation of `do` ... `ensure` ... `end` block' do
+        expect_no_offenses(<<~RUBY)
+          do_something do
+            foo
+          ensure
+            handle_error
+          end
+        RUBY
+      end
+
+      it 'registers an offense for bad indentation of `do` ... `ensure` ... `end` block' do
+        expect_offense(<<~RUBY)
+          do_something do
+              foo
+          ^^^^ Use 2 (not 4) spaces for indentation.
+          ensure
+            handle_error
+          end
+        RUBY
+      end
+
       context 'when using safe navigation operator' do
         it 'registers an offense for bad indentation of a {} body' do
           expect_offense(<<~RUBY)
@@ -1416,6 +1609,26 @@ RSpec.describe RuboCop::Cop::Layout::IndentationWidth do
         end
       end
 
+      context 'Ruby 2.7', :ruby27 do
+        it 'registers an offense for bad indentation of a {} body' do
+          expect_offense(<<~RUBY)
+            func {
+               _1&.foo
+            ^^^ Use 2 (not 3) spaces for indentation.
+            }
+          RUBY
+        end
+
+        it 'registers an offense for bad indentation of a do-end body' do
+          expect_offense(<<~RUBY)
+            func do
+               _1&.foo
+            ^^^ Use 2 (not 3) spaces for indentation.
+            end
+          RUBY
+        end
+      end
+
       # The cop uses the block end/} as the base for indentation, so if it's not
       # on its own line, all bets are off.
       it 'accepts badly indented code if block end is not on separate line' do
