@@ -1,8 +1,6 @@
 # frozen_string_literal: true
 
-RSpec.describe RuboCop::Cop::Layout::MultilineOperationIndentation do
-  subject(:cop) { described_class.new(config) }
-
+RSpec.describe RuboCop::Cop::Layout::MultilineOperationIndentation, :config do
   let(:config) do
     merged = RuboCop::ConfigLoader
              .default_configuration['Layout/MultilineOperationIndentation']
@@ -56,8 +54,7 @@ RSpec.describe RuboCop::Cop::Layout::MultilineOperationIndentation do
       RUBY
     end
 
-    it 'registers an offense and corrects one space indentation ' \
-      'of second line' do
+    it 'registers an offense and corrects one space indentation of second line' do
       expect_offense(<<~RUBY)
         a +
          b
@@ -83,14 +80,18 @@ RSpec.describe RuboCop::Cop::Layout::MultilineOperationIndentation do
         .a
           .b(c)
 
+        Foo.&(
+            foo,
+            bar
+        )
+
         expect { Foo.new }.
           to change { Bar.count }.
               from(1).to(2)
       RUBY
     end
 
-    it 'registers an offense and corrects three space indentation ' \
-      'of second line' do
+    it 'registers an offense and corrects three space indentation of second line' do
       expect_offense(<<~RUBY)
         a ||
            b
@@ -124,7 +125,7 @@ RSpec.describe RuboCop::Cop::Layout::MultilineOperationIndentation do
     end
 
     it 'registers an offense and corrects emacs ruby-mode 1.1 indentation of ' \
-    'an expression in an array' do
+       'an expression in an array' do
       expect_offense(<<~RUBY)
         [
          a +
@@ -216,7 +217,7 @@ RSpec.describe RuboCop::Cop::Layout::MultilineOperationIndentation do
     end
 
     it 'registers an offense and corrects an unindented multiline operation ' \
-      'that is the left operand in another operation' do
+       'that is the left operand in another operation' do
       expect_offense(<<~RUBY)
         a +
         b < 3
@@ -309,8 +310,7 @@ RSpec.describe RuboCop::Cop::Layout::MultilineOperationIndentation do
       RUBY
     end
 
-    it 'registers an offense and corrects indented operand ' \
-      'in second argument' do
+    it 'registers an offense and corrects indented operand in second argument' do
       expect_offense(<<~RUBY)
         puts a, 1 +
           2
@@ -324,7 +324,7 @@ RSpec.describe RuboCop::Cop::Layout::MultilineOperationIndentation do
     end
 
     it 'registers an offense and corrects misaligned string operand ' \
-      'when the first operand has backslash continuation' do
+       'when the first operand has backslash continuation' do
       expect_offense(<<~'RUBY')
         def f
           flash[:error] = 'Here is a string ' \
@@ -343,8 +343,7 @@ RSpec.describe RuboCop::Cop::Layout::MultilineOperationIndentation do
       RUBY
     end
 
-    it 'registers an offense and corrects misaligned string operand ' \
-      'when plus is used' do
+    it 'registers an offense and corrects misaligned string operand when plus is used' do
       expect_offense(<<~RUBY)
         Error = 'Here is a string ' +
                 'That spans' <<
@@ -359,8 +358,7 @@ RSpec.describe RuboCop::Cop::Layout::MultilineOperationIndentation do
       RUBY
     end
 
-    it 'registers an offense and corrects misaligned operands ' \
-      'in unless condition' do
+    it 'registers an offense and corrects misaligned operands in unless condition' do
       expect_offense(<<~RUBY)
         unless a +
           b
@@ -383,8 +381,7 @@ RSpec.describe RuboCop::Cop::Layout::MultilineOperationIndentation do
       %w[a while],
       %w[an until]
     ].each do |article, keyword|
-      it "registers an offense for misaligned operands in #{keyword} " \
-         'condition' do
+      it "registers an offense for misaligned operands in #{keyword} condition" do
         expect_offense(<<~RUBY)
           #{keyword} a or
               b
@@ -410,8 +407,7 @@ RSpec.describe RuboCop::Cop::Layout::MultilineOperationIndentation do
       RUBY
     end
 
-    it 'registers an offense and corrects unaligned operands ' \
-      'in op-assignment' do
+    it 'registers an offense and corrects unaligned operands in op-assignment' do
       expect_offense(<<~RUBY)
         bar *= Foo +
           a +
@@ -490,8 +486,7 @@ RSpec.describe RuboCop::Cop::Layout::MultilineOperationIndentation do
       RUBY
     end
 
-    it 'registers an offense and corrects aligned code on LHS ' \
-      'of equality operator' do
+    it 'registers an offense and corrects aligned code on LHS of equality operator' do
       expect_offense(<<~RUBY)
         def config_to_allow_offenses
           a +
@@ -526,8 +521,7 @@ RSpec.describe RuboCop::Cop::Layout::MultilineOperationIndentation do
         RUBY
       end
 
-      it "registers an offense for a 2 space indentation of #{keyword} " \
-         'condition' do
+      it "registers an offense for a 2 space indentation of #{keyword} condition" do
         expect_offense(<<~RUBY)
           #{keyword} receiver.nil? &&
             !args.empty? &&
@@ -565,8 +559,7 @@ RSpec.describe RuboCop::Cop::Layout::MultilineOperationIndentation do
       end
     end
 
-    it 'registers an offense and corrects wrong indentation ' \
-      'of for expression' do
+    it 'registers an offense and corrects wrong indentation of for expression' do
       expect_offense(<<~RUBY)
         for n in a +
           b
@@ -664,8 +657,7 @@ RSpec.describe RuboCop::Cop::Layout::MultilineOperationIndentation do
           RUBY
         end
 
-        it "registers an offense for a 4 space indentation of #{keyword} " \
-           'condition' do
+        it "registers an offense for a 4 space indentation of #{keyword} condition" do
           expect_offense(<<~RUBY)
             #{keyword} receiver.nil? &&
                 !args.empty? &&
