@@ -1,8 +1,6 @@
 # frozen_string_literal: true
 
-RSpec.describe RuboCop::Cop::Layout::SpaceAfterColon do
-  subject(:cop) { described_class.new }
-
+RSpec.describe RuboCop::Cop::Layout::SpaceAfterColon, :config do
   it 'registers an offense and corrects colon without space after it' do
     expect_offense(<<~RUBY)
       {a:3}
@@ -56,8 +54,7 @@ RSpec.describe RuboCop::Cop::Layout::SpaceAfterColon do
     RUBY
   end
 
-  it 'registers an offense and corrects a keyword optional ' \
-    'argument without a space' do
+  it 'registers an offense and corrects a keyword optional argument without a space' do
     expect_offense(<<~RUBY)
       def m(var:1, other_var: 2)
                ^ Space missing after colon.
@@ -69,4 +66,16 @@ RSpec.describe RuboCop::Cop::Layout::SpaceAfterColon do
       end
     RUBY
   end
+
+  context 'Ruby >= 3.1', :ruby31 do
+    it 'does not register an offense colon without space after it when using hash value omission' do
+      expect_no_offenses('{x:, y:}')
+    end
+
+    it 'accepts colons denoting hash value omission argument' do
+      expect_no_offenses(<<~RUBY)
+        foo(table:, nodes:)
+      RUBY
+    end
+  end
 end
