@@ -1,11 +1,10 @@
 # frozen_string_literal: true
 
-RSpec.describe RuboCop::Cop::Layout::SpaceAroundOperators do
-  subject(:cop) { described_class.new(config) }
-
+RSpec.describe RuboCop::Cop::Layout::SpaceAroundOperators, :config do
   let(:config) do
     RuboCop::Config
       .new(
+        'AllCops' => { 'TargetRubyVersion' => target_ruby_version },
         'Layout/HashAlignment' => { 'EnforcedHashRocketStyle' => hash_style },
         'Layout/SpaceAroundOperators' => {
           'AllowForAlignment' => allow_for_alignment,
@@ -13,6 +12,7 @@ RSpec.describe RuboCop::Cop::Layout::SpaceAroundOperators do
         }
       )
   end
+  let(:target_ruby_version) { 2.5 }
   let(:hash_style) { 'key' }
   let(:allow_for_alignment) { true }
   let(:exponent_operator_style) { nil }
@@ -129,6 +129,23 @@ RSpec.describe RuboCop::Cop::Layout::SpaceAroundOperators do
     expect_no_offenses('x = 0')
   end
 
+  it 'accepts an assignment with the same alignment margins' do
+    expect_no_offenses(<<~RUBY)
+      @integer_message = 12345
+      @output  = StringIO.new
+      @logger  = Logger.new(@output)
+    RUBY
+  end
+
+  it 'accepts an assignment with a blank line' do
+    expect_no_offenses(<<~RUBY)
+      expected = posts(:welcome)
+
+      tagging  = Tagging.all.merge!(includes: :taggable).find(taggings(:welcome_general).id)
+      assert_no_queries { assert_equal expected, tagging.taggable }
+    RUBY
+  end
+
   it 'accepts an assignment by `for` statement' do
     expect_no_offenses(<<~RUBY)
       for a in [] do; end
@@ -189,6 +206,32 @@ RSpec.describe RuboCop::Cop::Layout::SpaceAroundOperators do
     expect_no_offenses('x = a * b**2')
   end
 
+  context '>= Ruby 2.7', :ruby27 do
+    let(:target_ruby_version) { 2.7 }
+
+    # NOTE: It is `Layout/SpaceAroundKeyword` cop's role to detect this offense.
+    it 'does not register an offenses for one-line pattern matching syntax (`in`)' do
+      expect_no_offenses(<<~RUBY)
+        ""in foo
+      RUBY
+    end
+  end
+
+  context '>= Ruby 3.0', :ruby30 do
+    let(:target_ruby_version) { 3.0 }
+
+    it 'registers an offenses for one-line pattern matching syntax (`=>`)' do
+      expect_offense(<<~RUBY)
+        ""=>foo
+          ^^ Surrounding space missing for operator `=>`.
+      RUBY
+
+      expect_correction(<<~RUBY)
+        "" => foo
+      RUBY
+    end
+  end
+
   context 'when EnforcedStyleForExponentOperator is space' do
     let(:exponent_operator_style) { 'space' }
 
@@ -235,9 +278,15 @@ RSpec.describe RuboCop::Cop::Layout::SpaceAroundOperators do
     RUBY
   end
 
-  it 'accepts the construct class <<self with no space after <<' do
-    expect_no_offenses(<<~RUBY)
-      class <<self
+  it 'registers an offense and corrects singleton class operator`' do
+    expect_offense(<<~RUBY)
+      class<<self
+           ^^ Surrounding space missing for operator `<<`.
+      end
+    RUBY
+
+    expect_correction(<<~RUBY)
+      class << self
       end
     RUBY
   end
@@ -245,18 +294,14 @@ RSpec.describe RuboCop::Cop::Layout::SpaceAroundOperators do
   describe 'missing space around operators' do
     shared_examples 'modifier with missing space' do |keyword|
       it "registers an offense in presence of modifier #{keyword} statement" do
-        src = <<~RUBY
+        expect_offense(<<~RUBY)
           a=1 #{keyword} condition
+           ^ Surrounding space missing for operator `=`.
           c=2
+           ^ Surrounding space missing for operator `=`.
         RUBY
-        inspect_source(src)
-        expect(cop.offenses.map(&:line)).to eq([1, 2])
-        expect(cop.messages).to eq(
-          ['Surrounding space missing for operator `=`.'] * 2
-        )
 
-        new_source = autocorrect_source(src)
-        expect(new_source).to eq(<<~RUBY)
+        expect_correction(<<~RUBY)
           a = 1 #{keyword} condition
           c = 2
         RUBY
@@ -293,8 +338,7 @@ RSpec.describe RuboCop::Cop::Layout::SpaceAroundOperators do
         RUBY
       end
 
-      it 'registers an offense and corrects operators with ' \
-        'just a trailing space' do
+      it 'registers an offense and corrects operators with just a trailing space' do
         expect_offense(<<~RUBY)
           x == 0? 1: 2
                    ^ Surrounding space missing for operator `:`.
@@ -306,8 +350,7 @@ RSpec.describe RuboCop::Cop::Layout::SpaceAroundOperators do
         RUBY
       end
 
-      it 'registers an offense and corrects operators with ' \
-        'just a leading space' do
+      it 'registers an offense and corrects operators with just a leading space' do
         expect_offense(<<~RUBY)
           x == 0 ?1 :2
                     ^ Surrounding space missing for operator `:`.
@@ -525,8 +568,7 @@ RSpec.describe RuboCop::Cop::Layout::SpaceAroundOperators do
       RUBY
     end
 
-    it 'registers an offense and corrects `-` without space with a negative ' \
-      'lhs operand' do
+    it 'registers an offense and corrects `-` without space with a negative lhs operand' do
       expect_offense(<<~RUBY)
         -1-arg
           ^ Surrounding space missing for operator `-`.
@@ -550,8 +592,7 @@ RSpec.describe RuboCop::Cop::Layout::SpaceAroundOperators do
       RUBY
     end
 
-    it 'registers an offense and corrects hash rocket without ' \
-      'space at rescue' do
+    it 'registers an offense and corrects hash rocket without space at rescue' do
       expect_offense(<<~RUBY)
         begin
         rescue Exception=>e
@@ -566,8 +607,7 @@ RSpec.describe RuboCop::Cop::Layout::SpaceAroundOperators do
       RUBY
     end
 
-    it 'registers an offense and corrects string concatenation ' \
-      'without messing up new lines' do
+    it 'registers an offense and corrects string concatenation without messing up new lines' do
       expect_offense(<<~RUBY)
         'Here is a'+
                    ^ Surrounding space missing for operator `+`.
@@ -595,26 +635,21 @@ RSpec.describe RuboCop::Cop::Layout::SpaceAroundOperators do
   describe 'extra space around operators' do
     shared_examples 'modifier with extra space' do |keyword|
       it "registers an offense in presence of modifier #{keyword} statement" do
-        src = <<~RUBY
+        expect_offense(<<~RUBY)
           a =  1 #{keyword} condition
+            ^ Operator `=` should be surrounded by a single space.
           c =   2
+            ^ Operator `=` should be surrounded by a single space.
         RUBY
-        inspect_source(src)
-        expect(cop.offenses.map(&:line)).to eq([1, 2])
-        expect(cop.messages).to eq(
-          ['Operator `=` should be surrounded by a single space.'] * 2
-        )
 
-        new_source = autocorrect_source(src)
-        expect(new_source).to eq(<<~RUBY)
+        expect_correction(<<~RUBY)
           a = 1 #{keyword} condition
           c = 2
         RUBY
       end
     end
 
-    it 'registers an offense and corrects assignment with ' \
-      'too many spaces on either side' do
+    it 'registers an offense and corrects assignment with too many spaces on either side' do
       expect_offense(<<~RUBY)
         x   = 0
             ^ Operator `=` should be surrounded by a single space.
@@ -631,8 +666,7 @@ RSpec.describe RuboCop::Cop::Layout::SpaceAroundOperators do
       RUBY
     end
 
-    it 'registers an offense and corrects ternary operator with ' \
-      'too many spaces' do
+    it 'registers an offense and corrects ternary operator with too many spaces' do
       expect_offense(<<~RUBY)
         x == 0  ? 1 :  2
                     ^ Operator `:` should be surrounded by a single space.
@@ -649,8 +683,7 @@ RSpec.describe RuboCop::Cop::Layout::SpaceAroundOperators do
     it_behaves_like 'modifier with extra space', 'while'
     it_behaves_like 'modifier with extra space', 'until'
 
-    it 'registers an offense and corrects binary operators ' \
-      'that could be unary' do
+    it 'registers an offense and corrects binary operators that could be unary' do
       expect_offense(<<~RUBY)
         a -  3
           ^ Operator `-` should be surrounded by a single space.
@@ -720,8 +753,7 @@ RSpec.describe RuboCop::Cop::Layout::SpaceAroundOperators do
       RUBY
     end
 
-    it 'registers an offense and corrects operators with ' \
-      'too many spaces on the same line' do
+    it 'registers an offense and corrects operators with too many spaces on the same line' do
       expect_offense(<<~RUBY)
         x +=  a  + b -  c  * d /  e  % f  ^ g   | h &  i  ||  j
                                                           ^^ Operator `||` should be surrounded by a single space.
@@ -767,8 +799,7 @@ RSpec.describe RuboCop::Cop::Layout::SpaceAroundOperators do
       RUBY
     end
 
-    it 'registers an offense and corrects a hash rocket with an extra space' \
-      'on multiple line' do
+    it 'registers an offense and corrects a hash rocket with an extra spaceon multiple line' do
       expect_offense(<<~RUBY)
         {
           1 =>  2
@@ -783,8 +814,7 @@ RSpec.describe RuboCop::Cop::Layout::SpaceAroundOperators do
       RUBY
     end
 
-    it 'accepts for a hash rocket with an extra space for alignment' \
-      'on multiple line' do
+    it 'accepts for a hash rocket with an extra space for alignment on multiple line' do
       expect_no_offenses(<<~RUBY)
         {
           1 =>  2,
@@ -814,8 +844,7 @@ RSpec.describe RuboCop::Cop::Layout::SpaceAroundOperators do
       end
     end
 
-    it 'registers an offense and corrects match operators ' \
-      'with too many spaces' do
+    it 'registers an offense and corrects match operators with too many spaces' do
       expect_offense(<<~RUBY)
         x  =~ /abc/
            ^^ Operator `=~` should be surrounded by a single space.
@@ -829,8 +858,21 @@ RSpec.describe RuboCop::Cop::Layout::SpaceAroundOperators do
       RUBY
     end
 
-    it 'registers an offense and corrects various assignments ' \
-      'with too many spaces' do
+    it 'does not register an offenses match operators between `<<` and `+=`' do
+      expect_no_offenses(<<~RUBY)
+        x  << foo
+        yz += bar
+      RUBY
+    end
+
+    it 'does not register an offenses match operators between `+=` and `<<`' do
+      expect_no_offenses(<<~RUBY)
+        x  += foo
+        yz << bar
+      RUBY
+    end
+
+    it 'registers an offense and corrects various assignments with too many spaces' do
       expect_offense(<<~RUBY)
         x ||=  0
           ^^^ Operator `||=` should be surrounded by a single space.
@@ -871,8 +913,7 @@ RSpec.describe RuboCop::Cop::Layout::SpaceAroundOperators do
       RUBY
     end
 
-    it 'registers an offense and corrects equality operators ' \
-      'with too many spaces' do
+    it 'registers an offense and corrects equality operators with too many spaces' do
       expect_offense(<<~RUBY)
         x  ==  0
            ^^ Operator `==` should be surrounded by a single space.
@@ -889,8 +930,7 @@ RSpec.describe RuboCop::Cop::Layout::SpaceAroundOperators do
       RUBY
     end
 
-    it 'registers an offense and corrects `-` with too many spaces with ' \
-       'negative lhs operand' do
+    it 'registers an offense and corrects `-` with too many spaces with negative lhs operand' do
       expect_offense(<<~RUBY)
         -1  - arg
             ^ Operator `-` should be surrounded by a single space.
@@ -914,8 +954,7 @@ RSpec.describe RuboCop::Cop::Layout::SpaceAroundOperators do
       RUBY
     end
 
-    it 'registers an offense and corrects hash rocket with ' \
-      'too many spaces at rescue' do
+    it 'registers an offense and corrects hash rocket with too many spaces at rescue' do
       expect_offense(<<~RUBY)
         begin
         rescue Exception   =>      e
@@ -930,4 +969,28 @@ RSpec.describe RuboCop::Cop::Layout::SpaceAroundOperators do
       RUBY
     end
   end
+
+  describe 'when Layout/ExtraSpacing has `ForceEqualSignAlignment` configured to true' do
+    let(:other_cops) do
+      { 'Layout/ExtraSpacing' => { 'Enabled' => true, 'ForceEqualSignAlignment' => true } }
+    end
+
+    it 'allows variables to be aligned' do
+      expect_no_offenses(<<~RUBY)
+        first  = {
+          x: y
+        }.freeze
+        second = true
+      RUBY
+    end
+
+    it 'allows constants to be aligned' do
+      expect_no_offenses(<<~RUBY)
+        FIRST  = {
+          x: y
+        }.freeze
+        SECOND = true
+      RUBY
+    end
+  end
 end
