@@ -1,10 +1,7 @@
 # frozen_string_literal: true
 
-RSpec.describe RuboCop::Cop::Layout::SpaceBeforeComma do
-  subject(:cop) { described_class.new }
-
-  it 'registers an offense and corrects block argument ' \
-    'with space before comma' do
+RSpec.describe RuboCop::Cop::Layout::SpaceBeforeComma, :config do
+  it 'registers an offense and corrects block argument with space before comma' do
     expect_offense(<<~RUBY)
       each { |s , t| }
                ^ Space found before comma.
@@ -26,8 +23,7 @@ RSpec.describe RuboCop::Cop::Layout::SpaceBeforeComma do
     RUBY
   end
 
-  it 'registers an offense and corrects method call arg ' \
-    'with space before comma' do
+  it 'registers an offense and corrects method call arg with space before comma' do
     expect_offense(<<~RUBY)
       a(1 , 2)
          ^ Space found before comma.
@@ -54,4 +50,21 @@ RSpec.describe RuboCop::Cop::Layout::SpaceBeforeComma do
       each { |s, t| a(1, formats[0, 1])}
     RUBY
   end
+
+  context 'heredocs' do
+    it 'registers an offense and corrects' do
+      expect_offense(<<~RUBY)
+        a(<<~STR , 2)
+                ^ Space found before comma.
+          text
+        STR
+      RUBY
+
+      expect_correction(<<~RUBY)
+        a(<<~STR, 2)
+          text
+        STR
+      RUBY
+    end
+  end
 end
