@@ -1,8 +1,6 @@
 # frozen_string_literal: true
 
-RSpec.describe RuboCop::Cop::Layout::SpaceBeforeComment do
-  subject(:cop) { described_class.new }
-
+RSpec.describe RuboCop::Cop::Layout::SpaceBeforeComment, :config do
   it 'registers an offense and corrects missing space before an EOL comment' do
     expect_offense(<<~RUBY)
       a += 1# increment
@@ -29,4 +27,19 @@ RSpec.describe RuboCop::Cop::Layout::SpaceBeforeComment do
       =end
     RUBY
   end
+
+  it 'registers an offense and corrects after a heredoc' do
+    expect_offense(<<~RUBY)
+      <<~STR# my string
+            ^^^^^^^^^^^ Put a space before an end-of-line comment.
+        text
+      STR
+    RUBY
+
+    expect_correction(<<~RUBY)
+      <<~STR # my string
+        text
+      STR
+    RUBY
+  end
 end
