@@ -1,21 +1,21 @@
 # frozen_string_literal: true
 
-RSpec.describe RuboCop::Cop::Lint::EmptyEnsure do
-  subject(:cop) { described_class.new }
-
+RSpec.describe RuboCop::Cop::Lint::EmptyEnsure, :config do
   it 'registers an offense and corrects empty ensure' do
     expect_offense(<<~RUBY)
       begin
         something
-      ensure
+      ensure # hello
       ^^^^^^ Empty `ensure` block detected.
+        # world
       end
     RUBY
 
     expect_correction(<<~RUBY)
       begin
         something
-
+       # hello
+        # world
       end
     RUBY
   end
