@@ -1,8 +1,6 @@
 # frozen_string_literal: true
 
-RSpec.describe RuboCop::Cop::Lint::EnsureReturn do
-  subject(:cop) { described_class.new }
-
+RSpec.describe RuboCop::Cop::Lint::EnsureReturn, :config do
   it 'registers an offense and corrects for return in ensure' do
     expect_offense(<<~RUBY)
       begin
