@@ -1,10 +1,6 @@
 # frozen_string_literal: true
 
-RSpec.describe RuboCop::Cop::Lint::RegexpAsCondition do
-  subject(:cop) { described_class.new(config) }
-
-  let(:config) { RuboCop::Config.new }
-
+RSpec.describe RuboCop::Cop::Lint::RegexpAsCondition, :config do
   it 'registers an offense and corrects for a regexp literal in `if` condition' do
     expect_offense(<<~RUBY)
       if /foo/
