@@ -1,8 +1,6 @@
 # frozen_string_literal: true
 
-RSpec.describe RuboCop::Cop::Lint::SafeNavigationWithEmpty do
-  subject(:cop) { described_class.new }
-
+RSpec.describe RuboCop::Cop::Lint::SafeNavigationWithEmpty, :config do
   context 'in a conditional' do
     it 'registers an offense and corrects on `&.empty?`' do
       expect_offense(<<~RUBY)
