@@ -1,14 +1,10 @@
 # frozen_string_literal: true
 
-RSpec.describe RuboCop::Cop::Lint::ToJSON do
-  subject(:cop) { described_class.new(config) }
-
-  let(:config) { RuboCop::Config.new }
-
+RSpec.describe RuboCop::Cop::Lint::ToJSON, :config do
   it 'registers an offense and corrects using `#to_json` without arguments' do
     expect_offense(<<~RUBY)
       def to_json
-      ^^^^^^^^^^^  `#to_json` requires an optional argument to be parsable via JSON.generate(obj).
+      ^^^^^^^^^^^ `#to_json` requires an optional argument to be parsable via JSON.generate(obj).
       end
     RUBY
 
