@@ -1,10 +1,6 @@
 # frozen_string_literal: true
 
-RSpec.describe RuboCop::Cop::Lint::UselessAccessModifier do
-  subject(:cop) { described_class.new(config) }
-
-  let(:config) { RuboCop::Config.new }
-
+RSpec.describe RuboCop::Cop::Lint::UselessAccessModifier, :config do
   context 'when an access modifier has no effect' do
     it 'registers an offense and corrects' do
       expect_offense(<<~RUBY)
@@ -72,8 +68,7 @@ RSpec.describe RuboCop::Cop::Lint::UselessAccessModifier do
     end
   end
 
-  context 'when an access modifier is followed by a ' \
-    'class method defined on constant' do
+  context 'when an access modifier is followed by a class method defined on constant' do
     it 'registers an offense and corrects' do
       expect_offense(<<~RUBY)
         class SomeClass
@@ -184,8 +179,7 @@ RSpec.describe RuboCop::Cop::Lint::UselessAccessModifier do
     end
   end
 
-  context 'when only a constant or local variable is defined after the ' \
-    'modifier' do
+  context 'when only a constant or local variable is defined after the modifier' do
     %w[CONSTANT some_var].each do |binding_name|
       it 'registers an offense and corrects' do
         expect_offense(<<~RUBY)
@@ -335,6 +329,42 @@ RSpec.describe RuboCop::Cop::Lint::UselessAccessModifier do
          end
       RUBY
     end
+
+    context 'Ruby 2.7', :ruby27 do
+      it 'still points out redundant uses within the block' do
+        expect_offense(<<~RUBY)
+          class SomeClass
+            concerning :SecondThing do
+              p _1
+              def omg
+              end
+              private
+              def method
+              end
+              private
+              ^^^^^^^ Useless `private` access modifier.
+              def another_method
+              end
+            end
+           end
+        RUBY
+
+        expect_correction(<<~RUBY)
+          class SomeClass
+            concerning :SecondThing do
+              p _1
+              def omg
+              end
+              private
+              def method
+              end
+              def another_method
+              end
+            end
+           end
+        RUBY
+      end
+    end
   end
 
   context 'when using ActiveSupport behavior when Rails is not eabled' do
@@ -601,7 +631,7 @@ RSpec.describe RuboCop::Cop::Lint::UselessAccessModifier do
   end
 
   shared_examples 'method named by access modifier name' do |keyword, modifier|
-    it "registers an offense for `#{modifier}`" do
+    it "does not register an offense for `#{modifier}`" do
       expect_no_offenses(<<~RUBY)
         #{keyword} A
           def foo
@@ -714,8 +744,7 @@ RSpec.describe RuboCop::Cop::Lint::UselessAccessModifier do
         RUBY
       end
 
-      it "doesn't register an offense if the modifier is the same as " \
-        'outside the meta-class' do
+      it "doesn't register an offense if the modifier is the same as outside the meta-class" do
         expect_no_offenses(<<~RUBY)
           #{keyword} A
             #{modifier}
@@ -754,8 +783,7 @@ RSpec.describe RuboCop::Cop::Lint::UselessAccessModifier do
         RUBY
       end
 
-      it 'registers an offense even if a non-singleton-class method is ' \
-        'defined' do
+      it 'registers an offense even if a non-singleton-class method is defined' do
         expect_offense(<<~RUBY, modifier: modifier)
           #{keyword} A
             def method1
@@ -823,8 +851,7 @@ RSpec.describe RuboCop::Cop::Lint::UselessAccessModifier do
     end
 
     context 'inside a class' do
-      it 'registers an offense when a modifier is ouside the block and a ' \
-        'method is defined only inside the block' do
+      it 'registers an offense when a modifier is outside the block and a method is defined only inside the block' do
         expect_offense(<<~RUBY, modifier: modifier)
           class A
             %{modifier}
@@ -837,8 +864,7 @@ RSpec.describe RuboCop::Cop::Lint::UselessAccessModifier do
         RUBY
       end
 
-      it 'registers two offenses when a modifier is inside and outside the ' \
-        ' block and no method is defined' do
+      it 'registers two offenses when a modifier is inside and outside the block and no method is defined' do
         expect_offense(<<~RUBY, modifier: modifier)
           class A
             %{modifier}
@@ -895,8 +921,8 @@ RSpec.describe RuboCop::Cop::Lint::UselessAccessModifier do
     end
 
     context 'inside a class' do
-      it 'registers an offense when a modifier is ouside the block and a ' \
-        'method is defined only inside the block' do
+      it 'registers an offense when a modifier is outside the block and a ' \
+         'method is defined only inside the block' do
         expect_offense(<<~RUBY, modifier: modifier)
           class A
             %{modifier}
@@ -909,8 +935,7 @@ RSpec.describe RuboCop::Cop::Lint::UselessAccessModifier do
         RUBY
       end
 
-      it 'registers two offenses when a modifier is inside and outside the ' \
-        ' and no method is defined' do
+      it 'registers two offenses when a modifier is inside and outside the and no method is defined' do
         expect_offense(<<~RUBY, modifier: modifier)
           class A
             %{modifier}
