@@ -15,12 +15,12 @@ RSpec.describe RuboCop::Cop::Security::YAMLLoad, :config do
 
   it 'registers an offense and corrects load with a literal string' do
     expect_offense(<<~RUBY)
-      YAML.load("--- foo")
+      YAML.load("--- !ruby/object:Foo {}")
            ^^^^ Prefer using `YAML.safe_load` over `YAML.load`.
     RUBY
 
     expect_correction(<<~RUBY)
-      YAML.safe_load("--- foo")
+      YAML.safe_load("--- !ruby/object:Foo {}")
     RUBY
   end
 
@@ -34,4 +34,20 @@ RSpec.describe RuboCop::Cop::Security::YAMLLoad, :config do
       ::YAML.safe_load("--- foo")
     RUBY
   end
+
+  # Ruby 3.1+ (Psych 4) uses `Psych.load` as `Psych.safe_load` by default.
+  # https://github.com/ruby/psych/pull/487
+  context 'Ruby >= 3.1', :ruby31 do
+    it 'does not register an offense and corrects load with a literal string' do
+      expect_no_offenses(<<~RUBY)
+        YAML.load("--- !ruby/object:Foo {}", permitted_classes: [Foo])
+      RUBY
+    end
+
+    it 'does not register an offense and corrects a fully qualified `::YAML.load`' do
+      expect_no_offenses(<<~RUBY)
+        ::YAML.load("--- !ruby/object:Foo {}", permitted_classes: [Foo])
+      RUBY
+    end
+  end
 end
