@@ -1,8 +1,6 @@
 # frozen_string_literal: true
 
-RSpec.describe RuboCop::Cop::Style::ArrayJoin do
-  subject(:cop) { described_class.new }
-
+RSpec.describe RuboCop::Cop::Style::ArrayJoin, :config do
   it 'registers an offense for an array followed by string' do
     expect_offense(<<~RUBY)
       %w(one two three) * ", "
@@ -19,6 +17,7 @@ RSpec.describe RuboCop::Cop::Style::ArrayJoin do
       %w(one two three)*", "
                        ^ Favor `Array#join` over `Array#*`.
     RUBY
+
     expect_correction(<<~RUBY)
       %w(one two three).join(", ")
     RUBY
@@ -29,6 +28,7 @@ RSpec.describe RuboCop::Cop::Style::ArrayJoin do
       foo = %w(one two three)*", "
                              ^ Favor `Array#join` over `Array#*`.
     RUBY
+
     expect_correction(<<~RUBY)
       foo = %w(one two three).join(", ")
     RUBY
