@@ -1,8 +1,6 @@
 # frozen_string_literal: true
 
-RSpec.describe RuboCop::Cop::Style::AsciiComments do
-  subject(:cop) { described_class.new }
-
+RSpec.describe RuboCop::Cop::Style::AsciiComments, :config do
   it 'registers an offense for a comment with non-ascii chars' do
     expect_offense(<<~RUBY)
       # 这是什么？
@@ -21,7 +19,7 @@ RSpec.describe RuboCop::Cop::Style::AsciiComments do
     expect_no_offenses('# AZaz1@$%~,;*_`|')
   end
 
-  context 'when certain non-ascii chars are allowed', :config do
+  context 'when certain non-ascii chars are allowed' do
     let(:cop_config) { { 'AllowedChars' => ['∂'] } }
 
     it 'accepts comment with allowed non-ascii chars' do
