@@ -1,8 +1,6 @@
 # frozen_string_literal: true
 
-RSpec.describe RuboCop::Cop::Style::BlockComments do
-  subject(:cop) { described_class.new }
-
+RSpec.describe RuboCop::Cop::Style::BlockComments, :config do
   it 'registers an offense for block comments' do
     expect_offense(<<~RUBY)
       =begin
@@ -10,6 +8,7 @@ RSpec.describe RuboCop::Cop::Style::BlockComments do
       comment
       =end
     RUBY
+
     expect_correction(<<~RUBY)
       # comment
     RUBY
@@ -19,7 +18,7 @@ RSpec.describe RuboCop::Cop::Style::BlockComments do
     expect_no_offenses('# comment')
   end
 
-  it 'auto-corrects a block comment into a regular comment' do
+  it 'autocorrects a block comment into a regular comment' do
     expect_offense(<<~RUBY)
       =begin
       ^^^^^^ Do not use block comments.
@@ -30,6 +29,7 @@ RSpec.describe RuboCop::Cop::Style::BlockComments do
       def foo
       end
     RUBY
+
     expect_correction(<<~RUBY)
       # comment line 1
       #
@@ -39,7 +39,7 @@ RSpec.describe RuboCop::Cop::Style::BlockComments do
     RUBY
   end
 
-  it 'auto-corrects an empty block comment by removing it' do
+  it 'autocorrects an empty block comment by removing it' do
     expect_offense(<<~RUBY)
       =begin
       ^^^^^^ Do not use block comments.
@@ -47,14 +47,14 @@ RSpec.describe RuboCop::Cop::Style::BlockComments do
       def foo
       end
     RUBY
+
     expect_correction(<<~RUBY)
       def foo
       end
     RUBY
   end
 
-  it 'auto-corrects a block comment into a regular comment (without trailing' \
-    'newline)' do
+  it 'autocorrects a block comment into a regular comment (without trailingnewline)' do
     expect_offense(<<~RUBY)
       =begin
       ^^^^^^ Do not use block comments.
@@ -63,6 +63,7 @@ RSpec.describe RuboCop::Cop::Style::BlockComments do
       comment line 2
       =end
     RUBY
+
     expect_correction(<<~RUBY)
       # comment line 1
       #
