@@ -1,13 +1,12 @@
 # frozen_string_literal: true
 
-RSpec.describe RuboCop::Cop::Style::CharacterLiteral do
-  subject(:cop) { described_class.new }
-
+RSpec.describe RuboCop::Cop::Style::CharacterLiteral, :config do
   it 'registers an offense for character literals' do
     expect_offense(<<~RUBY)
       x = ?x
           ^^ Do not use the character literal - use string literal instead.
     RUBY
+
     expect_correction(<<~RUBY)
       x = 'x'
     RUBY
@@ -18,6 +17,7 @@ RSpec.describe RuboCop::Cop::Style::CharacterLiteral do
       x = ?\n
           ^^^ Do not use the character literal - use string literal instead.
     RUBY
+
     expect_correction(<<~'RUBY')
       x = "\n"
     RUBY
@@ -31,11 +31,12 @@ RSpec.describe RuboCop::Cop::Style::CharacterLiteral do
     expect_no_offenses('%w{? A}')
   end
 
-  it 'auto-corrects ?\' to "\'"' do
+  it 'autocorrects ?\' to "\'"' do
     expect_offense(<<~RUBY)
       x = ?'
           ^^ Do not use the character literal - use string literal instead.
     RUBY
+
     expect_correction(<<~RUBY)
       x = "'"
     RUBY
