@@ -1,8 +1,6 @@
 # frozen_string_literal: true
 
-RSpec.describe RuboCop::Cop::Style::ConditionalAssignment do
-  subject(:cop) { described_class.new(config) }
-
+RSpec.describe RuboCop::Cop::Style::ConditionalAssignment, :config do
   shared_examples 'all variable types' do |variable|
     it 'registers an offense assigning any variable type to ternary' do
       expect_offense(<<~RUBY, variable: variable)
@@ -57,8 +55,7 @@ RSpec.describe RuboCop::Cop::Style::ConditionalAssignment do
       RUBY
     end
 
-    it 'registers an offense assigning any variable type to if else' \
-      'with multiple assignment' do
+    it 'registers an offense assigning any variable type to if elsewith multiple assignment' do
       expect_offense(<<~RUBY, variable: variable)
         %{variable}, %{variable} = if foo
         ^{variable}^^^{variable}^^^^^^^^^ Assign variables inside of conditionals
@@ -129,6 +126,33 @@ RSpec.describe RuboCop::Cop::Style::ConditionalAssignment do
       RUBY
     end
 
+    context '>= Ruby 2.7', :ruby27 do
+      it 'registers an offense for assigning any variable type to case in' do
+        expect_offense(<<~RUBY, variable: variable)
+          %{variable} = case foo
+          ^{variable}^^^^^^^^^^^ Assign variables inside of conditionals
+                        in "a"
+                          1
+                        in "b"
+                          2
+                        else
+                          3
+                        end
+        RUBY
+
+        expect_correction(<<~RUBY)
+          case foo
+          in "a"
+            #{variable} = 1
+          in "b"
+            #{variable} = 2
+          else
+            #{variable} = 3
+          end
+        RUBY
+      end
+    end
+
     it 'does not crash for rescue assignment' do
       expect_no_offenses(<<~RUBY)
         begin
@@ -218,6 +242,16 @@ RSpec.describe RuboCop::Cop::Style::ConditionalAssignment do
         end
       RUBY
     end
+
+    it 'does not crash when used inside rescue' do
+      expect_no_offenses(<<~RUBY)
+        begin
+          bar #{assignment} 2
+        rescue
+          bar #{assignment} 1
+        end
+      RUBY
+    end
   end
 
   shared_examples 'multiline all variable types offense' do |variable|
@@ -244,8 +278,7 @@ RSpec.describe RuboCop::Cop::Style::ConditionalAssignment do
       RUBY
     end
 
-    it 'assigning any variable type to an if else with multiline ' \
-       'in one branch' do
+    it 'assigning any variable type to an if else with multiline in one branch' do
       expect_offense(<<~RUBY, variable: variable)
         %{variable} = if foo
         ^{variable}^^^^^^^^^ Assign variables inside of conditionals
@@ -363,8 +396,7 @@ RSpec.describe RuboCop::Cop::Style::ConditionalAssignment do
       RUBY
     end
 
-    it 'assigning any variable type to an if else with multiline ' \
-       'in one branch' do
+    it 'assigning any variable type to an if else with multiline in one branch' do
       expect_no_offenses(<<~RUBY)
         #{variable} = if foo
                         1
@@ -531,7 +563,7 @@ RSpec.describe RuboCop::Cop::Style::ConditionalAssignment do
     end
   end
 
-  shared_examples 'single line condition auto-correct' do
+  shared_examples 'single line condition autocorrect' do
     it 'corrects assignment to an if else condition' do
       expect_offense(<<~RUBY)
         bar = if foo
@@ -732,8 +764,6 @@ RSpec.describe RuboCop::Cop::Style::ConditionalAssignment do
     it_behaves_like('all assignment types', '>>=')
     it_behaves_like('all assignment types', '||=')
     it_behaves_like('all assignment types', '&&=')
-    it_behaves_like('all assignment types', '+=')
-    it_behaves_like('all assignment types', '-=')
     it_behaves_like('all assignment types', '<<')
 
     it_behaves_like('multiline all assignment types allow', '=')
@@ -754,16 +784,13 @@ RSpec.describe RuboCop::Cop::Style::ConditionalAssignment do
     it_behaves_like('multiline all assignment types allow', '>>=')
     it_behaves_like('multiline all assignment types allow', '||=')
     it_behaves_like('multiline all assignment types allow', '&&=')
-    it_behaves_like('multiline all assignment types allow', '+=')
-    it_behaves_like('multiline all assignment types allow', '-=')
     it_behaves_like('multiline all assignment types allow', '<<')
 
     it 'allows a method call in the subject of a ternary operator' do
       expect_no_offenses('bar << foo? ? 1 : 2')
     end
 
-    it 'registers an offense for assignment using a method that ends with ' \
-       'an equal sign' do
+    it 'registers an offense for assignment using a method that ends with an equal sign' do
       expect_offense(<<~RUBY)
         self.attributes = foo? ? 1 : 2
         ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^ Assign variables inside of conditionals
@@ -831,7 +858,7 @@ RSpec.describe RuboCop::Cop::Style::ConditionalAssignment do
       end
     end
 
-    it_behaves_like('single line condition auto-correct')
+    it_behaves_like('single line condition autocorrect')
 
     it 'corrects assignment to a namespaced constant' do
       expect_offense(<<~RUBY)
@@ -926,8 +953,6 @@ RSpec.describe RuboCop::Cop::Style::ConditionalAssignment do
     it_behaves_like('all assignment types', '>>=')
     it_behaves_like('all assignment types', '||=')
     it_behaves_like('all assignment types', '&&=')
-    it_behaves_like('all assignment types', '+=')
-    it_behaves_like('all assignment types', '-=')
     it_behaves_like('all assignment types', '<<')
 
     it_behaves_like('multiline all assignment types offense', '=')
@@ -948,11 +973,9 @@ RSpec.describe RuboCop::Cop::Style::ConditionalAssignment do
     it_behaves_like('multiline all assignment types offense', '>>=')
     it_behaves_like('multiline all assignment types offense', '||=')
     it_behaves_like('multiline all assignment types offense', '&&=')
-    it_behaves_like('multiline all assignment types offense', '+=')
-    it_behaves_like('multiline all assignment types offense', '-=')
     it_behaves_like('multiline all assignment types offense', '<<')
 
-    it_behaves_like('single line condition auto-correct')
+    it_behaves_like('single line condition autocorrect')
 
     it 'corrects assignment to a multiline if else condition' do
       expect_offense(<<~RUBY)
