@@ -1,8 +1,6 @@
 # frozen_string_literal: true
 
-RSpec.describe RuboCop::Cop::Style::ConditionalAssignment do
-  subject(:cop) { described_class.new(config) }
-
+RSpec.describe RuboCop::Cop::Style::ConditionalAssignment, :config, :config, :config do
   let(:config) do
     RuboCop::Config.new('Style/ConditionalAssignment' => {
                           'Enabled' => true,
@@ -139,6 +137,7 @@ RSpec.describe RuboCop::Cop::Style::ConditionalAssignment do
       foo? ? bar = "a" : bar = "b"
       ^^^^^^^^^^^^^^^^^^^^^^^^^^^^ Use the return of the conditional for variable assignment and comparison.
     RUBY
+
     expect_correction(<<~RUBY)
       bar = foo? ? "a" : "b"
     RUBY
@@ -169,6 +168,7 @@ RSpec.describe RuboCop::Cop::Style::ConditionalAssignment do
         default['key-with-dash'] << b
       end
     RUBY
+
     expect_correction(<<~RUBY)
       default['key-with-dash'] << if condition
         a
@@ -195,6 +195,7 @@ RSpec.describe RuboCop::Cop::Style::ConditionalAssignment do
         %{source}
         ^{source} Use the return of the conditional for variable assignment and comparison.
       RUBY
+
       expect_correction(<<~RUBY)
         bar #{method} (foo? ? 1 : 2)
       RUBY
@@ -270,6 +271,30 @@ RSpec.describe RuboCop::Cop::Style::ConditionalAssignment do
             #{indent}end
           RUBY
         end
+
+        context '>= Ruby 2.7', :ruby27 do
+          it 'corrects comparison methods in case in' do
+            expect_offense(<<~RUBY)
+              case foo
+              ^^^^^^^^ Use the return of the conditional for variable assignment and comparison.
+              in bar
+                a #{method} b
+              else
+                a #{method} d
+              end
+            RUBY
+
+            indent = ' ' * "a #{method} ".length if indent_end
+            expect_correction(<<~RUBY)
+              a #{method} case foo
+              in bar
+                b
+              else
+                d
+              #{indent}end
+            RUBY
+          end
+        end
       end
     end
   end
@@ -479,8 +504,7 @@ RSpec.describe RuboCop::Cop::Style::ConditionalAssignment do
     RUBY
   end
 
-  it 'registers an offense in an if else if the assignment is already ' \
-    'at the line length limit' do
+  it 'registers an offense in an if else if the assignment is already at the line length limit' do
     expect_offense(<<~RUBY)
       if foo
       ^^^^^^ Use the return of the conditional for variable assignment and comparison.
@@ -489,6 +513,7 @@ RSpec.describe RuboCop::Cop::Style::ConditionalAssignment do
         bar = #{'b' * 72}
       end
     RUBY
+
     expect_correction(<<~RUBY)
       bar = if foo
         #{'a' * 72}
@@ -636,8 +661,7 @@ RSpec.describe RuboCop::Cop::Style::ConditionalAssignment do
 
     variable_types.each do |type, name|
       context "for a #{type} lval" do
-        it "registers an offense for assignment using #{assignment} " \
-          'in ternary' do
+        it "registers an offense for assignment using #{assignment} in ternary" do
           source = "foo? ? #{name} #{assignment} 1 : #{name} #{assignment} 2"
           expect_offense(<<~RUBY, source: source)
             %{source}
@@ -660,8 +684,7 @@ RSpec.describe RuboCop::Cop::Style::ConditionalAssignment do
 
         variable_types.each do |type, name|
           context "for a #{type} lval" do
-            it "registers an offense for assignment using #{assignment} in " \
-              'if else' do
+            it "registers an offense for assignment using #{assignment} in if else" do
               expect_offense(<<~RUBY)
                 if foo
                 ^^^^^^ Use the return of the conditional for variable assignment and comparison.
@@ -681,8 +704,7 @@ RSpec.describe RuboCop::Cop::Style::ConditionalAssignment do
               RUBY
             end
 
-            it "registers an offense for assignment using #{assignment} in "\
-            ' case when' do
+            it "registers an offense for assignment using #{assignment} in case when" do
               expect_offense(<<~RUBY)
                 case foo
                 ^^^^^^^^ Use the return of the conditional for variable assignment and comparison.
@@ -736,6 +758,7 @@ RSpec.describe RuboCop::Cop::Style::ConditionalAssignment do
         bar = 3
       end
     RUBY
+
     expect_correction(<<~RUBY)
       bar = if foo
         1
@@ -760,6 +783,7 @@ RSpec.describe RuboCop::Cop::Style::ConditionalAssignment do
         bar = 4
       end
     RUBY
+
     expect_correction(<<~RUBY)
       bar = if foo
         1
@@ -773,8 +797,7 @@ RSpec.describe RuboCop::Cop::Style::ConditionalAssignment do
     RUBY
   end
 
-  it 'autocorrects assignment in if else when the assignment ' \
-    'spans multiple lines' do
+  it 'autocorrects assignment in if else when the assignment spans multiple lines' do
     expect_offense(<<~RUBY)
       if foo
       ^^^^^^ Use the return of the conditional for variable assignment and comparison.
@@ -1034,8 +1057,7 @@ RSpec.describe RuboCop::Cop::Style::ConditionalAssignment do
       RUBY
     end
 
-    it 'allows variable assignment in unless else with more than ' \
-       'variable assignment' do
+    it 'allows variable assignment in unless else with more than variable assignment' do
       expect_no_offenses(<<~RUBY)
         unless foo
           method_call
@@ -1047,8 +1069,7 @@ RSpec.describe RuboCop::Cop::Style::ConditionalAssignment do
       RUBY
     end
 
-    it 'allows variable assignment in case when else with more than ' \
-       'variable assignment' do
+    it 'allows variable assignment in case when else with more than variable assignment' do
       expect_no_offenses(<<~RUBY)
         case foo
         when foobar
@@ -1092,7 +1113,7 @@ RSpec.describe RuboCop::Cop::Style::ConditionalAssignment do
         RUBY
       end
 
-      it 'registers an offense when multiple assignment is in else' do
+      it 'does not register an offense when multiple assignment is in else' do
         expect_no_offenses(<<~RUBY)
           if foo
             method_call
@@ -1117,6 +1138,7 @@ RSpec.describe RuboCop::Cop::Style::ConditionalAssignment do
       else bar = 2
       end
     RUBY
+
     expect_correction(<<~RUBY)
       bar = if foo then 1
       elsif cond then 2
@@ -1134,6 +1156,7 @@ RSpec.describe RuboCop::Cop::Style::ConditionalAssignment do
         bar = 2
       end
     RUBY
+
     expect_correction(<<~RUBY)
       bar = unless foo
         1
@@ -1151,6 +1174,7 @@ RSpec.describe RuboCop::Cop::Style::ConditionalAssignment do
       else baz = 2
       end
     RUBY
+
     expect_correction(<<~RUBY)
       baz = case foo
       when bar then 1
@@ -1159,7 +1183,7 @@ RSpec.describe RuboCop::Cop::Style::ConditionalAssignment do
     RUBY
   end
 
-  it 'registers an offense for assignment in case with when when else' do
+  it 'registers an offense for assignment in case with when else' do
     expect_offense(<<~RUBY)
       case foo
       ^^^^^^^^ Use the return of the conditional for variable assignment and comparison.
@@ -1171,6 +1195,7 @@ RSpec.describe RuboCop::Cop::Style::ConditionalAssignment do
         bar = 3
       end
     RUBY
+
     expect_correction(<<~RUBY)
       bar = case foo
       when foobar
@@ -1183,7 +1208,7 @@ RSpec.describe RuboCop::Cop::Style::ConditionalAssignment do
     RUBY
   end
 
-  it 'allows different assignment types in case with when when else' do
+  it 'allows different assignment types in case with when else' do
     expect_no_offenses(<<~RUBY)
       case foo
       when foobar
@@ -1194,8 +1219,7 @@ RSpec.describe RuboCop::Cop::Style::ConditionalAssignment do
     RUBY
   end
 
-  it 'allows assignment in multiple branches when it is ' \
-     'wrapped in a modifier' do
+  it 'allows assignment in multiple branches when it is wrapped in a modifier' do
     expect_no_offenses(<<~RUBY)
       if foo
         bar << 1
@@ -1205,12 +1229,13 @@ RSpec.describe RuboCop::Cop::Style::ConditionalAssignment do
     RUBY
   end
 
-  describe 'auto-correct' do
+  describe 'autocorrect' do
     it 'corrects =~ in ternary operations' do
       expect_offense(<<~'RUBY')
         foo? ? bar =~ /a/ : bar =~ /b/
         ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^ Use the return of the conditional for variable assignment and comparison.
       RUBY
+
       expect_correction(<<~'RUBY')
         bar =~ (foo? ? /a/ : /b/)
       RUBY
@@ -1354,6 +1379,7 @@ RSpec.describe RuboCop::Cop::Style::ConditionalAssignment do
             array[1] = 2
           end
         RUBY
+
         expect_correction(<<~RUBY)
           array[1] = if something
             1
@@ -1386,6 +1412,7 @@ RSpec.describe RuboCop::Cop::Style::ConditionalAssignment do
             FOO::BAR = 2
           end
         RUBY
+
         expect_correction(<<~RUBY)
           FOO::BAR = if something
             1
@@ -1404,6 +1431,7 @@ RSpec.describe RuboCop::Cop::Style::ConditionalAssignment do
             ::BAR = 2
           end
         RUBY
+
         expect_correction(<<~RUBY)
           ::BAR = if something
             1
@@ -1472,8 +1500,6 @@ RSpec.describe RuboCop::Cop::Style::ConditionalAssignment do
   end
 
   context 'configured to check conditions with multiple statements' do
-    subject(:cop) { described_class.new(config) }
-
     let(:config) do
       RuboCop::Config.new('Style/ConditionalAssignment' => {
                             'Enabled' => true,
@@ -1517,8 +1543,7 @@ RSpec.describe RuboCop::Cop::Style::ConditionalAssignment do
         RUBY
       end
 
-      it 'registers an offense in if elsif else with more than ' \
-         'variable assignment' do
+      it 'registers an offense in if elsif else with more than variable assignment' do
         expect_offense(<<~RUBY)
           if foo
           ^^^^^^ Use the return of the conditional for variable assignment and comparison.
@@ -1659,8 +1684,7 @@ RSpec.describe RuboCop::Cop::Style::ConditionalAssignment do
         RUBY
       end
 
-      it 'registers offense for multiple assignments in case when with only ' \
-         'one when' do
+      it 'registers offense for multiple assignments in case when with only one when' do
         expect_offense(<<~RUBY)
           case foo
           ^^^^^^^^ Use the return of the conditional for variable assignment and comparison.
@@ -1685,8 +1709,7 @@ RSpec.describe RuboCop::Cop::Style::ConditionalAssignment do
         RUBY
       end
 
-      it 'registers offense for multiple assignments in case when with ' \
-         'multiple whens' do
+      it 'registers offense for multiple assignments in case when with multiple whens' do
         expect_offense(<<~RUBY)
           case foo
           ^^^^^^^^ Use the return of the conditional for variable assignment and comparison.
@@ -1718,8 +1741,8 @@ RSpec.describe RuboCop::Cop::Style::ConditionalAssignment do
       end
 
       it 'registers an offense in if elsif else with some branches only ' \
-          'containing variable assignment and others containing more than ' \
-          'variable assignment' do
+         'containing variable assignment and others containing more than ' \
+         'variable assignment' do
         expect_offense(<<~RUBY)
           if foo
           ^^^^^^ Use the return of the conditional for variable assignment and comparison.
@@ -1750,8 +1773,7 @@ RSpec.describe RuboCop::Cop::Style::ConditionalAssignment do
         RUBY
       end
 
-      it 'registers an offense in unless else with more than ' \
-         'variable assignment' do
+      it 'registers an offense in unless else with more than variable assignment' do
         expect_offense(<<~RUBY)
           unless foo
           ^^^^^^^^^^ Use the return of the conditional for variable assignment and comparison.
@@ -1774,8 +1796,7 @@ RSpec.describe RuboCop::Cop::Style::ConditionalAssignment do
         RUBY
       end
 
-      it 'registers an offense in case when else with more than ' \
-         'variable assignment' do
+      it 'registers an offense in case when else with more than variable assignment' do
         expect_offense(<<~RUBY)
           case foo
           ^^^^^^^^ Use the return of the conditional for variable assignment and comparison.
@@ -1890,8 +1911,7 @@ RSpec.describe RuboCop::Cop::Style::ConditionalAssignment do
       end
     end
 
-    it 'allows assignment in multiple branches when it is ' \
-       'wrapped in a modifier' do
+    it 'allows assignment in multiple branches when it is wrapped in a modifier' do
       expect_no_offenses(<<~RUBY)
         if foo
           bar << 1
@@ -1927,7 +1947,7 @@ RSpec.describe RuboCop::Cop::Style::ConditionalAssignment do
       RUBY
     end
 
-    context 'auto-correct' do
+    context 'autocorrect' do
       it 'corrects multiple assignment in if else' do
         expect_offense(<<~RUBY)
           if foo
@@ -2094,8 +2114,7 @@ RSpec.describe RuboCop::Cop::Style::ConditionalAssignment do
         RUBY
       end
 
-      it 'corrects assignment in an if statement that is nested ' \
-        'in unless else' do
+      it 'corrects assignment in an if statement that is nested in unless else' do
         expect_offense(<<~RUBY)
           unless foo
             if foobar
@@ -2129,9 +2148,7 @@ RSpec.describe RuboCop::Cop::Style::ConditionalAssignment do
   end
 
   context 'EndAlignment configured to start_of_line' do
-    subject(:cop) { described_class.new(config) }
-
-    context 'auto-correct' do
+    context 'autocorrect' do
       it 'uses proper end alignment in if' do
         expect_offense(<<~RUBY)
           if foo
