@@ -1,14 +1,13 @@
 # frozen_string_literal: true
 
-RSpec.describe RuboCop::Cop::Style::EmptyElse do
-  subject(:cop) { described_class.new(config) }
-
+RSpec.describe RuboCop::Cop::Style::EmptyElse, :config do
   let(:missing_else_config) { {} }
 
-  shared_examples 'auto-correct' do |keyword|
+  shared_examples 'autocorrect' do |keyword|
     context 'MissingElse is disabled' do
-      it 'does auto-correction' do
+      it 'does autocorrection' do
         expect_offense(source)
+
         expect_correction(corrected_source)
       end
     end
@@ -21,13 +20,15 @@ RSpec.describe RuboCop::Cop::Style::EmptyElse do
         end
 
         if ['both', keyword].include? missing_else_style
-          it 'does not auto-correct' do
+          it 'does not autocorrect' do
             expect_offense(source)
+
             expect_no_corrections
           end
         else
-          it 'does auto-correction' do
+          it 'does autocorrection' do
             expect_offense(source)
+
             expect_correction(corrected_source)
           end
         end
@@ -55,7 +56,7 @@ RSpec.describe RuboCop::Cop::Style::EmptyElse do
             if a; foo end
           RUBY
 
-          it_behaves_like 'auto-correct', 'if'
+          it_behaves_like 'autocorrect', 'if'
         end
 
         context 'not using semicolons' do
@@ -72,7 +73,7 @@ RSpec.describe RuboCop::Cop::Style::EmptyElse do
             end
           RUBY
 
-          it_behaves_like 'auto-correct', 'if'
+          it_behaves_like 'autocorrect', 'if'
         end
       end
 
@@ -112,27 +113,22 @@ RSpec.describe RuboCop::Cop::Style::EmptyElse do
           end
         RUBY
 
-        it_behaves_like 'auto-correct', 'if'
+        it_behaves_like 'autocorrect', 'if'
       end
 
       context 'with an empty comment' do
-        let(:source) { <<~RUBY }
-          if cond
-            something
-          else
-          ^^^^ Redundant `else`-clause.
-            # TODO
-          end
-        RUBY
-        let(:corrected_source) { <<~RUBY }
-          if cond
-            something
-          else
-            # TODO
-          end
-        RUBY
+        it 'does not autocorrect' do
+          expect_offense(<<~RUBY)
+            if cond
+              something
+            else
+            ^^^^ Redundant `else`-clause.
+              # TODO
+            end
+          RUBY
 
-        it_behaves_like 'auto-correct', 'if'
+          expect_no_corrections
+        end
       end
     end
 
@@ -146,7 +142,7 @@ RSpec.describe RuboCop::Cop::Style::EmptyElse do
           unless cond; foo end
         RUBY
 
-        it_behaves_like 'auto-correct', 'if'
+        it_behaves_like 'autocorrect', 'if'
       end
 
       context 'with an else-clause containing only the literal nil' do
@@ -178,7 +174,7 @@ RSpec.describe RuboCop::Cop::Style::EmptyElse do
           case v; when a; foo end
         RUBY
 
-        it_behaves_like 'auto-correct', 'case'
+        it_behaves_like 'autocorrect', 'case'
       end
 
       context 'with an else-clause containing only the literal nil' do
@@ -238,7 +234,7 @@ RSpec.describe RuboCop::Cop::Style::EmptyElse do
             end
           RUBY
 
-          it_behaves_like 'auto-correct', 'if'
+          it_behaves_like 'autocorrect', 'if'
         end
 
         context 'when the result is assigned to a variable' do
@@ -261,12 +257,11 @@ RSpec.describe RuboCop::Cop::Style::EmptyElse do
                      end
           RUBY
 
-          it_behaves_like 'auto-correct', 'if'
+          it_behaves_like 'autocorrect', 'if'
         end
       end
 
-      context 'with an else-clause containing only the literal nil ' \
-              'using semicolons' do
+      context 'with an else-clause containing only the literal nil using semicolons' do
         context 'with one elsif' do
           let(:source) { <<~RUBY }
             if a; foo elsif b; bar else nil end
@@ -276,7 +271,7 @@ RSpec.describe RuboCop::Cop::Style::EmptyElse do
             if a; foo elsif b; bar end
           RUBY
 
-          it_behaves_like 'auto-correct', 'if'
+          it_behaves_like 'autocorrect', 'if'
         end
 
         context 'with multiple elsifs' do
@@ -288,7 +283,7 @@ RSpec.describe RuboCop::Cop::Style::EmptyElse do
             if a; foo elsif b; bar; elsif c; bar end
           RUBY
 
-          it_behaves_like 'auto-correct', 'if'
+          it_behaves_like 'autocorrect', 'if'
         end
       end
 
@@ -321,7 +316,7 @@ RSpec.describe RuboCop::Cop::Style::EmptyElse do
           unless cond; foo end
         RUBY
 
-        it_behaves_like 'auto-correct', 'if'
+        it_behaves_like 'autocorrect', 'if'
       end
 
       context 'with an else-clause with side-effects' do
@@ -354,7 +349,7 @@ RSpec.describe RuboCop::Cop::Style::EmptyElse do
             case v; when a; foo; when b; bar; end
           RUBY
 
-          it_behaves_like 'auto-correct', 'case'
+          it_behaves_like 'autocorrect', 'case'
         end
 
         context 'when the result is assigned to a variable' do
@@ -379,7 +374,7 @@ RSpec.describe RuboCop::Cop::Style::EmptyElse do
                      end
           RUBY
 
-          it_behaves_like 'auto-correct', 'case'
+          it_behaves_like 'autocorrect', 'case'
         end
       end
 
@@ -416,7 +411,7 @@ RSpec.describe RuboCop::Cop::Style::EmptyElse do
           if a; foo end
         RUBY
 
-        it_behaves_like 'auto-correct', 'if'
+        it_behaves_like 'autocorrect', 'if'
       end
 
       context 'with an else-clause containing only the literal nil' do
@@ -429,7 +424,7 @@ RSpec.describe RuboCop::Cop::Style::EmptyElse do
             if a; foo elsif b; bar end
           RUBY
 
-          it_behaves_like 'auto-correct', 'if'
+          it_behaves_like 'autocorrect', 'if'
         end
 
         context 'with multiple elsifs' do
@@ -441,7 +436,7 @@ RSpec.describe RuboCop::Cop::Style::EmptyElse do
             if a; foo elsif b; bar; elsif c; bar end
           RUBY
 
-          it_behaves_like 'auto-correct', 'if'
+          it_behaves_like 'autocorrect', 'if'
         end
       end
 
@@ -468,7 +463,7 @@ RSpec.describe RuboCop::Cop::Style::EmptyElse do
           unless cond; foo end
         RUBY
 
-        it_behaves_like 'auto-correct', 'if'
+        it_behaves_like 'autocorrect', 'if'
       end
 
       context 'with an else-clause containing only the literal nil' do
@@ -480,7 +475,7 @@ RSpec.describe RuboCop::Cop::Style::EmptyElse do
           unless cond; foo end
         RUBY
 
-        it_behaves_like 'auto-correct', 'if'
+        it_behaves_like 'autocorrect', 'if'
       end
 
       context 'with an else-clause with side-effects' do
@@ -506,7 +501,7 @@ RSpec.describe RuboCop::Cop::Style::EmptyElse do
           case v; when a; foo end
         RUBY
 
-        it_behaves_like 'auto-correct', 'case'
+        it_behaves_like 'autocorrect', 'case'
       end
 
       context 'with an else-clause containing only the literal nil' do
@@ -518,7 +513,7 @@ RSpec.describe RuboCop::Cop::Style::EmptyElse do
           case v; when a; foo; when b; bar; end
         RUBY
 
-        it_behaves_like 'auto-correct', 'case'
+        it_behaves_like 'autocorrect', 'case'
       end
 
       context 'with an else-clause with side-effects' do
@@ -535,6 +530,174 @@ RSpec.describe RuboCop::Cop::Style::EmptyElse do
     end
   end
 
+  context 'when `AllowComments: true`' do
+    let(:config) do
+      RuboCop::Config.new('Style/EmptyElse' => {
+                            'AllowComments' => true,
+                            'EnforcedStyle' => 'both',
+                            'SupportedStyles' => %w[empty nil both]
+                          },
+                          'Style/MissingElse' => missing_else_config)
+    end
+
+    context 'given an if-statement' do
+      context 'with not comment and empty else-clause' do
+        it 'registers an offense' do
+          expect_offense(<<~RUBY)
+            if condition
+              statement
+            else
+            ^^^^ Redundant `else`-clause.
+            end
+          RUBY
+        end
+      end
+
+      context 'with not comment and nil else-clause' do
+        it 'registers an offense' do
+          expect_offense(<<~RUBY)
+            if condition
+              statement
+            else
+            ^^^^ Redundant `else`-clause.
+              nil
+            end
+          RUBY
+        end
+      end
+
+      context 'with comment and empty else-clause' do
+        it "doesn't register an offense" do
+          expect_no_offenses(<<~RUBY)
+            if condition
+              statement
+            else
+              # some comment
+            end
+          RUBY
+        end
+      end
+
+      context 'with comment and nil else-clause' do
+        it "doesn't register an offense" do
+          expect_no_offenses(<<~RUBY)
+            if condition
+              statement
+            else
+              nil # some comment
+            end
+          RUBY
+        end
+      end
+    end
+
+    context 'given an unless-statement' do
+      context 'with not comment and empty else-clause' do
+        it 'registers an offense' do
+          expect_offense(<<~RUBY)
+            unless condition
+              statement
+            else
+            ^^^^ Redundant `else`-clause.
+            end
+          RUBY
+        end
+      end
+
+      context 'with not comment and nil else-clause' do
+        it 'registers an offense' do
+          expect_offense(<<~RUBY)
+            unless condition
+              statement
+            else
+            ^^^^ Redundant `else`-clause.
+              nil
+            end
+          RUBY
+        end
+      end
+
+      context 'with comment and empty else-clause' do
+        it "doesn't register an offense" do
+          expect_no_offenses(<<~RUBY)
+            unless condition
+              statement
+            else
+              # some comment
+            end
+          RUBY
+        end
+      end
+
+      context 'with comment and nil else-clause' do
+        it "doesn't register an offense" do
+          expect_no_offenses(<<~RUBY)
+            unless condition
+              statement
+            else
+              nil # some comment
+            end
+          RUBY
+        end
+      end
+    end
+
+    context 'given a case statement' do
+      context 'with not comment and empty else-clause' do
+        it 'registers an offense' do
+          expect_offense(<<~RUBY)
+            case a
+            when condition
+              statement
+            else
+            ^^^^ Redundant `else`-clause.
+            end
+          RUBY
+        end
+      end
+
+      context 'with not comment and nil else-clause' do
+        it 'registers an offense' do
+          expect_offense(<<~RUBY)
+            case a
+            when condition
+              statement
+            else
+            ^^^^ Redundant `else`-clause.
+              nil
+            end
+          RUBY
+        end
+      end
+
+      context 'with comment and empty else-clause' do
+        it "doesn't register an offense" do
+          expect_no_offenses(<<~RUBY)
+            case a
+            when condition
+              statement
+            else
+              # some comment
+            end
+          RUBY
+        end
+      end
+
+      context 'with comment and nil else-clause' do
+        it "doesn't register an offense" do
+          expect_no_offenses(<<~RUBY)
+            case a
+            when condition
+              statement
+            else
+              nil # some comment
+            end
+          RUBY
+        end
+      end
+    end
+  end
+
   context 'with nested if and case statement' do
     let(:config) do
       RuboCop::Config.new('Style/EmptyElse' => {
@@ -573,6 +736,6 @@ RSpec.describe RuboCop::Cop::Style::EmptyElse do
       end
     RUBY
 
-    it_behaves_like 'auto-correct', 'case'
+    it_behaves_like 'autocorrect', 'case'
   end
 end
