@@ -1,11 +1,7 @@
 # frozen_string_literal: true
 
 RSpec.describe RuboCop::Cop::Style::GlobalVars, :config do
-  cop_config = {
-    'AllowedVariables' => ['$allowed']
-  }
-
-  subject(:cop) { described_class.new(config) }
+  cop_config = { 'AllowedVariables' => ['$allowed'] }
 
   let(:cop_config) { cop_config }
 
