@@ -25,9 +25,7 @@ RSpec.describe RuboCop::Cop::Style::IfUnlessModifier, :config do
     let(:spaces) { ' ' * 59 }
     let(:body) { "puts '#{spaces}'" }
     let(:source) { "#{body} if condition" }
-    let(:long_url) do
-      'https://some.example.com/with/a/rather?long&and=very&complicated=path'
-    end
+    let(:long_url) { 'https://some.example.com/with/a/rather?long&and=very&complicated=path' }
 
     context 'when Layout/LineLength is enabled' do
       it 'corrects it to normal form' do
@@ -75,13 +73,46 @@ RSpec.describe RuboCop::Cop::Style::IfUnlessModifier, :config do
         end
       end
 
+      context 'when using a method with heredoc argument' do
+        it 'accepts' do
+          expect_offense(<<~RUBY)
+            fooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo(<<~EOS) if condition
+                                                                                 ^^ Modifier form of `if` makes the line too long.
+              string
+            EOS
+          RUBY
+
+          expect_correction(<<~RUBY)
+            if condition
+              fooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo(<<~EOS)
+                string
+              EOS
+            end
+          RUBY
+        end
+      end
+
+      context 'when variable assignment is used in the branch body of if modifier' do
+        it 'registers an offense' do
+          expect_offense(<<~RUBY)
+            variable = foooooooooooooooooooooooooooooooooooooooooooooooooooooooo if condition
+                                                                                 ^^ Modifier form of `if` makes the line too long.
+          RUBY
+
+          expect_correction(<<~RUBY)
+            if condition
+              variable = foooooooooooooooooooooooooooooooooooooooooooooooooooooooo
+            end
+          RUBY
+        end
+      end
+
       describe 'IgnoreCopDirectives' do
         let(:spaces) { ' ' * 57 }
         let(:comment) { '# rubocop:disable Style/For' }
         let(:body) { "puts '#{spaces}'" }
 
-        context 'and the long line is allowed because IgnoreCopDirectives is ' \
-                'true' do
+        context 'and the long line is allowed because IgnoreCopDirectives is true' do
           it 'accepts' do
             expect("#{body} if condition".length).to eq(77) # That's 79 including indentation.
             expect_no_offenses(<<~RUBY)
@@ -92,8 +123,7 @@ RSpec.describe RuboCop::Cop::Style::IfUnlessModifier, :config do
           end
         end
 
-        context 'and the long line is too long because IgnoreCopDirectives ' \
-                'is false' do
+        context 'and the long line is too long because IgnoreCopDirectives is false' do
           let(:ignore_cop_directives) { false }
 
           it 'registers an offense' do
@@ -128,8 +158,7 @@ RSpec.describe RuboCop::Cop::Style::IfUnlessModifier, :config do
       end
     end
 
-    context 'when Layout/LineLength is disabled with enable/disable ' \
-            'comments' do
+    context 'when Layout/LineLength is disabled with enable/disable comments' do
       it 'accepts' do
         expect_no_offenses(<<~RUBY)
           def f
@@ -186,8 +215,7 @@ RSpec.describe RuboCop::Cop::Style::IfUnlessModifier, :config do
     end
   end
 
-  context 'modifier if that does not fit on one line, but is not the only' \
-          ' statement on the line' do
+  context 'modifier if that does not fit on one line, but is not the only statement on the line' do
     let(:spaces) { ' ' * 59 }
 
     # long lines which have multiple statements on the same line can be flagged
@@ -357,71 +385,6 @@ RSpec.describe RuboCop::Cop::Style::IfUnlessModifier, :config do
     RUBY
   end
 
-  it "doesn't break if-end when used as RHS of local var assignment" do
-    expect_offense(<<~RUBY)
-      a = if b
-          ^^ Favor modifier `if` usage when having a single-line body. [...]
-        1
-      end
-    RUBY
-
-    expect_correction(<<~RUBY)
-      a = (1 if b)
-    RUBY
-  end
-
-  it "doesn't break if-end when used as RHS of instance var assignment" do
-    expect_offense(<<~RUBY)
-      @a = if b
-           ^^ Favor modifier `if` usage when having a single-line body. [...]
-        1
-      end
-    RUBY
-
-    expect_correction(<<~RUBY)
-      @a = (1 if b)
-    RUBY
-  end
-
-  it "doesn't break if-end when used as RHS of class var assignment" do
-    expect_offense(<<~RUBY)
-      @@a = if b
-            ^^ Favor modifier `if` usage when having a single-line body. [...]
-        1
-      end
-    RUBY
-
-    expect_correction(<<~RUBY)
-      @@a = (1 if b)
-    RUBY
-  end
-
-  it "doesn't break if-end when used as RHS of constant assignment" do
-    expect_offense(<<~RUBY)
-      A = if b
-          ^^ Favor modifier `if` usage when having a single-line body. [...]
-        1
-      end
-    RUBY
-
-    expect_correction(<<~RUBY)
-      A = (1 if b)
-    RUBY
-  end
-
-  it "doesn't break if-end when used as RHS of binary arithmetic" do
-    expect_offense(<<~RUBY)
-      a + if b
-          ^^ Favor modifier `if` usage when having a single-line body. [...]
-        1
-      end
-    RUBY
-
-    expect_correction(<<~RUBY)
-      a + (1 if b)
-    RUBY
-  end
-
   it 'adds parens in autocorrect when if-end used with `||` operator' do
     expect_offense(<<~RUBY)
       a || if b
@@ -601,20 +564,22 @@ RSpec.describe RuboCop::Cop::Style::IfUnlessModifier, :config do
 
   context 'when if-end condition is assigned to a variable' do
     context 'with variable being on the same line' do
-      let(:source) do
-        <<~RUBY
-          x = if a
-            #{'b' * body_length}
-          end
-        RUBY
-      end
+      let(:body) { 'b' * body_length }
 
       context 'when it is short enough to fit on a single line' do
         let(:body_length) { 69 }
 
         it 'corrects it to the single-line form' do
-          corrected = autocorrect_source(source)
-          expect(corrected).to eq "x = (#{'b' * body_length} if a)\n"
+          expect_offense(<<~RUBY, body: body)
+            x = if a
+                ^^ Favor modifier `if` usage [...]
+              %{body}
+            end
+          RUBY
+
+          expect_correction(<<~RUBY)
+            x = (#{body} if a)
+          RUBY
         end
       end
 
@@ -622,27 +587,34 @@ RSpec.describe RuboCop::Cop::Style::IfUnlessModifier, :config do
         let(:body_length) { 70 }
 
         it 'accepts it in the multiline form' do
-          expect_no_offenses(source)
+          expect_no_offenses(<<~RUBY)
+            x = if a
+              #{body}
+            end
+          RUBY
         end
       end
     end
 
     context 'with variable being on the previous line' do
-      let(:source) do
-        <<~RUBY
-          x =
-            if a
-              #{'b' * body_length}
-            end
-        RUBY
-      end
+      let(:body) { 'b' * body_length }
 
       context 'when it is short enough to fit on a single line' do
         let(:body_length) { 71 }
 
         it 'corrects it to the single-line form' do
-          corrected = autocorrect_source(source)
-          expect(corrected).to eq "x =\n  (#{'b' * body_length} if a)\n"
+          expect_offense(<<~RUBY, body: body)
+            x =
+              if a
+              ^^ Favor modifier `if` usage [...]
+                %{body}
+              end
+          RUBY
+
+          expect_correction(<<~RUBY)
+            x =
+              (#{body} if a)
+          RUBY
         end
       end
 
@@ -650,29 +622,38 @@ RSpec.describe RuboCop::Cop::Style::IfUnlessModifier, :config do
         let(:body_length) { 72 }
 
         it 'accepts it in the multiline form' do
-          expect_no_offenses(source)
+          expect_no_offenses(<<~RUBY)
+            x =
+              if a
+                #{body}
+              end
+          RUBY
         end
       end
     end
   end
 
   context 'when if-end condition is an element of an array' do
-    let(:source) do
-      <<~RUBY
-        [
-          if a
-            #{'b' * body_length}
-          end
-        ]
-      RUBY
-    end
+    let(:body) { 'b' * body_length }
 
     context 'when short enough to fit on a single line' do
       let(:body_length) { 71 }
 
       it 'corrects it to the single-line form' do
-        corrected = autocorrect_source(source)
-        expect(corrected).to eq "[\n  (#{'b' * body_length} if a)\n]\n"
+        expect_offense(<<~RUBY, body: body)
+          [
+            if a
+            ^^ Favor modifier `if` usage [...]
+              %{body}
+            end
+          ]
+        RUBY
+
+        expect_correction(<<~RUBY)
+          [
+            (#{body} if a)
+          ]
+        RUBY
       end
     end
 
@@ -680,28 +661,38 @@ RSpec.describe RuboCop::Cop::Style::IfUnlessModifier, :config do
       let(:body_length) { 72 }
 
       it 'accepts it in the multiline form' do
-        expect_no_offenses(source)
+        expect_no_offenses(<<~RUBY)
+          [
+            if a
+              #{body}
+            end
+          ]
+        RUBY
       end
     end
   end
 
   context 'when if-end condition is a value in a hash' do
-    let(:source) do
-      <<~RUBY
-        {
-          x: if a
-               #{'b' * body_length}
-             end
-        }
-      RUBY
-    end
+    let(:body) { 'b' * body_length }
 
     context 'when it is short enough to fit on a single line' do
       let(:body_length) { 68 }
 
       it 'corrects it to the single-line form' do
-        corrected = autocorrect_source(source)
-        expect(corrected).to eq "{\n  x: (#{'b' * body_length} if a)\n}\n"
+        expect_offense(<<~RUBY, body: body)
+          {
+            x: if a
+               ^^ Favor modifier `if` usage [...]
+                 %{body}
+               end
+          }
+        RUBY
+
+        expect_correction(<<~RUBY)
+          {
+            x: (#{body} if a)
+          }
+        RUBY
       end
     end
 
@@ -709,26 +700,34 @@ RSpec.describe RuboCop::Cop::Style::IfUnlessModifier, :config do
       let(:body_length) { 69 }
 
       it 'accepts it in the multiline form' do
-        expect_no_offenses(source)
+        expect_no_offenses(<<~RUBY)
+          {
+            x: if a
+                 #{body}
+               end
+          }
+        RUBY
       end
     end
   end
 
   context 'when if-end condition has a first line comment' do
-    let(:source) do
-      <<~RUBY
-        if foo # #{'c' * comment_length}
-          bar
-        end
-      RUBY
-    end
+    let(:comment) { 'c' * comment_length }
 
     context 'when it is short enough to fit on a single line' do
       let(:comment_length) { 67 }
 
       it 'corrects it to the single-line form' do
-        corrected = autocorrect_source(source)
-        expect(corrected).to eq "bar if foo # #{'c' * comment_length}\n"
+        expect_offense(<<~RUBY, comment: comment)
+          if foo # %{comment}
+          ^^ Favor modifier `if` usage [...]
+            bar
+          end
+        RUBY
+
+        expect_correction(<<~RUBY)
+          bar if foo # #{comment}
+        RUBY
       end
     end
 
@@ -736,28 +735,36 @@ RSpec.describe RuboCop::Cop::Style::IfUnlessModifier, :config do
       let(:comment_length) { 68 }
 
       it 'accepts it in the multiline form' do
-        expect_no_offenses(source)
+        expect_no_offenses(<<~RUBY)
+          if foo # #{comment}
+            bar
+          end
+        RUBY
       end
     end
   end
 
   context 'when if-end condition has some code after the end keyword' do
-    let(:source) do
-      <<~RUBY
-        [
-          1, if foo
-               #{'b' * body_length}
-             end, 300_000_000
-        ]
-      RUBY
-    end
+    let(:body) { 'b' * body_length }
 
     context 'when it is short enough to fit on a single line' do
       let(:body_length) { 53 }
 
       it 'corrects it to the single-line form' do
-        corrected = autocorrect_source(source)
-        expect(corrected).to eq "[\n  1, (#{'b' * body_length} if foo), 300_000_000\n]\n"
+        expect_offense(<<~RUBY, body: body)
+          [
+            1, if foo
+               ^^ Favor modifier `if` usage [...]
+                 %{body}
+               end, 300_000_000
+          ]
+        RUBY
+
+        expect_correction(<<~RUBY)
+          [
+            1, (#{body} if foo), 300_000_000
+          ]
+        RUBY
       end
     end
 
@@ -765,7 +772,13 @@ RSpec.describe RuboCop::Cop::Style::IfUnlessModifier, :config do
       let(:body_length) { 54 }
 
       it 'accepts it in the multiline form' do
-        expect_no_offenses(source)
+        expect_no_offenses(<<~RUBY)
+          [
+            1, if foo
+                 #{body}
+               end, 300_000_000
+          ]
+        RUBY
       end
     end
   end
