@@ -1,10 +1,76 @@
 # frozen_string_literal: true
 
 RSpec.describe RuboCop::Cop::Style::MethodCallWithArgsParentheses, :config do
-  context 'when EnforcedStyle is require_parentheses (default)' do
-    let(:cop_config) do
-      { 'IgnoredMethods' => %w[puts] }
+  shared_examples 'endless methods' do |omit: false|
+    context 'endless methods', :ruby30 do
+      context 'with arguments' do
+        it 'requires method calls to have parens' do
+          expect_no_offenses(<<~RUBY)
+            def x() = foo("bar")
+          RUBY
+        end
+      end
+
+      context 'without arguments' do
+        if omit
+          it 'registers an offense when there are parens' do
+            expect_offense(<<~RUBY)
+              def x() = foo()
+                           ^^ Omit parentheses for method calls with arguments.
+            RUBY
+
+            expect_correction(<<~RUBY)
+              def x() = foo#{trailing_whitespace}
+            RUBY
+          end
+
+          it 'registers an offense for `defs` when there are parens' do
+            expect_offense(<<~RUBY)
+              def self.x() = foo()
+                                ^^ Omit parentheses for method calls with arguments.
+            RUBY
+
+            expect_correction(<<~RUBY)
+              def self.x() = foo#{trailing_whitespace}
+            RUBY
+          end
+        else
+          it 'does not register an offense when there are parens' do
+            expect_no_offenses(<<~RUBY)
+              def x() = foo()
+            RUBY
+          end
+
+          it 'does not register an offense for `defs` when there are parens' do
+            expect_no_offenses(<<~RUBY)
+              def self.x() = foo()
+            RUBY
+          end
+        end
+
+        it 'does not register an offense when there are no parens' do
+          expect_no_offenses(<<~RUBY)
+            def x() = foo
+          RUBY
+        end
+
+        it 'does not register an offense when there are arguments' do
+          expect_no_offenses(<<~RUBY)
+            def x() = foo(y)
+          RUBY
+        end
+
+        it 'does not register an offense for `defs` when there are arguments' do
+          expect_no_offenses(<<~RUBY)
+            def self.x() = foo(y)
+          RUBY
+        end
+      end
     end
+  end
+
+  context 'when EnforcedStyle is require_parentheses (default)' do
+    it_behaves_like 'endless methods'
 
     it 'accepts no parens in method call without args' do
       expect_no_offenses('top.test')
@@ -130,7 +196,7 @@ RSpec.describe RuboCop::Cop::Style::MethodCallWithArgsParentheses, :config do
       expect_no_offenses('!test')
     end
 
-    it 'auto-corrects fully parenthesized args by removing space' do
+    it 'autocorrects fully parenthesized args by removing space' do
       expect_offense(<<~RUBY)
         top.eq (1 + 2)
         ^^^^^^^^^^^^^^ Use parentheses for method calls with arguments.
@@ -141,7 +207,7 @@ RSpec.describe RuboCop::Cop::Style::MethodCallWithArgsParentheses, :config do
       RUBY
     end
 
-    it 'auto-corrects parenthesized args for local methods by removing space' do
+    it 'autocorrects parenthesized args for local methods by removing space' do
       expect_offense(<<~RUBY)
         def foo
           eq (1 + 2)
@@ -156,7 +222,7 @@ RSpec.describe RuboCop::Cop::Style::MethodCallWithArgsParentheses, :config do
       RUBY
     end
 
-    it 'auto-corrects call with multiple args by adding braces' do
+    it 'autocorrects call with multiple args by adding braces' do
       expect_offense(<<~RUBY)
         def foo
           eq 1, (2 + 3)
@@ -174,7 +240,7 @@ RSpec.describe RuboCop::Cop::Style::MethodCallWithArgsParentheses, :config do
       RUBY
     end
 
-    it 'auto-corrects partially parenthesized args by adding needed braces' do
+    it 'autocorrects partially parenthesized args by adding needed braces' do
       expect_offense(<<~RUBY)
         top.eq (1 + 2) + 3
         ^^^^^^^^^^^^^^^^^^ Use parentheses for method calls with arguments.
@@ -185,7 +251,7 @@ RSpec.describe RuboCop::Cop::Style::MethodCallWithArgsParentheses, :config do
       RUBY
     end
 
-    it 'auto-corrects calls with multiple args by adding needed braces' do
+    it 'autocorrects calls with multiple args by adding needed braces' do
       expect_offense(<<~RUBY)
         top.eq (1 + 2), 3
         ^^^^^^^^^^^^^^^^^ Use parentheses for method calls with arguments.
@@ -196,7 +262,7 @@ RSpec.describe RuboCop::Cop::Style::MethodCallWithArgsParentheses, :config do
       RUBY
     end
 
-    it 'auto-corrects calls where arg is method call' do
+    it 'autocorrects calls where arg is method call' do
       expect_offense(<<~RUBY)
         def my_method
           foo bar.baz(abc, xyz)
@@ -211,7 +277,7 @@ RSpec.describe RuboCop::Cop::Style::MethodCallWithArgsParentheses, :config do
       RUBY
     end
 
-    it 'auto-corrects calls where multiple args are method calls' do
+    it 'autocorrects calls where multiple args are method calls' do
       expect_offense(<<~RUBY)
         def my_method
           foo bar.baz(abc, xyz), foo(baz)
@@ -226,7 +292,7 @@ RSpec.describe RuboCop::Cop::Style::MethodCallWithArgsParentheses, :config do
       RUBY
     end
 
-    it 'auto-corrects calls where the argument node is a constant' do
+    it 'autocorrects calls where the argument node is a constant' do
       expect_offense(<<~RUBY)
         def my_method
           raise NotImplementedError
@@ -241,7 +307,7 @@ RSpec.describe RuboCop::Cop::Style::MethodCallWithArgsParentheses, :config do
       RUBY
     end
 
-    it 'auto-corrects calls where the argument node is a number' do
+    it 'autocorrects calls where the argument node is a number' do
       expect_offense(<<~RUBY)
         def my_method
           sleep 1
@@ -256,14 +322,16 @@ RSpec.describe RuboCop::Cop::Style::MethodCallWithArgsParentheses, :config do
       RUBY
     end
 
-    it 'ignores method listed in IgnoredMethods' do
-      expect_no_offenses('puts :test')
+    context 'with AllowedMethods' do
+      let(:cop_config) { { 'AllowedMethods' => %w[puts] } }
+
+      it 'allow method listed in AllowedMethods' do
+        expect_no_offenses('puts :test')
+      end
     end
 
     context 'when inspecting macro methods' do
-      let(:cop_config) do
-        { 'IgnoreMacros' => 'true' }
-      end
+      let(:cop_config) { { 'IgnoreMacros' => 'true' } }
 
       context 'in a class body' do
         it 'does not register an offense' do
@@ -286,12 +354,10 @@ RSpec.describe RuboCop::Cop::Style::MethodCallWithArgsParentheses, :config do
       end
     end
 
-    context 'IgnoredPatterns' do
-      let(:cop_config) do
-        { 'IgnoredPatterns' => %w[^assert ^refute] }
-      end
+    context 'AllowedPatterns' do
+      let(:cop_config) { { 'AllowedPatterns' => %w[^assert ^refute] } }
 
-      it 'ignored methods listed in IgnoredPatterns' do
+      it 'ignored methods listed in AllowedPatterns' do
         expect_no_offenses('assert 2 == 2')
         expect_no_offenses('assert_equal 2, 2')
         expect_no_offenses('assert_match /^yes/i, result')
@@ -304,8 +370,102 @@ RSpec.describe RuboCop::Cop::Style::MethodCallWithArgsParentheses, :config do
   end
 
   context 'when EnforcedStyle is omit_parentheses' do
-    let(:cop_config) do
-      { 'EnforcedStyle' => 'omit_parentheses' }
+    let(:cop_config) { { 'EnforcedStyle' => 'omit_parentheses' } }
+
+    it_behaves_like 'endless methods', omit: true
+
+    context 'forwarded arguments in 2.7', :ruby27 do
+      it 'accepts parens for forwarded arguments' do
+        expect_no_offenses(<<~RUBY)
+          def delegated_call(...)
+            @proxy.call(...)
+          end
+        RUBY
+      end
+    end
+
+    context 'forwarded arguments in 3.0', :ruby30 do
+      it 'accepts parens for forwarded arguments' do
+        expect_no_offenses(<<~RUBY)
+          def method_missing(name, ...)
+            @proxy.call(name, ...)
+          end
+        RUBY
+      end
+    end
+
+    context 'numbered parameters in 2.7', :ruby27 do
+      it 'accepts parens for braced numeric block calls' do
+        expect_no_offenses(<<~RUBY)
+          numblock.call(:arg) { _1 }
+        RUBY
+      end
+    end
+
+    context 'hash value omission in 3.1', :ruby31 do
+      it 'registers an offense when last argument is a hash value omission' do
+        expect_offense(<<~RUBY)
+          foo(bar:, baz:)
+             ^^^^^^^^^^^^ Omit parentheses for method calls with arguments.
+        RUBY
+
+        expect_correction(<<~RUBY)
+          foo bar:, baz:
+        RUBY
+      end
+
+      it 'does not register an offense when hash value omission with parentheses and using modifier form' do
+        expect_no_offenses(<<~RUBY)
+          do_something(value:) if condition
+        RUBY
+      end
+
+      it 'registers and corrects an offense when explicit hash value with parentheses and using modifier form' do
+        expect_offense(<<~RUBY)
+          do_something(value: value) if condition
+                      ^^^^^^^^^^^^^^ Omit parentheses for method calls with arguments.
+        RUBY
+
+        expect_correction(<<~RUBY)
+          do_something value: value if condition
+        RUBY
+      end
+
+      it 'does not register an offense when without parentheses call expr follows' do
+        expect_no_offenses(<<~RUBY)
+          foo value:
+        RUBY
+      end
+
+      it 'registers an offense when with parentheses call expr follows' do
+        # Require hash value omission be enclosed in parentheses to prevent the following issue:
+        # https://bugs.ruby-lang.org/issues/18396.
+        expect_offense(<<~RUBY)
+          foo(value:)
+          foo(arg)
+             ^^^^^ Omit parentheses for method calls with arguments.
+        RUBY
+
+        expect_correction(<<~RUBY)
+          foo(value:)
+          foo arg
+        RUBY
+      end
+
+      it 'registers an offense using assignment with parentheses call expr follows' do
+        # Require hash value omission be enclosed in parentheses to prevent the following issue:
+        # https://bugs.ruby-lang.org/issues/18396.
+        expect_offense(<<~RUBY)
+          var = foo(value:)
+          foo(arg)
+             ^^^^^ Omit parentheses for method calls with arguments.
+        RUBY
+
+        expect_correction(<<~RUBY)
+          var = foo(value:)
+          foo arg
+        RUBY
+      end
     end
 
     it 'register an offense for parens in method call without args' do
@@ -414,6 +574,17 @@ RSpec.describe RuboCop::Cop::Style::MethodCallWithArgsParentheses, :config do
       RUBY
     end
 
+    it 'register an offense for parens in string interpolation' do
+      expect_offense(<<~'RUBY')
+        "#{t('no.parens')}"
+            ^^^^^^^^^^^^^ Omit parentheses for method calls with arguments.
+      RUBY
+
+      expect_correction(<<~'RUBY')
+        "#{t 'no.parens'}"
+      RUBY
+    end
+
     it 'register an offense in complex conditionals' do
       expect_offense(<<~RUBY)
         def foo
@@ -605,6 +776,11 @@ RSpec.describe RuboCop::Cop::Style::MethodCallWithArgsParentheses, :config do
       expect_no_offenses('foo &block')
     end
 
+    it 'accepts parens in yield argument method calls' do
+      expect_no_offenses('yield File.basepath(path)')
+      expect_no_offenses('yield path, File.basepath(path)')
+    end
+
     it 'accepts parens in super without args' do
       expect_no_offenses('super()')
     end
@@ -653,7 +829,20 @@ RSpec.describe RuboCop::Cop::Style::MethodCallWithArgsParentheses, :config do
       RUBY
     end
 
-    it 'auto-corrects single-line calls' do
+    it 'accepts parens in assignment in conditions' do
+      expect_no_offenses(<<-RUBY)
+        case response = get("server/list")
+        when server = response.take(1)
+          if @size ||= server.take(:size)
+            pass
+          elsif @@image &&= server.take(:image)
+            pass
+          end
+        end
+      RUBY
+    end
+
+    it 'autocorrects single-line calls' do
       expect_offense(<<~RUBY)
         top.test(1, 2, foo: bar(3))
                 ^^^^^^^^^^^^^^^^^^^ Omit parentheses for method calls with arguments.
@@ -664,7 +853,7 @@ RSpec.describe RuboCop::Cop::Style::MethodCallWithArgsParentheses, :config do
       RUBY
     end
 
-    it 'auto-corrects multi-line calls with trailing whitespace' do
+    it 'autocorrects multi-line calls with trailing whitespace' do
       trailing_whitespace = ' '
 
       expect_offense(<<~RUBY)
@@ -681,7 +870,7 @@ RSpec.describe RuboCop::Cop::Style::MethodCallWithArgsParentheses, :config do
       RUBY
     end
 
-    it 'auto-corrects complex multi-line calls' do
+    it 'autocorrects complex multi-line calls' do
       expect_offense(<<~RUBY)
         foo(arg,
            ^^^^^ Omit parentheses for method calls with arguments.
@@ -700,6 +889,16 @@ RSpec.describe RuboCop::Cop::Style::MethodCallWithArgsParentheses, :config do
       expect_no_offenses('Something.find(criteria: given)&.field')
     end
 
+    it 'accepts parens in operator method calls' do
+      expect_no_offenses(<<~RUBY)
+        data.[](value)
+        data&.[](value)
+        string.<<(even_more_string)
+        ruby.==(good)
+        ruby&.===(better)
+      RUBY
+    end
+
     context 'allowing parenthesis in chaining' do
       let(:cop_config) do
         {
@@ -778,14 +977,27 @@ RSpec.describe RuboCop::Cop::Style::MethodCallWithArgsParentheses, :config do
     end
   end
 
-  context 'when inspecting macro methods with IncludedMacros' do
+  context 'allowing parens in string interpolation' do
     let(:cop_config) do
       {
-        'IgnoreMacros' => 'true',
-        'IncludedMacros' => ['bar']
+        'EnforcedStyle' => 'omit_parentheses',
+        'AllowParenthesesInStringInterpolation' => true
       }
     end
 
+    it 'accepts parens for camel-case method names' do
+      expect_no_offenses(<<~'RUBY')
+        "#{t('this.is.good')}"
+        "#{t 'this.is.also.good'}"
+      RUBY
+    end
+  end
+
+  context 'when inspecting macro methods with IncludedMacros' do
+    let(:cop_config) { { 'IgnoreMacros' => 'true', 'IncludedMacros' => ['bar'] } }
+
+    it_behaves_like 'endless methods'
+
     context 'in a class body' do
       it 'finds offense' do
         expect_offense(<<~RUBY)
@@ -830,12 +1042,12 @@ RSpec.describe RuboCop::Cop::Style::MethodCallWithArgsParentheses, :config do
       end
     end
 
-    context 'for a macro in both IncludedMacros and IgnoredMethods' do
+    context 'for a macro in both IncludedMacros and AllowedMethods' do
       let(:cop_config) do
         {
           'IgnoreMacros' => 'true',
           'IncludedMacros' => ['bar'],
-          'IgnoredMethods' => ['bar']
+          'AllowedMethods' => ['bar']
         }
       end
 
