@@ -43,6 +43,167 @@ RSpec.describe RuboCop::Cop::Style::MutableConstant, :config do
     end
   end
 
+  shared_examples 'literals that are frozen' do |o|
+    let(:prefix) { o }
+
+    it_behaves_like 'immutable objects', '[1, 2, 3]'
+    it_behaves_like 'immutable objects', '%w(a b c)'
+    it_behaves_like 'immutable objects', '{ a: 1, b: 2 }'
+    it_behaves_like 'immutable objects', "'str'"
+    it_behaves_like 'immutable objects', '"top#{1 + 2}"'
+    it_behaves_like 'immutable objects', '1'
+    it_behaves_like 'immutable objects', '1.5'
+    it_behaves_like 'immutable objects', ':sym'
+    it_behaves_like 'immutable objects', 'FOO + BAR'
+    it_behaves_like 'immutable objects', 'FOO - BAR'
+    it_behaves_like 'immutable objects', "'foo' + 'bar'"
+    it_behaves_like 'immutable objects', "ENV['foo']"
+    it_behaves_like 'immutable objects', "::ENV['foo']"
+  end
+
+  shared_examples 'literals that are not frozen' do |o|
+    let(:prefix) { o }
+
+    it_behaves_like 'mutable objects', '[1, 2, 3]'
+    it_behaves_like 'mutable objects', '%w(a b c)'
+    it_behaves_like 'mutable objects', '{ a: 1, b: 2 }'
+    it_behaves_like 'mutable objects', "'str'"
+    it_behaves_like 'mutable objects', '"top#{1 + 2}"'
+
+    it_behaves_like 'immutable objects', '1'
+    it_behaves_like 'immutable objects', '1.5'
+    it_behaves_like 'immutable objects', ':sym'
+    it_behaves_like 'immutable objects', 'FOO + BAR'
+    it_behaves_like 'immutable objects', 'FOO - BAR'
+    it_behaves_like 'immutable objects', "'foo' + 'bar'"
+    it_behaves_like 'immutable objects', "ENV['foo']"
+    it_behaves_like 'immutable objects', "::ENV['foo']"
+  end
+
+  shared_examples 'string literal' do
+    # TODO : It is not yet decided when frozen string will be the default.
+    # It has been abandoned in the Ruby 3.0 period, but may default in
+    # the long run. So these tests are left with a provisional value of 4.0.
+    if RuboCop::TargetRuby.supported_versions.include?(4.0)
+      context 'when the target ruby version >= 4.0' do
+        let(:ruby_version) { 4.0 }
+
+        context 'when the frozen string literal comment is missing' do
+          it_behaves_like 'immutable objects', '"#{a}"'
+        end
+
+        context 'when the frozen string literal comment is true' do
+          let(:prefix) { '# frozen_string_literal: true' }
+
+          it_behaves_like 'immutable objects', '"#{a}"'
+        end
+
+        context 'when the frozen string literal comment is false' do
+          let(:prefix) { '# frozen_string_literal: false' }
+
+          it_behaves_like 'immutable objects', '"#{a}"'
+        end
+      end
+    end
+
+    context 'Ruby 3.0 or higher', :ruby30 do
+      context 'when the frozen string literal comment is missing' do
+        it_behaves_like 'mutable objects', '"#{a}"'
+      end
+
+      context 'when the frozen string literal comment is true' do
+        let(:prefix) { '# frozen_string_literal: true' }
+
+        it_behaves_like 'mutable objects', '"#{a}"'
+        it_behaves_like 'immutable objects', <<~'RUBY'
+          <<~HERE
+            foo
+            bar
+          HERE
+        RUBY
+        it 'registers an offense when using interpolated heredoc constant' do
+          expect_offense(<<~'RUBY')
+            # frozen_string_literal: true
+
+            CONST = <<~HERE
+                    ^^^^^^^ Freeze mutable objects assigned to constants.
+              foo #{use_interpolation}
+              bar
+            HERE
+          RUBY
+        end
+
+        it 'does not register an offense when using a multiline string' do
+          expect_no_offenses(<<~RUBY)
+            # frozen_string_literal: true
+
+            CONST = 'foo' \
+                    'bar'
+          RUBY
+        end
+
+        it 'registers an offense when using a multiline string with interpolation' do
+          expect_offense(<<~'RUBY')
+            # frozen_string_literal: true
+
+            CONST = "#{foo}" \
+                    ^^^^^^^^^^ Freeze mutable objects assigned to constants.
+                    'bar'
+          RUBY
+        end
+      end
+
+      context 'when the frozen string literal comment is false' do
+        let(:prefix) { '# frozen_string_literal: false' }
+
+        it_behaves_like 'mutable objects', '"#{a}"'
+      end
+    end
+
+    context 'Ruby 2.7 or lower', :ruby27 do
+      context 'when the frozen string literal comment is missing' do
+        it_behaves_like 'mutable objects', '"#{a}"'
+      end
+
+      context 'when the frozen string literal comment is true' do
+        let(:prefix) { '# frozen_string_literal: true' }
+
+        it_behaves_like 'immutable objects', '"#{a}"'
+        it_behaves_like 'immutable objects', <<~'RUBY'
+          <<~HERE
+            foo
+            bar
+          HERE
+        RUBY
+        it 'does not register an offense when using interpolated heredoc constant' do
+          expect_no_offenses(<<~'RUBY')
+            # frozen_string_literal: true
+
+            CONST = <<~HERE
+              foo #{use_interpolation}
+              bar
+            HERE
+          RUBY
+        end
+
+        it 'does not register an offense when using a multiline string' do
+          expect_no_offenses(<<~RUBY)
+            # frozen_string_literal: true
+
+            CONST = 'foo' \
+                    'bar'
+          RUBY
+        end
+      end
+
+      context 'when the frozen string literal comment is false' do
+        let(:prefix) { '# frozen_string_literal: false' }
+
+        it_behaves_like 'mutable objects', '"#{a}"'
+      end
+    end
+  end
+
   context 'Strict: false' do
     let(:cop_config) { { 'EnforcedStyle' => 'literals' } }
 
@@ -72,6 +233,7 @@ RSpec.describe RuboCop::Cop::Style::MutableConstant, :config do
             FOO = *1..10
                   ^^^^^^ Freeze mutable objects assigned to constants.
           RUBY
+
           expect_correction(<<~RUBY)
             FOO = (1..10).to_a.freeze
           RUBY
@@ -83,6 +245,7 @@ RSpec.describe RuboCop::Cop::Style::MutableConstant, :config do
               FOO = *(1..10)
                     ^^^^^^^^ Freeze mutable objects assigned to constants.
             RUBY
+
             expect_correction(<<~RUBY)
               FOO = (1..10).to_a.freeze
             RUBY
@@ -92,113 +255,170 @@ RSpec.describe RuboCop::Cop::Style::MutableConstant, :config do
     end
 
     context 'when assigning an array without brackets' do
-      it 'adds brackets when auto-correcting' do
+      it 'adds brackets when autocorrecting' do
         expect_offense(<<~RUBY)
           XXX = YYY, ZZZ
                 ^^^^^^^^ Freeze mutable objects assigned to constants.
         RUBY
+
         expect_correction(<<~RUBY)
           XXX = [YYY, ZZZ].freeze
         RUBY
       end
 
-      it 'does not add brackets to %w() arrays' do
+      it 'does not insert brackets for %w() arrays' do
         expect_offense(<<~RUBY)
           XXX = %w(YYY ZZZ)
                 ^^^^^^^^^^^ Freeze mutable objects assigned to constants.
         RUBY
+
         expect_correction(<<~RUBY)
           XXX = %w(YYY ZZZ).freeze
         RUBY
       end
     end
 
-    context 'when assigning a range (irange) without parenthesis' do
-      it 'adds parenthesis when auto-correcting' do
-        expect_offense(<<~RUBY)
-          XXX = 1..99
-                ^^^^^ Freeze mutable objects assigned to constants.
-        RUBY
-        expect_correction(<<~RUBY)
-          XXX = (1..99).freeze
-        RUBY
-      end
-
-      it 'does not add parenthesis to range enclosed in parentheses' do
-        expect_offense(<<~RUBY)
-          XXX = (1..99)
-                ^^^^^^^ Freeze mutable objects assigned to constants.
-        RUBY
-        expect_correction(<<~RUBY)
-          XXX = (1..99).freeze
-        RUBY
-      end
-    end
-
-    context 'when assigning a range (erange) without parenthesis' do
-      it 'adds parenthesis when auto-correcting' do
-        expect_offense(<<~RUBY)
-          XXX = 1...99
-                ^^^^^^ Freeze mutable objects assigned to constants.
-        RUBY
-        expect_correction(<<~RUBY)
-          XXX = (1...99).freeze
-        RUBY
-      end
-
-      it 'does not add parenthesis to range enclosed in parentheses' do
-        expect_offense(<<~RUBY)
-          XXX = (1...99)
-                ^^^^^^^^ Freeze mutable objects assigned to constants.
-        RUBY
-        expect_correction(<<~RUBY)
-          XXX = (1...99).freeze
-        RUBY
-      end
-    end
-
-    context 'when the constant is a frozen string literal' do
-      # TODO : It is not yet decided when frozen string will be the default.
-      # It has been abandoned in the Ruby 3.0 period, but may default in
-      # the long run. So these tests are left with a provisional value of 4.0.
-      if RuboCop::TargetRuby.supported_versions.include?(4.0)
-        context 'when the target ruby version >= 4.0' do
-          let(:ruby_version) { 4.0 }
-
-          context 'when the frozen string literal comment is missing' do
-            it_behaves_like 'immutable objects', '"#{a}"'
-          end
-
-          context 'when the frozen string literal comment is true' do
-            let(:prefix) { '# frozen_string_literal: true' }
-
-            it_behaves_like 'immutable objects', '"#{a}"'
-          end
-
-          context 'when the frozen string literal comment is false' do
-            let(:prefix) { '# frozen_string_literal: false' }
-
-            it_behaves_like 'immutable objects', '"#{a}"'
-          end
+    # Ruby 3.0's Regexp and Range literals are frozen.
+    #
+    # https://bugs.ruby-lang.org/issues/15504
+    # https://bugs.ruby-lang.org/issues/16377
+    context 'Ruby 3.0 or higher', :ruby30 do
+      context 'when assigning a regexp' do
+        it 'does not register an offense' do
+          expect_no_offenses(<<~RUBY)
+            XXX = /regexp/
+          RUBY
         end
       end
 
-      context 'when the frozen string literal comment is missing' do
-        it_behaves_like 'mutable objects', '"#{a}"'
+      context 'when assigning a range (irange)' do
+        it 'does not register an offense when without parenthesis' do
+          expect_no_offenses(<<~RUBY)
+            XXX = 1..99
+          RUBY
+        end
+
+        it 'does not register an offense when with parenthesis' do
+          expect_no_offenses(<<~RUBY)
+            XXX = (1..99)
+          RUBY
+        end
       end
 
-      context 'when the frozen string literal comment is true' do
-        let(:prefix) { '# frozen_string_literal: true' }
+      context 'when assigning a range (erange)' do
+        it 'does not register an offense when without parenthesis' do
+          expect_no_offenses(<<~RUBY)
+            XXX = 1...99
+          RUBY
+        end
 
-        it_behaves_like 'immutable objects', '"#{a}"'
+        it 'does not register an offense when with parenthesis' do
+          expect_no_offenses(<<~RUBY)
+            XXX = (1...99)
+          RUBY
+        end
       end
 
-      context 'when the frozen string literal comment is false' do
-        let(:prefix) { '# frozen_string_literal: false' }
+      context 'when using shareable_constant_value' do
+        it_behaves_like 'literals that are frozen', '# shareable_constant_value: literal'
+        it_behaves_like 'literals that are frozen', '# shareable_constant_value: experimental_everything'
+        it_behaves_like 'literals that are frozen', '# shareable_constant_value: experimental_copy'
+        it_behaves_like 'literals that are not frozen', '# shareable_constant_value: none'
+      end
 
-        it_behaves_like 'mutable objects', '"#{a}"'
+      it 'raises offense when shareable_constant_value is specified as an inline comment' do
+        expect_offense(<<~RUBY)
+          X = [1, 2, 3] # shareable_constant_value: literal
+              ^^^^^^^^^ Freeze mutable objects assigned to constants.
+          Y = [4, 5, 6]
+              ^^^^^^^^^ Freeze mutable objects assigned to constants.
+        RUBY
+      end
+
+      it 'raises offense only for shareable_constant_value as none when set in the order of: literal, none and experimental_everything' do
+        expect_offense(<<~RUBY)
+          # shareable_constant_value: literal
+          X = [1, 2, 3]
+          # shareable_constant_value: none
+          Y = [4, 5, 6]
+              ^^^^^^^^^ Freeze mutable objects assigned to constants.
+          # shareable_constant_value: experimental_everything
+          Z = [7, 8, 9]
+        RUBY
       end
     end
+
+    context 'Ruby 2.7 or lower', :ruby27 do
+      context 'when assigning a regexp' do
+        it 'registers an offense' do
+          expect_offense(<<~RUBY)
+            XXX = /regexp/
+                  ^^^^^^^^ Freeze mutable objects assigned to constants.
+          RUBY
+
+          expect_correction(<<~RUBY)
+            XXX = /regexp/.freeze
+          RUBY
+        end
+      end
+
+      context 'when assigning a range (irange) without parenthesis' do
+        it 'adds parentheses when autocorrecting' do
+          expect_offense(<<~RUBY)
+            XXX = 1..99
+                  ^^^^^ Freeze mutable objects assigned to constants.
+          RUBY
+
+          expect_correction(<<~RUBY)
+            XXX = (1..99).freeze
+          RUBY
+        end
+
+        it 'does not insert parenthesis to range enclosed in parentheses' do
+          expect_offense(<<~RUBY)
+            XXX = (1..99)
+                  ^^^^^^^ Freeze mutable objects assigned to constants.
+          RUBY
+
+          expect_correction(<<~RUBY)
+            XXX = (1..99).freeze
+          RUBY
+        end
+      end
+
+      context 'when assigning a range (erange) without parenthesis' do
+        it 'adds parentheses when autocorrecting' do
+          expect_offense(<<~RUBY)
+            XXX = 1...99
+                  ^^^^^^ Freeze mutable objects assigned to constants.
+          RUBY
+
+          expect_correction(<<~RUBY)
+            XXX = (1...99).freeze
+          RUBY
+        end
+
+        it 'does not insert parenthesis to range enclosed in parentheses' do
+          expect_offense(<<~RUBY)
+            XXX = (1...99)
+                  ^^^^^^^^ Freeze mutable objects assigned to constants.
+          RUBY
+
+          expect_correction(<<~RUBY)
+            XXX = (1...99).freeze
+          RUBY
+        end
+      end
+
+      context 'when using shareable_constant_values' do
+        it_behaves_like 'literals that are not frozen', '# shareable_constant_value: literal'
+        it_behaves_like 'literals that are not frozen', '# shareable_constant_value: experimental_everything'
+        it_behaves_like 'literals that are not frozen', '# shareable_constant_value: experimental_copy'
+        it_behaves_like 'literals that are not frozen', '# shareable_constant_value: none'
+      end
+    end
+
+    it_behaves_like 'string literal'
   end
 
   context 'Strict: true' do
@@ -244,6 +464,7 @@ RSpec.describe RuboCop::Cop::Style::MutableConstant, :config do
             FOO = *1..10
                   ^^^^^^ Freeze mutable objects assigned to constants.
           RUBY
+
           expect_correction(<<~RUBY)
             FOO = (1..10).to_a.freeze
           RUBY
@@ -255,6 +476,7 @@ RSpec.describe RuboCop::Cop::Style::MutableConstant, :config do
               FOO = *(1..10)
                     ^^^^^^^^ Freeze mutable objects assigned to constants.
             RUBY
+
             expect_correction(<<~RUBY)
               FOO = (1..10).to_a.freeze
             RUBY
@@ -270,6 +492,7 @@ RSpec.describe RuboCop::Cop::Style::MutableConstant, :config do
             CONST = FOO %{o} BAR
                     ^^^^^{o}^^^^ Freeze mutable objects assigned to constants.
           RUBY
+
           expect_correction(<<~RUBY)
             CONST = (FOO #{o} BAR).freeze
           RUBY
@@ -293,6 +516,7 @@ RSpec.describe RuboCop::Cop::Style::MutableConstant, :config do
           CONST = FOO + BAR + BAZ
                   ^^^^^^^^^^^^^^^ Freeze mutable objects assigned to constants.
         RUBY
+
         expect_correction(<<~RUBY)
           FOO = [1].freeze
           BAR = [2].freeze
@@ -360,6 +584,7 @@ RSpec.describe RuboCop::Cop::Style::MutableConstant, :config do
           CONST = FOO + 'bar'
                   ^^^^^^^^^^^ Freeze mutable objects assigned to constants.
         RUBY
+
         expect_correction(<<~RUBY)
           CONST = (FOO + 'bar').freeze
         RUBY
@@ -370,6 +595,7 @@ RSpec.describe RuboCop::Cop::Style::MutableConstant, :config do
           CONST = 'foo' + 'bar' + 'baz'
                   ^^^^^^^^^^^^^^^^^^^^^ Freeze mutable objects assigned to constants.
         RUBY
+
         expect_correction(<<~RUBY)
           CONST = ('foo' + 'bar' + 'baz').freeze
         RUBY
@@ -377,21 +603,23 @@ RSpec.describe RuboCop::Cop::Style::MutableConstant, :config do
     end
 
     context 'when assigning an array without brackets' do
-      it 'adds brackets when auto-correcting' do
+      it 'adds brackets when autocorrecting' do
         expect_offense(<<~RUBY)
           XXX = YYY, ZZZ
                 ^^^^^^^^ Freeze mutable objects assigned to constants.
         RUBY
+
         expect_correction(<<~RUBY)
           XXX = [YYY, ZZZ].freeze
         RUBY
       end
 
-      it 'does not add brackets to %w() arrays' do
+      it 'does not insert brackets for %w() arrays' do
         expect_offense(<<~RUBY)
           XXX = %w(YYY ZZZ)
                 ^^^^^^^^^^^ Freeze mutable objects assigned to constants.
         RUBY
+
         expect_correction(<<~RUBY)
           XXX = %w(YYY ZZZ).freeze
         RUBY
@@ -405,6 +633,7 @@ RSpec.describe RuboCop::Cop::Style::MutableConstant, :config do
           SOMETHING
         HERE
       RUBY
+
       expect_correction(<<~RUBY)
         FOO = <<-HERE.freeze
           SOMETHING
@@ -412,20 +641,6 @@ RSpec.describe RuboCop::Cop::Style::MutableConstant, :config do
       RUBY
     end
 
-    context 'when the frozen string literal comment is missing' do
-      it_behaves_like 'mutable objects', '"#{a}"'
-    end
-
-    context 'when the frozen string literal comment is true' do
-      let(:prefix) { '# frozen_string_literal: true' }
-
-      it_behaves_like 'immutable objects', '"#{a}"'
-    end
-
-    context 'when the frozen string literal comment is false' do
-      let(:prefix) { '# frozen_string_literal: false' }
-
-      it_behaves_like 'mutable objects', '"#{a}"'
-    end
+    it_behaves_like 'string literal'
   end
 end
