@@ -1,8 +1,6 @@
 # frozen_string_literal: true
 
-RSpec.describe RuboCop::Cop::Style::NestedTernaryOperator do
-  subject(:cop) { described_class.new }
-
+RSpec.describe RuboCop::Cop::Style::NestedTernaryOperator, :config do
   it 'registers an offense and corrects for a nested ternary operator expression' do
     expect_offense(<<~RUBY)
       a ? (b ? b1 : b2) : a2
@@ -11,9 +9,9 @@ RSpec.describe RuboCop::Cop::Style::NestedTernaryOperator do
 
     expect_correction(<<~RUBY)
       if a
-        b ? b1 : b2
+      b ? b1 : b2
       else
-        a2
+      a2
       end
     RUBY
   end
@@ -27,9 +25,24 @@ RSpec.describe RuboCop::Cop::Style::NestedTernaryOperator do
 
     expect_correction(<<~RUBY)
       if cond
-        foo
+      foo
       else
-        bar(foo.a ? foo.b : foo) { |e, k| e.nil? ? nil : e[k] }
+      bar(foo.a ? foo.b : foo) { |e, k| e.nil? ? nil : e[k] }
+      end
+    RUBY
+  end
+
+  it 'registers an offense and corrects for a nested ternary operator expression with no parentheses on the outside' do
+    expect_offense(<<~RUBY)
+      x ? y + (z ? 1 : 0) : nil
+               ^^^^^^^^^ Ternary operators must not be nested. Prefer `if` or `else` constructs instead.
+    RUBY
+
+    expect_correction(<<~RUBY)
+      if x
+      y + (z ? 1 : 0)
+      else
+      nil
       end
     RUBY
   end
@@ -43,4 +56,24 @@ RSpec.describe RuboCop::Cop::Style::NestedTernaryOperator do
       end
     RUBY
   end
+
+  it 'can handle multiple nested ternaries' do
+    expect_offense(<<~RUBY)
+      a ? b : c ? d : e ? f : g
+                      ^^^^^^^^^ Ternary operators must not be nested. Prefer `if` or `else` constructs instead.
+              ^^^^^^^^^^^^^^^^^ Ternary operators must not be nested. Prefer `if` or `else` constructs instead.
+    RUBY
+
+    expect_correction(<<~RUBY)
+      if a
+      b
+      else
+      if c
+      d
+      else
+      e ? f : g
+      end
+      end
+    RUBY
+  end
 end
