@@ -1,8 +1,6 @@
 # frozen_string_literal: true
 
-RSpec.describe RuboCop::Cop::Style::Proc do
-  subject(:cop) { described_class.new }
-
+RSpec.describe RuboCop::Cop::Style::Proc, :config do
   it 'registers an offense for a Proc.new call' do
     expect_offense(<<~RUBY)
       f = Proc.new { |x| puts x }
@@ -32,4 +30,17 @@ RSpec.describe RuboCop::Cop::Style::Proc do
   it 'accepts the ::Proc.new call without block' do
     expect_no_offenses('p = ::Proc.new')
   end
+
+  context 'Ruby 2.7', :ruby27 do
+    it 'registers an offense for a Proc.new call' do
+      expect_offense(<<~RUBY)
+        f = Proc.new { puts _1 }
+            ^^^^^^^^ Use `proc` instead of `Proc.new`.
+      RUBY
+
+      expect_correction(<<~RUBY)
+        f = proc { puts _1 }
+      RUBY
+    end
+  end
 end
