@@ -2,11 +2,7 @@
 
 RSpec.describe RuboCop::Cop::Style::SafeNavigation, :config do
   let(:cop_config) { { 'ConvertCodeThatCanStartToReturnNil' => false } }
-
-  let(:message) do
-    'Use safe navigation (`&.`) instead of checking if an object ' \
-    'exists before calling the method.'
-  end
+  let(:target_ruby_version) { 2.3 }
 
   it 'allows calls to methods not safeguarded by respond_to' do
     expect_no_offenses('foo.bar')
@@ -55,13 +51,11 @@ RSpec.describe RuboCop::Cop::Style::SafeNavigation, :config do
     expect_no_offenses('foo && !foo.bar.baz?')
   end
 
-  it 'allows method call that is used in a comparison safe guarded by ' \
-     'an object check' do
+  it 'allows method call that is used in a comparison safe guarded by an object check' do
     expect_no_offenses('foo.bar > 2 if foo')
   end
 
-  it 'allows method call that is used in a regex comparison ' \
-     'safe guarded by an object check' do
+  it 'allows method call that is used in a regex comparison safe guarded by an object check' do
     expect_no_offenses('foo.bar =~ /baz/ if foo')
   end
 
@@ -70,66 +64,62 @@ RSpec.describe RuboCop::Cop::Style::SafeNavigation, :config do
     expect_no_offenses('foo.bar !~ /baz/ if foo')
   end
 
-  it 'allows method call that is used in a spaceship comparison ' \
-     'safe guarded by an object check' do
+  it 'allows method call that is used in a spaceship comparison safe guarded by an object check' do
     expect_no_offenses('foo.bar <=> baz if foo')
   end
 
-  it 'allows an object check before a method call that is used in ' \
-     'a comparison' do
+  it 'allows an object check before a method call that is used in a comparison' do
     expect_no_offenses('foo && foo.bar > 2')
   end
 
-  it 'allows an object check before a method call that is used in ' \
-     'a regex comparison' do
+  it 'allows an object check before a method call that is used in a regex comparison' do
     expect_no_offenses('foo && foo.bar =~ /baz/')
   end
 
-  it 'allows an object check before a method call that is used in ' \
-     'a negated regex comparison' do
+  it 'allows an object check before a method call that is used in a negated regex comparison' do
     expect_no_offenses('foo && foo.bar !~ /baz/')
   end
 
-  it 'allows an object check before a method call that is used in ' \
-     'a spaceship comparison' do
+  it 'allows an object check before a method call that is used with `empty?`' do
+    expect_no_offenses('foo && foo.empty?')
+  end
+
+  it 'allows an object check before a method call that is used in a spaceship comparison' do
     expect_no_offenses('foo && foo.bar <=> baz')
   end
 
-  it 'allows an object check before a method chain that is used in ' \
-     'a comparison' do
+  it 'allows an object check before a method chain that is used in a comparison' do
     expect_no_offenses('foo && foo.bar.baz > 2')
   end
 
-  it 'allows a method chain that is used in a comparison ' \
-     'safe guarded by an object check' do
+  it 'allows a method chain that is used in a comparison safe guarded by an object check' do
     expect_no_offenses('foo.bar.baz > 2 if foo')
   end
 
-  it 'allows a method call safeguarded with a negative check ' \
-     'for the object when using `unless`' do
+  it 'allows a method call safeguarded with a negative check for the object when using `unless`' do
     expect_no_offenses('obj.do_something unless obj')
   end
 
-  it 'allows a method call safeguarded with a negative check ' \
-     'for the object when using `if`' do
+  it 'allows a method call safeguarded with a negative check for the object when using `if`' do
     expect_no_offenses('obj.do_something if !obj')
   end
 
-  it 'allows method calls that do not get called using . safe guarded by ' \
-     'an object check' do
+  it 'allows method calls that do not get called using . safe guarded by an object check' do
     expect_no_offenses('foo + bar if foo')
   end
 
-  it 'allows chained method calls during arithmetic operations safe ' \
-     'guarded by an object check' do
+  it 'allows chained method calls during arithmetic operations safe guarded by an object check' do
     expect_no_offenses('foo.baz + bar if foo')
   end
 
-  it 'allows chained method calls during assignment safe guarded' \
-     'by an object check' do
+  it 'allows chained method calls during assignment safe guardedby an object check' do
     expect_no_offenses('foo.baz = bar if foo')
   end
 
+  it 'allows an object check before a negated method call with a safe navigation' do
+    expect_no_offenses('obj && !obj&.do_something')
+  end
+
   it 'allows object checks in the condition of an elsif statement ' \
      'and a method call on that object in the body' do
     expect_no_offenses(<<~RUBY)
@@ -144,7 +134,7 @@ RSpec.describe RuboCop::Cop::Style::SafeNavigation, :config do
   it 'allows for empty if blocks with comments' do
     expect_no_offenses(<<~RUBY)
       if foo
-        # a random commnet
+        # a random comment
         # TODO: Implement this before
       end
     RUBY
@@ -161,11 +151,36 @@ RSpec.describe RuboCop::Cop::Style::SafeNavigation, :config do
     RUBY
   end
 
+  # See https://github.com/rubocop/rubocop/issues/8781
+  it 'does not move comments that are inside an inner block' do
+    expect_offense(<<~RUBY)
+      # Comment 1
+      if x
+      ^^^^ Use safe navigation (`&.`) instead of checking if an object exists before calling the method.
+        # Comment 2
+        x.each do
+          # Comment 3
+          # Comment 4
+        end
+        # Comment 5
+      end
+    RUBY
+
+    expect_correction(<<~RUBY)
+      # Comment 1
+      # Comment 2
+      # Comment 5
+      x&.each do
+          # Comment 3
+          # Comment 4
+        end
+    RUBY
+  end
+
   shared_examples 'all variable types' do |variable|
     context 'modifier if' do
       shared_examples 'safe guarding logical break keywords' do |keyword|
-        it "allows a method call being passed to #{keyword} safe guarded " \
-           'by an object check' do
+        it "allows a method call being passed to #{keyword} safe guarded by an object check" do
           expect_no_offenses(<<~RUBY)
             something.each do
               #{keyword} #{variable}.bar if #{variable}
@@ -194,6 +209,17 @@ RSpec.describe RuboCop::Cop::Style::SafeNavigation, :config do
         RUBY
       end
 
+      it 'registers an offense when safe guard check and safe navigation method call are connected with `&&` condition' do
+        expect_offense(<<~RUBY, variable: variable)
+          %{variable} && %{variable}&.do_something
+          ^{variable}^^^^^{variable}^^^^^^^^^^^^^^ Use safe navigation (`&.`) instead of checking if an object exists before calling the method.
+        RUBY
+
+        expect_correction(<<~RUBY)
+          #{variable}&.do_something
+        RUBY
+      end
+
       it 'registers an offense for a method call on an accessor ' \
          'safeguarded by a check for the accessed variable' do
         expect_offense(<<~RUBY, variable: variable)
@@ -206,8 +232,7 @@ RSpec.describe RuboCop::Cop::Style::SafeNavigation, :config do
         RUBY
       end
 
-      it 'registers an offense for a method call safeguarded with a check ' \
-         'for the object' do
+      it 'registers an offense for a method call safeguarded with a check for the object' do
         expect_offense(<<~RUBY, variable: variable)
           %{variable}.bar if %{variable}
           ^{variable}^^^^^^^^^{variable} Use safe navigation (`&.`) instead [...]
@@ -254,8 +279,7 @@ RSpec.describe RuboCop::Cop::Style::SafeNavigation, :config do
         RUBY
       end
 
-      it 'registers an offense for a chained method call safeguarded ' \
-          'with a check for the object' do
+      it 'registers an offense for a chained method call safeguarded with a check for the object' do
         expect_offense(<<~RUBY, variable: variable)
           %{variable}.one.two(baz) { |e| e.qux } if %{variable}
           ^{variable}^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^{variable} Use safe navigation (`&.`) instead [...]
@@ -314,8 +338,7 @@ RSpec.describe RuboCop::Cop::Style::SafeNavigation, :config do
         RUBY
       end
 
-      it 'registers an offense for a method call safeguarded with a nil ' \
-         'check for the object' do
+      it 'registers an offense for a method call safeguarded with a nil check for the object' do
         expect_offense(<<~RUBY, variable: variable)
           %{variable}.bar unless %{variable}.nil?
           ^{variable}^^^^^^^^^^^^^{variable}^^^^^ Use safe navigation (`&.`) instead [...]
@@ -363,7 +386,7 @@ RSpec.describe RuboCop::Cop::Style::SafeNavigation, :config do
       end
 
       it 'registers an offense for a chained method call safeguarded ' \
-          'with an unless nil check for the object' do
+         'with an unless nil check for the object' do
         expect_offense(<<~RUBY, variable: variable)
           %{variable}.one.two(baz) { |e| e.qux } unless %{variable}.nil?
           ^{variable}^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^{variable}^^^^^ Use safe navigation (`&.`) instead [...]
@@ -448,8 +471,7 @@ RSpec.describe RuboCop::Cop::Style::SafeNavigation, :config do
     end
 
     context 'if expression' do
-      it 'registers an offense for a single method call inside of a check ' \
-         'for the object' do
+      it 'registers an offense for a single method call inside of a check for the object' do
         expect_offense(<<~RUBY, variable: variable)
           if %{variable}
           ^^^^{variable} Use safe navigation (`&.`) instead [...]
@@ -504,8 +526,7 @@ RSpec.describe RuboCop::Cop::Style::SafeNavigation, :config do
         RUBY
       end
 
-      it 'registers an offense for a single method call inside of a ' \
-         'non-nil check for the object' do
+      it 'registers an offense for a single method call inside of a non-nil check for the object' do
         expect_offense(<<~RUBY, variable: variable)
           if !%{variable}.nil?
           ^^^^^{variable}^^^^^ Use safe navigation (`&.`) instead [...]
@@ -711,8 +732,7 @@ RSpec.describe RuboCop::Cop::Style::SafeNavigation, :config do
         RUBY
       end
 
-      it 'allows a single method call inside of a check for the object ' \
-         'with an else' do
+      it 'allows a single method call inside of a check for the object with an else' do
         expect_no_offenses(<<~RUBY)
           if #{variable}
             #{variable}.bar
@@ -735,8 +755,7 @@ RSpec.describe RuboCop::Cop::Style::SafeNavigation, :config do
       context 'ConvertCodeThatCanStartToReturnNil true' do
         let(:cop_config) { { 'ConvertCodeThatCanStartToReturnNil' => true } }
 
-        it 'registers an offense for a non-nil object check followed by a ' \
-           'method call' do
+        it 'registers an offense for a non-nil object check followed by a method call' do
           expect_offense(<<~RUBY, variable: variable)
             !%{variable}.nil? && %{variable}.bar
             ^^{variable}^^^^^^^^^^{variable}^^^^ Use safe navigation (`&.`) instead [...]
@@ -783,8 +802,7 @@ RSpec.describe RuboCop::Cop::Style::SafeNavigation, :config do
           RUBY
         end
 
-        it 'registers an offense for an object check followed by a ' \
-           'method call' do
+        it 'registers an offense for an object check followed by a method call' do
           expect_offense(<<~RUBY, variable: variable)
             %{variable} && %{variable}.bar
             ^{variable}^^^^^{variable}^^^^ Use safe navigation (`&.`) instead [...]
@@ -795,8 +813,7 @@ RSpec.describe RuboCop::Cop::Style::SafeNavigation, :config do
           RUBY
         end
 
-        it 'registers an offense for an object check followed by a ' \
-           'method call with params' do
+        it 'registers an offense for an object check followed by a method call with params' do
           expect_offense(<<~RUBY, variable: variable)
             %{variable} && %{variable}.bar(baz)
             ^{variable}^^^^^{variable}^^^^^^^^^ Use safe navigation (`&.`) instead [...]
@@ -807,8 +824,7 @@ RSpec.describe RuboCop::Cop::Style::SafeNavigation, :config do
           RUBY
         end
 
-        it 'registers an offense for an object check followed by a ' \
-           'method call with a block' do
+        it 'registers an offense for an object check followed by a method call with a block' do
           expect_offense(<<~RUBY, variable: variable)
             %{variable} && %{variable}.bar { |e| e.qux }
             ^{variable}^^^^^{variable}^^^^^^^^^^^^^^^^^^ Use safe navigation (`&.`) instead [...]
@@ -847,8 +863,7 @@ RSpec.describe RuboCop::Cop::Style::SafeNavigation, :config do
           RUBY
         end
 
-        it 'corrects an object check followed by a method call and ' \
-            'another check' do
+        it 'corrects an object check followed by a method call and another check' do
           expect_offense(<<~RUBY, variable: variable)
             %{variable} && %{variable}.bar && something
             ^{variable}^^^^^{variable}^^^^ Use safe navigation (`&.`) instead [...]
@@ -872,12 +887,55 @@ RSpec.describe RuboCop::Cop::Style::SafeNavigation, :config do
             RUBY
           end
 
+          context 'MaxChainLength: 1' do
+            let(:cop_config) { { 'MaxChainLength' => 1 } }
+
+            it 'registers an offense for an object check followed by 1 chained method calls' do
+              expect_offense(<<~RUBY, variable: variable)
+                %{variable} && %{variable}.one
+                ^{variable}^^^^^{variable}^^^^ Use safe navigation (`&.`) instead [...]
+              RUBY
+
+              expect_correction(<<~RUBY)
+                #{variable}&.one
+              RUBY
+            end
+
+            it 'allows an object check followed by 2 chained method calls' do
+              expect_no_offenses(<<~RUBY)
+                #{variable} && #{variable}.one.two
+              RUBY
+            end
+          end
+
+          context 'MaxChainLength: 3' do
+            let(:cop_config) { { 'MaxChainLength' => 3 } }
+
+            it 'registers an offense for an object check followed by 3 chained method calls' do
+              expect_offense(<<~RUBY, variable: variable)
+                %{variable} && %{variable}.one.two.three
+                ^{variable}^^^^^{variable}^^^^^^^^^^^^^^ Use safe navigation (`&.`) instead [...]
+              RUBY
+
+              expect_correction(<<~RUBY)
+                #{variable}&.one&.two&.three
+              RUBY
+            end
+
+            it 'allows an object check followed by 4 chained method calls' do
+              expect_no_offenses(<<~RUBY)
+                #{variable} && #{variable}.one.two.three.fore
+              RUBY
+            end
+          end
+
           context 'with Lint/SafeNavigationChain disabled' do
             let(:config) do
-              RuboCop::Config.new('Lint/SafeNavigationChain' => {
-                                    'Enabled' => false
-                                  },
-                                  'Style/SafeNavigation' => cop_config)
+              RuboCop::Config.new(
+                'AllCops' => { 'TargetRubyVersion' => target_ruby_version },
+                'Lint/SafeNavigationChain' => { 'Enabled' => false },
+                'Style/SafeNavigation' => cop_config
+              )
             end
 
             it 'allows an object check followed by chained method calls' do
@@ -886,8 +944,7 @@ RSpec.describe RuboCop::Cop::Style::SafeNavigation, :config do
               RUBY
             end
 
-            it 'allows an object check followed by chained method calls ' \
-               'with blocks' do
+            it 'allows an object check followed by chained method calls with blocks' do
               expect_no_offenses(<<~RUBY)
                 #{variable} && #{variable}.one { |a| b }.two(baz) { |e| e.qux }
               RUBY
@@ -903,27 +960,23 @@ RSpec.describe RuboCop::Cop::Style::SafeNavigation, :config do
           expect_no_offenses("!#{variable}.nil? && #{variable}.bar")
         end
 
-        it 'allows a non-nil object check followed by a method call ' \
-           'with params' do
+        it 'allows a non-nil object check followed by a method call with params' do
           expect_no_offenses("!#{variable}.nil? && #{variable}.bar(baz)")
         end
 
-        it 'allows a non-nil object check followed by a method call ' \
-           'with a block' do
+        it 'allows a non-nil object check followed by a method call with a block' do
           expect_no_offenses(<<~RUBY)
             !#{variable}.nil? && #{variable}.bar { |e| e.qux }
           RUBY
         end
 
-        it 'allows a non-nil object check followed by a method call ' \
-           'with params and a block' do
+        it 'allows a non-nil object check followed by a method call with params and a block' do
           expect_no_offenses(<<~RUBY)
             !#{variable}.nil? && #{variable}.bar(baz) { |e| e.qux }
           RUBY
         end
 
-        it 'registers an offense for an object check followed by ' \
-           'a method calls that nil responds to ' do
+        it 'registers an offense for an object check followed by a method calls that nil responds to' do
           expect_offense(<<~RUBY, variable: variable)
             %{variable} && %{variable}.to_i
             ^{variable}^^^^^{variable}^^^^^ Use safe navigation (`&.`) instead [...]
@@ -934,8 +987,7 @@ RSpec.describe RuboCop::Cop::Style::SafeNavigation, :config do
           RUBY
         end
 
-        it 'registers an offense for an object check followed by ' \
-           'a method call' do
+        it 'registers an offense for an object check followed by a method call' do
           expect_offense(<<~RUBY, variable: variable)
             %{variable} && %{variable}.bar
             ^{variable}^^^^^{variable}^^^^ Use safe navigation (`&.`) instead [...]
@@ -946,8 +998,7 @@ RSpec.describe RuboCop::Cop::Style::SafeNavigation, :config do
           RUBY
         end
 
-        it 'registers an offense for an object check followed by ' \
-           'a method call with params' do
+        it 'registers an offense for an object check followed by a method call with params' do
           expect_offense(<<~RUBY, variable: variable)
             %{variable} && %{variable}.bar(baz)
             ^{variable}^^^^^{variable}^^^^^^^^^ Use safe navigation (`&.`) instead [...]
@@ -958,8 +1009,7 @@ RSpec.describe RuboCop::Cop::Style::SafeNavigation, :config do
           RUBY
         end
 
-        it 'registers an offense for an object check followed by ' \
-           'a method call with a block' do
+        it 'registers an offense for an object check followed by a method call with a block' do
           expect_offense(<<~RUBY, variable: variable)
             %{variable} && %{variable}.bar { |e| e.qux }
             ^{variable}^^^^^{variable}^^^^^^^^^^^^^^^^^^ Use safe navigation (`&.`) instead [...]
@@ -999,8 +1049,7 @@ RSpec.describe RuboCop::Cop::Style::SafeNavigation, :config do
         end
 
         context 'method chaining' do
-          it 'corrects an object check followed by ' \
-             'a chained method call' do
+          it 'corrects an object check followed by a chained method call' do
             expect_offense(<<~RUBY, variable: variable)
               %{variable} && %{variable}.one.two
               ^{variable}^^^^^{variable}^^^^^^^^ Use safe navigation (`&.`) instead [...]
@@ -1011,8 +1060,7 @@ RSpec.describe RuboCop::Cop::Style::SafeNavigation, :config do
             RUBY
           end
 
-          it 'corrects an object check followed by ' \
-             'a chained method call with params' do
+          it 'corrects an object check followed by a chained method call with params' do
             expect_offense(<<~RUBY, variable: variable)
               %{variable} && %{variable}.one.two(baz)
               ^{variable}^^^^^{variable}^^^^^^^^^^^^^ Use safe navigation (`&.`) instead [...]
@@ -1023,8 +1071,7 @@ RSpec.describe RuboCop::Cop::Style::SafeNavigation, :config do
             RUBY
           end
 
-          it 'corrects an object check followed by ' \
-             'a chained method call with a symbol proc' do
+          it 'corrects an object check followed by a chained method call with a symbol proc' do
             expect_offense(<<~RUBY, variable: variable)
               %{variable} && %{variable}.one.two(&:baz)
               ^{variable}^^^^^{variable}^^^^^^^^^^^^^^^ Use safe navigation (`&.`) instead [...]
@@ -1035,8 +1082,7 @@ RSpec.describe RuboCop::Cop::Style::SafeNavigation, :config do
             RUBY
           end
 
-          it 'corrects an object check followed by ' \
-             'a chained method call with a block' do
+          it 'corrects an object check followed by a chained method call with a block' do
             expect_offense(<<~RUBY, variable: variable)
               %{variable} && %{variable}.one.two(baz) { |e| e.qux }
               ^{variable}^^^^^{variable}^^^^^^^^^^^^^^^^^^^^^^^^^^^ Use safe navigation (`&.`) instead [...]
@@ -1063,8 +1109,7 @@ RSpec.describe RuboCop::Cop::Style::SafeNavigation, :config do
         RUBY
       end
 
-      it 'allows a nil object check followed by a method call with params ' \
-         'and a block' do
+      it 'allows a nil object check followed by a method call with params and a block' do
         expect_no_offenses(<<~RUBY)
           #{variable}.nil? || #{variable}.bar(baz) { |e| e.qux }
         RUBY
@@ -1082,8 +1127,7 @@ RSpec.describe RuboCop::Cop::Style::SafeNavigation, :config do
         expect_no_offenses("!#{variable} || #{variable}.bar { |e| e.qux }")
       end
 
-      it 'allows a non object check followed by a method call with params ' \
-         'and a block' do
+      it 'allows a non object check followed by a method call with params and a block' do
         expect_no_offenses(<<~RUBY)
           !#{variable} || #{variable}.bar(baz) { |e| e.qux }
         RUBY
@@ -1103,8 +1147,7 @@ RSpec.describe RuboCop::Cop::Style::SafeNavigation, :config do
       expect_no_offenses('foo.bar if foo.respond_to?(:bar)')
     end
 
-    it 'allows method calls safeguarded by a respond_to check to a ' \
-       'different method' do
+    it 'allows method calls safeguarded by a respond_to check to a different method' do
       expect_no_offenses('foo.bar if foo.respond_to?(:foobar)')
     end
 
@@ -1113,14 +1156,18 @@ RSpec.describe RuboCop::Cop::Style::SafeNavigation, :config do
       expect_no_offenses('foo.bar if baz.respond_to?(:bar)')
     end
 
-    it 'allows method calls safeguarded by a respond_to check on a' \
-       'different variable and method' do
+    it 'allows method calls safeguarded by a respond_to check on adifferent variable and method' do
       expect_no_offenses('foo.bar if baz.respond_to?(:foo)')
     end
 
-    it 'allows enumerable accessor method calls safeguarded by ' \
-       'a respond_to check' do
+    it 'allows enumerable accessor method calls safeguarded by a respond_to check' do
       expect_no_offenses('foo[0] if foo.respond_to?(:[])')
     end
   end
+
+  context 'when Ruby <= 2.2', :ruby22 do
+    it 'does not register an offense when a method call that nil responds to safe guarded by an object check' do
+      expect_no_offenses('foo.bar if foo')
+    end
+  end
 end
