@@ -1,8 +1,6 @@
 # frozen_string_literal: true
 
-RSpec.describe RuboCop::Cop::Style::SelfAssignment do
-  subject(:cop) { described_class.new }
-
+RSpec.describe RuboCop::Cop::Style::SelfAssignment, :config do
   %i[+ - * ** / | & || &&].product(['x', '@x', '@@x']).each do |op, var|
     it "registers an offense for non-shorthand assignment #{op} and #{var}" do
       expect_offense(<<~RUBY, op: op, var: var)
