@@ -2,19 +2,9 @@
 
 RSpec.describe RuboCop::Cop::Style::TernaryParentheses, :config do
   let(:redundant_parens_enabled) { false }
-  let(:other_cops) do
-    {
-      'Style/RedundantParentheses' => { 'Enabled' => redundant_parens_enabled }
-    }
-  end
 
   shared_examples 'safe assignment disabled' do |style, message|
-    let(:cop_config) do
-      {
-        'EnforcedStyle' => style,
-        'AllowSafeAssignment' => false
-      }
-    end
+    let(:cop_config) { { 'EnforcedStyle' => style, 'AllowSafeAssignment' => false } }
 
     it 'registers an offense for parens around assignment' do
       expect_offense(<<~RUBY)
@@ -159,6 +149,50 @@ RSpec.describe RuboCop::Cop::Style::TernaryParentheses, :config do
           not (bar) ? a : b
         RUBY
       end
+
+      it 'registers an offense for defined? with variable in condition' do
+        expect_offense(<<~RUBY)
+          foo = defined?(bar) ? a : b
+                ^^^^^^^^^^^^^^^^^^^^^ Use parentheses for ternary conditions.
+        RUBY
+
+        expect_correction(<<~RUBY)
+          foo = (defined?(bar)) ? a : b
+        RUBY
+      end
+
+      it 'registers an offense for defined? with method chain in condition' do
+        expect_offense(<<~RUBY)
+          foo = defined?(bar.baz) ? a : b
+                ^^^^^^^^^^^^^^^^^^^^^^^^^ Use parentheses for ternary conditions.
+        RUBY
+
+        expect_correction(<<~RUBY)
+          foo = (defined?(bar.baz)) ? a : b
+        RUBY
+      end
+
+      it 'registers an offense for defined? with class method in condition' do
+        expect_offense(<<~RUBY)
+          foo = defined?(Bar.baz) ? a : b
+                ^^^^^^^^^^^^^^^^^^^^^^^^^ Use parentheses for ternary conditions.
+        RUBY
+
+        expect_correction(<<~RUBY)
+          foo = (defined?(Bar.baz)) ? a : b
+        RUBY
+      end
+
+      it 'registers an offense for defined? with nested constant in condition' do
+        expect_offense(<<~RUBY)
+          foo = defined?(Bar::BAZ) ? a : b
+                ^^^^^^^^^^^^^^^^^^^^^^^^^^ Use parentheses for ternary conditions.
+        RUBY
+
+        expect_correction(<<~RUBY)
+          foo = (defined?(Bar::BAZ)) ? a : b
+        RUBY
+      end
     end
 
     context 'with an assignment condition' do
@@ -184,8 +218,7 @@ RSpec.describe RuboCop::Cop::Style::TernaryParentheses, :config do
         RUBY
       end
 
-      it 'registers an offense for double assignment with ' \
-         'equality check in condition' do
+      it 'registers an offense for double assignment with equality check in condition' do
         expect_offense(<<~RUBY)
           foo = bar = baz == 1 ? a : b
                       ^^^^^^^^^^^^^^^^ Use parentheses for ternary conditions.
@@ -327,6 +360,68 @@ RSpec.describe RuboCop::Cop::Style::TernaryParentheses, :config do
 
         expect_no_corrections
       end
+
+      it 'registers an offense for defined with variable in condition' do
+        expect_offense(<<~RUBY)
+          foo = (defined? bar) ? a : b
+                ^^^^^^^^^^^^^^^^^^^^^^ Omit parentheses for ternary conditions.
+        RUBY
+
+        expect_no_corrections
+      end
+
+      it 'registers an offense for defined with method chain in condition' do
+        expect_offense(<<~RUBY)
+          foo = (defined? bar.baz) ? a : b
+                ^^^^^^^^^^^^^^^^^^^^^^^^^^ Omit parentheses for ternary conditions.
+        RUBY
+
+        expect_no_corrections
+      end
+
+      it 'registers an offense for defined with class method in condition' do
+        expect_offense(<<~RUBY)
+          foo = (defined? Bar.baz) ? a : b
+                ^^^^^^^^^^^^^^^^^^^^^^^^^^ Omit parentheses for ternary conditions.
+        RUBY
+
+        expect_no_corrections
+      end
+
+      it 'registers an offense for defined with nested constant in condition' do
+        expect_offense(<<~RUBY)
+          foo = (defined? Bar::BAZ) ? a : b
+                ^^^^^^^^^^^^^^^^^^^^^^^^^^^ Omit parentheses for ternary conditions.
+        RUBY
+
+        expect_no_corrections
+      end
+    end
+
+    # In Ruby 2.7, `match-pattern` node represents one line pattern matching.
+    #
+    # % ruby-parse --27 -e 'foo in bar'
+    # (match-pattern (send nil :foo) (match-var :bar))
+    #
+    context 'with one line pattern matching', :ruby27 do
+      it 'does not register an offense' do
+        expect_no_offenses(<<~RUBY)
+          (foo in bar) ? a : b
+        RUBY
+      end
+    end
+
+    # In Ruby 3.0, `match-pattern-p` node represents one line pattern matching.
+    #
+    # % ruby-parse --30 -e 'foo in bar'
+    # (match-pattern-p (send nil :foo) (match-var :bar))
+    #
+    context 'with one line pattern matching', :ruby30 do
+      it 'does not register an offense' do
+        expect_no_offenses(<<~RUBY)
+          (foo in bar) ? a : b
+        RUBY
+      end
     end
 
     context 'with an assignment condition' do
@@ -441,9 +536,7 @@ RSpec.describe RuboCop::Cop::Style::TernaryParentheses, :config do
   end
 
   context 'configured for parentheses on complex and there are parens' do
-    let(:cop_config) do
-      { 'EnforcedStyle' => 'require_parentheses_when_complex' }
-    end
+    let(:cop_config) { { 'EnforcedStyle' => 'require_parentheses_when_complex' } }
 
     context 'with a simple condition' do
       it 'registers an offense for query method in condition' do
@@ -521,6 +614,42 @@ RSpec.describe RuboCop::Cop::Style::TernaryParentheses, :config do
       it 'accepts boolean expression' do
         expect_no_offenses('foo = (bar && (baz || bar)) ? a : b')
       end
+
+      it 'registers an offense for defined with variable in condition' do
+        expect_offense(<<~RUBY)
+          foo = (defined? bar) ? a : b
+                ^^^^^^^^^^^^^^^^^^^^^^ Only use parentheses for ternary expressions with complex conditions.
+        RUBY
+
+        expect_no_corrections
+      end
+
+      it 'registers an offense for defined with method chain in condition' do
+        expect_offense(<<~RUBY)
+          foo = (defined? bar.baz) ? a : b
+                ^^^^^^^^^^^^^^^^^^^^^^^^^^ Only use parentheses for ternary expressions with complex conditions.
+        RUBY
+
+        expect_no_corrections
+      end
+
+      it 'registers an offense for defined with class method in condition' do
+        expect_offense(<<~RUBY)
+          foo = (defined? Bar.baz) ? a : b
+                ^^^^^^^^^^^^^^^^^^^^^^^^^^ Only use parentheses for ternary expressions with complex conditions.
+        RUBY
+
+        expect_no_corrections
+      end
+
+      it 'registers an offense for defined with nested constant in condition' do
+        expect_offense(<<~RUBY)
+          foo = (defined? Bar::BAZ) ? a : b
+                ^^^^^^^^^^^^^^^^^^^^^^^^^^^ Only use parentheses for ternary expressions with complex conditions.
+        RUBY
+
+        expect_no_corrections
+      end
     end
 
     context 'with an assignment condition' do
@@ -565,8 +694,7 @@ RSpec.describe RuboCop::Cop::Style::TernaryParentheses, :config do
           expect_no_corrections
         end
 
-        it 'registers an offense for array include? with ' \
-          'multiple parameters without parens' do
+        it 'registers an offense for array include? with multiple parameters without parens' do
           expect_offense(<<~'RUBY')
             (%w(a b).include? params[:t], 3) ? "ab" : "c"
             ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^ Only use parentheses for ternary expressions with complex conditions.
@@ -575,8 +703,7 @@ RSpec.describe RuboCop::Cop::Style::TernaryParentheses, :config do
           expect_no_corrections
         end
 
-        it 'registers an offense for array include? with ' \
-          'multiple parameters with parens' do
+        it 'registers an offense for array include? with multiple parameters with parens' do
           expect_offense(<<~RUBY)
             (%w(a b).include?(params[:t], x)) ? "ab" : "c"
             ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^ Only use parentheses for ternary expressions with complex conditions.
@@ -635,9 +762,7 @@ RSpec.describe RuboCop::Cop::Style::TernaryParentheses, :config do
   end
 
   context 'configured for parentheses on complex and there are no parens' do
-    let(:cop_config) do
-      { 'EnforcedStyle' => 'require_parentheses_when_complex' }
-    end
+    let(:cop_config) { { 'EnforcedStyle' => 'require_parentheses_when_complex' } }
 
     context 'with complex condition' do
       it 'registers an offense for arithmetic and equality check' do
@@ -768,28 +893,4 @@ RSpec.describe RuboCop::Cop::Style::TernaryParentheses, :config do
       end
     end
   end
-
-  context 'when `RedundantParenthesis` would cause an infinite loop' do
-    let(:redundant_parens_enabled) { true }
-
-    context 'when `EnforcedStyle: require_parentheses`' do
-      let(:cop_config) do
-        { 'EnforcedStyle' => 'require_parentheses' }
-      end
-
-      it 'accepts' do
-        expect_no_offenses('foo = bar? ? a : b')
-      end
-    end
-
-    context 'when `EnforcedStyle: require_parentheses_when_complex`' do
-      let(:cop_config) do
-        { 'EnforcedStyle' => 'require_parentheses_when_complex' }
-      end
-
-      it 'accepts' do
-        expect_no_offenses('!condition.nil? ? foo : bar')
-      end
-    end
-  end
 end
