@@ -1,13 +1,11 @@
 # frozen_string_literal: true
 
-RSpec.describe RuboCop::Cop::Style::WhenThen do
-  subject(:cop) { described_class.new }
-
-  it 'registers an offense for when x;' do
+RSpec.describe RuboCop::Cop::Style::WhenThen, :config do
+  it 'registers an offense for when b;' do
     expect_offense(<<~RUBY)
       case a
       when b; c
-            ^ Do not use `when x;`. Use `when x then` instead.
+            ^ Do not use `when b;`. Use `when b then` instead.
       end
     RUBY
 
@@ -18,6 +16,21 @@ RSpec.describe RuboCop::Cop::Style::WhenThen do
     RUBY
   end
 
+  it 'registers an offense for when b, c;' do
+    expect_offense(<<~RUBY)
+      case a
+      when b, c; d
+               ^ Do not use `when b, c;`. Use `when b, c then` instead.
+      end
+    RUBY
+
+    expect_correction(<<~RUBY)
+      case a
+      when b, c then d
+      end
+    RUBY
+  end
+
   it 'accepts ; separating statements in the body of when' do
     expect_no_offenses(<<~RUBY)
       case a
@@ -31,7 +44,7 @@ RSpec.describe RuboCop::Cop::Style::WhenThen do
     RUBY
   end
 
-  # Regression: https://github.com/rubocop-hq/rubocop/issues/3868
+  # Regression: https://github.com/rubocop/rubocop/issues/3868
   context 'when inspecting a case statement with an empty branch' do
     it 'does not register an offense' do
       expect_no_offenses(<<~RUBY)
