@@ -4,7 +4,7 @@ RSpec.describe RuboCop::StringInterpreter do
   describe '.interpret' do
     shared_examples 'simple escape' do |escaped|
       it "handles #{escaped}" do
-        expect(described_class.interpret(escaped)).to eq escaped[1..-1]
+        expect(described_class.interpret(escaped)).to eq escaped[1..]
       end
     end
 
@@ -21,8 +21,7 @@ RSpec.describe RuboCop::StringInterpreter do
     end
 
     it 'handles extended unicode' do
-      expect(described_class.interpret('\\\\u{0068 0068}'))
-        .to eq('\\u{0068 0068}')
+      expect(described_class.interpret('\\\\u{0068 0068}')).to eq('\\u{0068 0068}')
     end
 
     it_behaves_like 'simple escape', '\\\\a'
@@ -34,6 +33,5 @@ RSpec.describe RuboCop::StringInterpreter do
     it_behaves_like 'simple escape', '\\\\s'
     it_behaves_like 'simple escape', '\\\\t'
     it_behaves_like 'simple escape', '\\\\v'
-    it_behaves_like 'simple escape', '\\\\n'
   end
 end
